/**
 * @file
 * @copyright This code is licensed under the 3-clause BSD license.\n
 *            Copyright ETH Zurich, Department of Chemistry and Applied Biosciences, Reiher Group.\n
 *            See LICENSE.txt for details.
 */

#ifndef MOLECULARMECHANICS_GAFFDEFAULTPARAMETERS_H
#define MOLECULARMECHANICS_GAFFDEFAULTPARAMETERS_H

#include <array>

/*
 * This is basically just a one-to-one copy from the data in the gaff.dat file,
 * which is available in the tests directory.
 */

namespace Scine {
namespace MolecularMechanics {
namespace GaffDefaultParameters {

static constexpr std::array<std::array<const char*, 2>, 791> bondAtomTypes = {
    {{"ow", "hw"}, {"br", "br"}, {"br", "c1"}, {"br", "c2"}, {"br", "c"},  {"br", "c3"}, {"br", "ca"}, {"br", "cc"},
     {"br", "cx"}, {"br", "i"},  {"br", "n1"}, {"br", "n2"}, {"br", "n"},  {"br", "n3"}, {"br", "n4"}, {"br", "na"},
     {"br", "nh"}, {"br", "no"}, {"br", "o"},  {"br", "oh"}, {"br", "os"}, {"br", "p2"}, {"br", "p3"}, {"br", "p4"},
     {"br", "p5"}, {"br", "s"},  {"br", "s4"}, {"br", "s6"}, {"br", "sh"}, {"br", "ss"}, {"c1", "c1"}, {"c1", "c2"},
     {"c1", "c3"}, {"c1", "ca"}, {"c1", "ce"}, {"c1", "cg"}, {"c1", "ch"}, {"c1", "cl"}, {"c1", "cx"}, {"c1", "f"},
     {"c1", "ha"}, {"c1", "hc"}, {"c1", "i"},  {"c1", "n1"}, {"c1", "n2"}, {"c1", "n3"}, {"c1", "n4"}, {"c1", "n"},
     {"c1", "na"}, {"c1", "ne"}, {"c1", "nf"}, {"c1", "nh"}, {"c1", "no"}, {"c1", "o"},  {"c1", "oh"}, {"c1", "os"},
     {"c1", "p2"}, {"c1", "p3"}, {"c1", "p4"}, {"c1", "p5"}, {"c1", "s2"}, {"c1", "s"},  {"c1", "s4"}, {"c1", "s6"},
     {"c1", "sh"}, {"c1", "ss"}, {"c2", "c2"}, {"c2", "c3"}, {"c2", "ca"}, {"c2", "cc"}, {"c2", "cd"}, {"c2", "ce"},
     {"c2", "cf"}, {"c2", "cl"}, {"c2", "cu"}, {"c2", "cx"}, {"c2", "cy"}, {"c2", "f"},  {"c2", "h4"}, {"c2", "h5"},
     {"c2", "ha"}, {"c2", "hc"}, {"c2", "hx"}, {"c2", "i"},  {"c2", "n1"}, {"c2", "n2"}, {"c2", "n3"}, {"c2", "n"},
     {"c2", "n4"}, {"c2", "na"}, {"c2", "nc"}, {"c2", "nd"}, {"c2", "ne"}, {"c2", "nf"}, {"c2", "nh"}, {"c2", "no"},
     {"c2", "o"},  {"c2", "oh"}, {"c2", "os"}, {"c2", "p2"}, {"c2", "p3"}, {"c2", "p4"}, {"c2", "p5"}, {"c2", "pe"},
     {"c2", "pf"}, {"c2", "s2"}, {"c2", "s"},  {"c2", "s4"}, {"c2", "s6"}, {"c2", "sh"}, {"c2", "ss"}, {"c3", "c3"},
     {"c3", "ca"}, {"c3", "cc"}, {"c3", "cd"}, {"c3", "ce"}, {"c3", "cf"}, {"c3", "cl"}, {"c3", "cu"}, {"c3", "cv"},
     {"c3", "cx"}, {"c3", "cy"}, {"c3", "f"},  {"c3", "h1"}, {"c3", "h2"}, {"c3", "h3"}, {"c3", "hc"}, {"c3", "hx"},
     {"c3", "i"},  {"c3", "n1"}, {"c3", "n2"}, {"c3", "n"},  {"c3", "n3"}, {"c3", "n4"}, {"c3", "na"}, {"c3", "nc"},
     {"c3", "nd"}, {"c3", "nh"}, {"c3", "no"}, {"c3", "o"},  {"c3", "oh"}, {"c3", "os"}, {"c3", "p2"}, {"c3", "p3"},
     {"c3", "p4"}, {"c3", "p5"}, {"c3", "px"}, {"c3", "py"}, {"c3", "s"},  {"c3", "s4"}, {"c3", "s6"}, {"c3", "sh"},
     {"c3", "ss"}, {"c3", "sx"}, {"c3", "sy"}, {"ca", "ca"}, {"ca", "cc"}, {"ca", "cd"}, {"ca", "ce"}, {"ca", "cf"},
     {"ca", "cg"}, {"ca", "ch"}, {"ca", "cl"}, {"ca", "cp"}, {"ca", "cq"}, {"ca", "cx"}, {"ca", "cy"}, {"ca", "f"},
     {"ca", "h4"}, {"ca", "h5"}, {"ca", "ha"}, {"ca", "i"},  {"ca", "n1"}, {"ca", "n2"}, {"ca", "n"},  {"ca", "n4"},
     {"ca", "na"}, {"ca", "nb"}, {"ca", "nc"}, {"ca", "nd"}, {"ca", "ne"}, {"ca", "nf"}, {"ca", "nh"}, {"ca", "no"},
     {"ca", "o"},  {"ca", "oh"}, {"ca", "os"}, {"ca", "p2"}, {"ca", "p3"}, {"ca", "p4"}, {"ca", "p5"}, {"ca", "pe"},
     {"ca", "pf"}, {"ca", "px"}, {"ca", "py"}, {"ca", "s"},  {"ca", "s4"}, {"ca", "s6"}, {"ca", "sh"}, {"ca", "ss"},
     {"ca", "sx"}, {"ca", "sy"}, {"c", "c1"},  {"c", "c2"},  {"c", "c"},   {"c", "c3"},  {"c", "ca"},  {"c", "cc"},
     {"cc", "cc"}, {"cc", "cd"}, {"cc", "ce"}, {"cc", "cf"}, {"cc", "cg"}, {"cc", "ch"}, {"cc", "cl"}, {"cc", "cx"},
     {"c", "cd"},  {"c", "ce"},  {"c", "cf"},  {"cc", "f"},  {"c", "cg"},  {"c", "ch"},  {"cc", "h4"}, {"cc", "h5"},
     {"cc", "ha"}, {"c", "cl"},  {"cc", "n2"}, {"cc", "n"},  {"cc", "n4"}, {"cc", "na"}, {"cc", "nc"}, {"cc", "nd"},
     {"cc", "ne"}, {"cc", "nf"}, {"cc", "nh"}, {"cc", "no"}, {"cc", "oh"}, {"cc", "os"}, {"cc", "pd"}, {"cc", "sh"},
     {"cc", "ss"}, {"cc", "sx"}, {"cc", "sy"}, {"c", "cu"},  {"c", "cx"},  {"c", "cy"},  {"cd", "cd"}, {"cd", "ce"},
     {"cd", "cf"}, {"cd", "cg"}, {"cd", "ch"}, {"cd", "cl"}, {"cd", "cx"}, {"cd", "cy"}, {"cd", "h4"}, {"cd", "h5"},
     {"cd", "ha"}, {"cd", "n2"}, {"cd", "n"},  {"cd", "na"}, {"cd", "nc"}, {"cd", "nd"}, {"cd", "ne"}, {"cd", "nh"},
     {"cd", "oh"}, {"cd", "os"}, {"cd", "pc"}, {"cd", "ss"}, {"cd", "sy"}, {"ce", "ce"}, {"ce", "cf"}, {"ce", "cg"},
     {"ce", "ch"}, {"ce", "cl"}, {"ce", "cx"}, {"ce", "cy"}, {"ce", "h4"}, {"ce", "ha"}, {"ce", "n1"}, {"ce", "n2"},
     {"ce", "n"},  {"ce", "na"}, {"ce", "ne"}, {"ce", "nf"}, {"ce", "nh"}, {"ce", "oh"}, {"ce", "os"}, {"ce", "p2"},
     {"ce", "pe"}, {"ce", "px"}, {"ce", "py"}, {"ce", "s"},  {"ce", "ss"}, {"ce", "sx"}, {"ce", "sy"}, {"c", "f"},
     {"cf", "cf"}, {"cf", "cg"}, {"cf", "ch"}, {"cf", "h4"}, {"cf", "ha"}, {"cf", "n1"}, {"cf", "n2"}, {"cf", "n"},
     {"cf", "ne"}, {"cf", "nf"}, {"cf", "nh"}, {"cf", "oh"}, {"cf", "os"}, {"cf", "p2"}, {"cf", "pf"}, {"cf", "px"},
     {"cf", "py"}, {"cf", "s"},  {"cf", "sx"}, {"cf", "sy"}, {"cg", "cg"}, {"cg", "ch"}, {"cg", "n1"}, {"cg", "ne"},
     {"cg", "pe"}, {"c", "h4"},  {"c", "h5"},  {"c", "ha"},  {"ch", "ch"}, {"ch", "n1"}, {"ch", "nf"}, {"ch", "pf"},
     {"c", "i"},   {"cl", "cl"}, {"cl", "cx"}, {"cl", "cy"}, {"cl", "f"},  {"cl", "i"},  {"cl", "n1"}, {"cl", "n2"},
     {"cl", "n3"}, {"cl", "n"},  {"cl", "n4"}, {"cl", "na"}, {"cl", "nh"}, {"cl", "no"}, {"cl", "o"},  {"cl", "oh"},
     {"cl", "os"}, {"cl", "p2"}, {"cl", "p3"}, {"cl", "p4"}, {"cl", "p5"}, {"cl", "pb"}, {"cl", "s"},  {"cl", "s2"},
     {"cl", "s4"}, {"cl", "s6"}, {"cl", "sh"}, {"cl", "ss"}, {"cl", "sx"}, {"cl", "sy"}, {"c", "n2"},  {"c", "n4"},
     {"c", "n"},   {"c", "nc"},  {"c", "nd"},  {"c", "ne"},  {"c", "nf"},  {"c", "no"},  {"c", "o"},   {"c", "oh"},
     {"c", "os"},  {"c", "p2"},  {"c", "p3"},  {"c", "p4"},  {"c", "p5"},  {"cp", "cp"}, {"cp", "cq"}, {"c", "pe"},
     {"c", "pf"},  {"cp", "na"}, {"cp", "nb"}, {"c", "px"},  {"c", "py"},  {"cq", "cq"}, {"c", "s"},   {"c", "s4"},
     {"c", "s6"},  {"c", "sh"},  {"c", "ss"},  {"c", "sx"},  {"c", "sy"},  {"cu", "cu"}, {"cu", "cx"}, {"cu", "ha"},
     {"cv", "cv"}, {"cv", "cy"}, {"cv", "ha"}, {"cx", "cv"}, {"cx", "cx"}, {"cx", "cy"}, {"cx", "f"},  {"cx", "h1"},
     {"cx", "h2"}, {"cx", "hc"}, {"cx", "hx"}, {"cx", "n2"}, {"cx", "n3"}, {"cx", "n"},  {"cx", "na"}, {"cx", "nh"},
     {"cx", "oh"}, {"cx", "os"}, {"cx", "p3"}, {"cx", "s4"}, {"cx", "s6"}, {"cx", "ss"}, {"cy", "cy"}, {"cy", "f"},
     {"cy", "h1"}, {"cy", "h2"}, {"cy", "hc"}, {"cy", "n"},  {"cy", "n3"}, {"cy", "oh"}, {"cy", "os"}, {"cy", "s6"},
     {"cy", "ss"}, {"cz", "nh"}, {"f", "n1"},  {"f", "n2"},  {"f", "n3"},  {"f", "n"},   {"f", "n4"},  {"f", "na"},
     {"f", "nh"},  {"f", "no"},  {"f", "o"},   {"f", "oh"},  {"f", "os"},  {"f", "p2"},  {"f", "p3"},  {"f", "p4"},
     {"f", "p5"},  {"f", "s2"},  {"f", "s"},   {"f", "s4"},  {"f", "s6"},  {"f", "sh"},  {"f", "ss"},  {"hn", "n1"},
     {"hn", "n2"}, {"hn", "n3"}, {"hn", "n"},  {"hn", "n4"}, {"hn", "na"}, {"hn", "nh"}, {"hn", "no"}, {"ho", "o"},
     {"ho", "oh"}, {"hp", "p2"}, {"hp", "p3"}, {"hp", "p4"}, {"hp", "p5"}, {"hs", "s"},  {"hs", "s4"}, {"hs", "s6"},
     {"hs", "sh"}, {"i", "i"},   {"i", "n1"},  {"i", "n2"},  {"i", "n"},   {"i", "n3"},  {"i", "n4"},  {"i", "na"},
     {"i", "nh"},  {"i", "no"},  {"i", "o"},   {"i", "oh"},  {"i", "os"},  {"i", "p2"},  {"i", "p3"},  {"i", "p4"},
     {"i", "p5"},  {"i", "s"},   {"i", "s4"},  {"i", "s6"},  {"i", "sh"},  {"i", "ss"},  {"n1", "n1"}, {"n1", "n2"},
     {"n1", "n3"}, {"n1", "n4"}, {"n1", "na"}, {"n1", "nc"}, {"n1", "nd"}, {"n1", "ne"}, {"n1", "nf"}, {"n1", "nh"},
     {"n1", "no"}, {"n1", "o"},  {"n1", "oh"}, {"n1", "os"}, {"n1", "p2"}, {"n1", "p3"}, {"n1", "p4"}, {"n1", "p5"},
     {"n1", "s2"}, {"n1", "s"},  {"n1", "s4"}, {"n1", "s6"}, {"n1", "sh"}, {"n1", "ss"}, {"n2", "n2"}, {"n2", "n3"},
     {"n2", "n4"}, {"n2", "na"}, {"n2", "nc"}, {"n2", "nd"}, {"n2", "ne"}, {"n2", "nf"}, {"n2", "nh"}, {"n2", "no"},
     {"n2", "o"},  {"n2", "oh"}, {"n2", "os"}, {"n2", "p2"}, {"n2", "p3"}, {"n2", "p4"}, {"n2", "p5"}, {"n2", "pe"},
     {"n2", "pf"}, {"n2", "s2"}, {"n2", "s4"}, {"n2", "s"},  {"n2", "s6"}, {"n2", "sh"}, {"n2", "ss"}, {"n3", "n3"},
     {"n3", "n4"}, {"n3", "na"}, {"n3", "nh"}, {"n3", "no"}, {"n3", "o"},  {"n3", "oh"}, {"n3", "os"}, {"n3", "p2"},
     {"n3", "p3"}, {"n3", "p4"}, {"n3", "p5"}, {"n3", "py"}, {"n3", "s"},  {"n3", "s4"}, {"n3", "s6"}, {"n3", "sh"},
     {"n3", "ss"}, {"n3", "sy"}, {"n4", "n4"}, {"n4", "na"}, {"n4", "nh"}, {"n4", "no"}, {"n4", "o"},  {"n4", "oh"},
     {"n4", "os"}, {"n4", "p2"}, {"n4", "p3"}, {"n4", "p4"}, {"n4", "p5"}, {"n4", "py"}, {"n4", "s"},  {"n4", "s4"},
     {"n4", "s6"}, {"n4", "sh"}, {"n4", "ss"}, {"na", "na"}, {"na", "nb"}, {"na", "nc"}, {"na", "nd"}, {"na", "nh"},
     {"na", "no"}, {"na", "o"},  {"na", "oh"}, {"na", "os"}, {"na", "p2"}, {"na", "p3"}, {"na", "p4"}, {"na", "p5"},
     {"na", "pc"}, {"na", "pd"}, {"na", "py"}, {"na", "s"},  {"na", "s4"}, {"na", "s6"}, {"na", "sh"}, {"na", "ss"},
     {"na", "sy"}, {"nb", "nb"}, {"nb", "pb"}, {"nc", "nc"}, {"nc", "nd"}, {"nc", "os"}, {"nc", "ss"}, {"nc", "sy"},
     {"nd", "nd"}, {"nd", "os"}, {"nd", "ss"}, {"nd", "sy"}, {"ne", "ne"}, {"ne", "nf"}, {"ne", "o"},  {"ne", "p2"},
     {"ne", "pe"}, {"ne", "px"}, {"ne", "py"}, {"ne", "s"},  {"ne", "sx"}, {"ne", "sy"}, {"nf", "nf"}, {"nf", "o"},
     {"nf", "p2"}, {"nf", "pf"}, {"nf", "px"}, {"nf", "py"}, {"nf", "s"},  {"nf", "sx"}, {"nf", "sy"}, {"nh", "nh"},
     {"nh", "no"}, {"nh", "o"},  {"nh", "oh"}, {"nh", "os"}, {"nh", "p2"}, {"nh", "p3"}, {"nh", "p4"}, {"nh", "p5"},
     {"nh", "s"},  {"nh", "s4"}, {"nh", "s6"}, {"nh", "sh"}, {"nh", "ss"}, {"nh", "sy"}, {"n", "n1"},  {"n", "n2"},
     {"n", "n3"},  {"n", "n4"},  {"n", "n"},   {"n", "na"},  {"n", "nc"},  {"n", "nd"},  {"n", "nh"},  {"n", "no"},
     {"n", "o"},   {"n", "oh"},  {"no", "no"}, {"no", "o"},  {"no", "oh"}, {"no", "os"}, {"no", "os"}, {"no", "p2"},
     {"no", "p3"}, {"no", "p4"}, {"no", "p5"}, {"no", "s"},  {"n", "os"},  {"no", "s4"}, {"no", "s6"}, {"no", "sh"},
     {"no", "ss"}, {"n", "p2"},  {"n", "p3"},  {"n", "p4"},  {"n", "p5"},  {"n", "pc"},  {"n", "pd"},  {"n", "s"},
     {"n", "s4"},  {"n", "s6"},  {"n", "sh"},  {"n", "ss"},  {"n", "sy"},  {"oh", "oh"}, {"oh", "os"}, {"oh", "p2"},
     {"oh", "p3"}, {"oh", "p4"}, {"oh", "p5"}, {"oh", "py"}, {"oh", "s"},  {"oh", "s4"}, {"oh", "s6"}, {"oh", "sh"},
     {"oh", "ss"}, {"oh", "sy"}, {"o", "o"},   {"o", "oh"},  {"o", "os"},  {"o", "p2"},  {"o", "p3"},  {"o", "p4"},
     {"o", "p5"},  {"o", "pe"},  {"o", "pf"},  {"o", "px"},  {"o", "py"},  {"o", "s"},   {"o", "s2"},  {"o", "s4"},
     {"o", "s6"},  {"o", "sh"},  {"os", "os"}, {"os", "p2"}, {"os", "p3"}, {"os", "p4"}, {"os", "p5"}, {"os", "py"},
     {"os", "s"},  {"o", "ss"},  {"os", "s4"}, {"os", "s6"}, {"os", "sh"}, {"os", "ss"}, {"os", "sy"}, {"o", "sx"},
     {"o", "sy"},  {"p2", "p2"}, {"p2", "p3"}, {"p2", "p4"}, {"p2", "p5"}, {"p2", "pe"}, {"p2", "pf"}, {"p2", "s"},
     {"p2", "s4"}, {"p2", "s6"}, {"p2", "sh"}, {"p2", "ss"}, {"p3", "p3"}, {"p3", "p4"}, {"p3", "p5"}, {"p3", "s"},
     {"p3", "s4"}, {"p3", "s6"}, {"p3", "sh"}, {"p3", "ss"}, {"p4", "p4"}, {"p4", "p5"}, {"p4", "s"},  {"p4", "s4"},
     {"p4", "s6"}, {"p4", "sh"}, {"p4", "ss"}, {"p5", "p5"}, {"p5", "s"},  {"p5", "s4"}, {"p5", "s6"}, {"p5", "sh"},
     {"p5", "ss"}, {"pe", "pe"}, {"pe", "pf"}, {"pe", "px"}, {"pe", "py"}, {"pe", "s"},  {"pe", "sx"}, {"pe", "sy"},
     {"pf", "pf"}, {"pf", "px"}, {"pf", "py"}, {"pf", "s"},  {"pf", "sx"}, {"pf", "sy"}, {"px", "py"}, {"px", "sx"},
     {"px", "sy"}, {"py", "py"}, {"py", "sx"}, {"py", "sy"}, {"s4", "s4"}, {"s4", "s6"}, {"s4", "sh"}, {"s4", "ss"},
     {"s6", "s6"}, {"s6", "sh"}, {"s6", "ss"}, {"sh", "sh"}, {"sh", "ss"}, {"s", "s"},   {"s", "s2"},  {"s", "s4"},
     {"s", "s6"},  {"s", "sh"},  {"s", "ss"},  {"ss", "ss"}, {"sx", "sx"}, {"sx", "sy"}, {"sy", "sy"}}};

static constexpr std::array<std::array<double, 2>, 791> bondParameters = {
    {{553.0, 0.9572},  {123.2, 2.5420},  {352.7, 1.7870}, {278.7, 1.8830}, {240.3, 1.9460}, {229.5, 1.9660},
     {269.6, 1.8970},  {277.6, 1.8847},  {261.4, 1.9100}, {142.4, 2.6710}, {330.4, 1.8600}, {219.0, 2.0380},
     {320.2, 1.8730},  {265.9, 1.9520},  {282.4, 1.9260}, {237.3, 2.0020}, {270.9, 1.9440}, {191.0, 2.1010},
     {278.9, 1.8000},  {237.2, 1.8660},  {225.6, 1.8870}, {174.3, 2.2100}, {167.0, 2.2310}, {188.8, 2.1710},
     {179.3, 2.1960},  {170.6, 2.2200},  {134.3, 2.3410}, {172.7, 2.2140}, {174.4, 2.2090}, {176.6, 2.2030},
     {986.2, 1.1810},  {625.0, 1.3070},  {368.3, 1.4700}, {404.1, 1.4400}, {607.4, 1.3153}, {845.8, 1.2220},
     {845.8, 1.2220},  {419.7, 1.6310},  {399.1, 1.4440}, {469.4, 1.2700}, {375.9, 1.0660}, {385.6, 1.0600},
     {318.8, 1.9890},  {1014.5, 1.1380}, {769.8, 1.2100}, {409.8, 1.3920}, {378.2, 1.4170}, {503.0, 1.3300},
     {452.0, 1.3620},  {803.3, 1.1986},  {803.3, 1.1986}, {485.0, 1.3408}, {393.0, 1.4050}, {777.0, 1.1660},
     {435.6, 1.3260},  {437.1, 1.3250},  {289.3, 1.7700}, {275.1, 1.7900}, {275.1, 1.7900}, {302.2, 1.7530},
     {410.0, 1.5950},  {371.8, 1.6300},  {272.9, 1.7460}, {290.4, 1.7220}, {324.5, 1.6800}, {325.4, 1.6790},
     {589.7, 1.3240},  {328.3, 1.5080},  {357.2, 1.4800}, {522.6, 1.3600}, {522.6, 1.3600}, {560.5, 1.3390},
     {560.5, 1.3390},  {328.8, 1.7220},  {573.9, 1.3320}, {353.3, 1.4836}, {331.7, 1.5046}, {368.7, 1.3400},
     {348.6, 1.0840},  {338.0, 1.0915},  {344.3, 1.0870}, {344.3, 1.0870}, {350.1, 1.0830}, {223.2, 2.1530},
     {546.0, 1.3060},  {581.1, 1.2880},  {486.3, 1.3400}, {390.5, 1.4070}, {309.1, 1.4820}, {411.1, 1.3910},
     {533.0, 1.3130},  {533.0, 1.3130},  {597.7, 1.2800}, {597.7, 1.2800}, {462.6, 1.3550}, {345.6, 1.4457},
     {623.6, 1.2244},  {425.4, 1.3330},  {392.6, 1.3570}, {375.9, 1.6700}, {246.6, 1.8340}, {254.0, 1.8220},
     {228.2, 1.8658},  {355.3, 1.6910},  {355.3, 1.6910}, {393.1, 1.6100}, {281.5, 1.7340}, {263.2, 1.7600},
     {263.2, 1.7600},  {252.0, 1.7771},  {280.0, 1.7360}, {303.1, 1.5350}, {323.5, 1.5130}, {337.3, 1.4990},
     {337.3, 1.4990},  {331.3, 1.5050},  {331.3, 1.5050}, {279.0, 1.7860}, {359.4, 1.4780}, {347.6, 1.4890},
     {322.5, 1.5140},  {308.5, 1.5290},  {363.8, 1.3440}, {335.9, 1.0930}, {326.4, 1.1000}, {333.4, 1.0948},
     {337.3, 1.0920},  {338.7, 1.0910},  {219.1, 2.1620}, {325.1, 1.4700}, {313.8, 1.4770}, {330.6, 1.4600},
     {320.6, 1.4700},  {293.6, 1.4990},  {334.7, 1.4560}, {334.7, 1.4560}, {334.7, 1.4560}, {332.7, 1.4580},
     {265.4, 1.5330},  {449.9, 1.3165},  {314.1, 1.4260}, {301.5, 1.4390}, {234.3, 1.8550}, {240.6, 1.8440},
     {247.2, 1.8330},  {259.7, 1.8130},  {252.7, 1.8240}, {259.7, 1.8130}, {212.9, 1.8450}, {233.8, 1.8070},
     {254.0, 1.7740},  {225.3, 1.8220},  {225.8, 1.8210}, {232.6, 1.8090}, {248.9, 1.7820}, {478.4, 1.3870},
     {411.7, 1.4340},  {411.7, 1.4340},  {366.0, 1.4720}, {366.0, 1.4720}, {406.6, 1.4380}, {406.6, 1.4380},
     {322.8, 1.7290},  {466.1, 1.3950},  {457.4, 1.4009}, {350.8, 1.4860}, {323.0, 1.5135}, {363.8, 1.3440},
     {342.9, 1.0880},  {347.2, 1.0850},  {344.3, 1.0870}, {252.4, 2.0950}, {398.1, 1.4000}, {551.6, 1.3030},
     {372.3, 1.4220},  {325.6, 1.4650},  {470.3, 1.3500}, {483.1, 1.3420}, {492.9, 1.3360}, {492.9, 1.3360},
     {361.8, 1.4310},  {361.8, 1.4310},  {449.0, 1.3640}, {322.6, 1.4680}, {610.0, 1.2304}, {386.1, 1.3620},
     {372.4, 1.3730},  {243.0, 1.8400},  {252.7, 1.8240}, {264.3, 1.8060}, {271.6, 1.7950}, {249.6, 1.8290},
     {249.6, 1.8290},  {252.1, 1.8250},  {268.3, 1.7999}, {277.9, 1.7390}, {245.2, 1.7880}, {263.9, 1.7590},
     {251.3, 1.7783},  {256.6, 1.7700},  {223.5, 1.8252}, {247.7, 1.7840}, {379.8, 1.4600}, {449.9, 1.4060},
     {290.1, 1.5500},  {328.3, 1.5080},  {349.7, 1.4870}, {377.4, 1.4620}, {418.3, 1.4290}, {504.0, 1.3710},
     {391.4, 1.4502},  {521.7, 1.3605},  {420.9, 1.4270}, {420.9, 1.4270}, {317.1, 1.7359}, {369.3, 1.4691},
     {377.4, 1.4620},  {363.8, 1.4740},  {363.8, 1.4740}, {368.6, 1.3401}, {389.3, 1.4520}, {389.3, 1.4520},
     {350.1, 1.0830},  {356.0, 1.0790},  {347.2, 1.0850}, {293.5, 1.7660}, {572.5, 1.2923}, {426.0, 1.3800},
     {299.0, 1.4930},  {438.8, 1.3710},  {431.6, 1.3760}, {494.6, 1.3350}, {427.4, 1.3790}, {580.1, 1.2885},
     {449.0, 1.3640},  {367.4, 1.4262},  {411.8, 1.3427}, {376.1, 1.3700}, {318.2, 1.7330}, {257.9, 1.7681},
     {279.3, 1.7370},  {231.3, 1.8113},  {245.7, 1.7872}, {441.4, 1.4120}, {350.8, 1.4860}, {308.5, 1.5290},
     {418.3, 1.4290},  {504.8, 1.3705},  {381.8, 1.4583}, {420.9, 1.4270}, {420.9, 1.4270}, {317.3, 1.7356},
     {358.6, 1.4787},  {330.9, 1.5054},  {350.1, 1.0830}, {356.0, 1.0790}, {347.2, 1.0850}, {577.7, 1.2897},
     {426.0, 1.3800},  {438.8, 1.3710},  {494.6, 1.3350}, {431.6, 1.3760}, {554.1, 1.3017}, {449.0, 1.3640},
     {404.7, 1.3479},  {376.1, 1.3700},  {318.2, 1.7330}, {279.3, 1.7370}, {251.7, 1.7777}, {390.5, 1.4510},
     {562.4, 1.3380},  {415.6, 1.4310},  {415.6, 1.4310}, {292.6, 1.7671}, {337.0, 1.4993}, {323.0, 1.5135},
     {337.8, 1.0916},  {341.5, 1.0890},  {540.3, 1.3090}, {599.8, 1.2790}, {369.2, 1.4246}, {373.8, 1.4207},
     {381.8, 1.4140},  {571.9, 1.2926},  {410.8, 1.3912}, {395.9, 1.3545}, {370.6, 1.3745}, {259.1, 1.8140},
     {256.5, 1.8180},  {254.6, 1.8210},  {272.3, 1.7940}, {324.5, 1.6800}, {243.6, 1.7906}, {239.7, 1.7970},
     {248.9, 1.7820},  {387.9, 1.3250},  {390.5, 1.4510}, {415.6, 1.4310}, {415.6, 1.4310}, {334.5, 1.0940},
     {341.5, 1.0890},  {522.2, 1.3190},  {599.8, 1.2790}, {362.6, 1.4303}, {575.1, 1.2910}, {381.8, 1.4140},
     {423.0, 1.3822},  {414.4, 1.3408},  {387.2, 1.3612}, {259.1, 1.8140}, {256.5, 1.8180}, {254.6, 1.8210},
     {272.3, 1.7940},  {324.5, 1.6800},  {239.7, 1.7970}, {248.9, 1.7820}, {494.2, 1.3770}, {949.5, 1.1910},
     {994.7, 1.1430},  {509.5, 1.3262},  {429.8, 1.6210}, {310.5, 1.1123}, {319.4, 1.1053}, {325.1, 1.1010},
     {494.2, 1.3770},  {994.7, 1.1430},  {509.5, 1.3262}, {429.8, 1.6210}, {198.9, 2.2090}, {143.3, 2.2670},
     {301.8, 1.7550},  {292.0, 1.7680},  {298.6, 1.6480}, {163.5, 2.5500}, {431.6, 1.6300}, {263.4, 1.8190},
     {290.4, 1.7800},  {344.2, 1.7140},  {311.1, 1.7530}, {253.2, 1.8350}, {303.2, 1.7630}, {250.1, 1.8400},
     {557.6, 1.4830},  {309.7, 1.6900},  {278.8, 1.7300}, {217.5, 2.0700}, {249.4, 2.0080}, {249.4, 2.0080},
     {249.4, 2.0080},  {255.6, 1.9970},  {208.7, 2.0720}, {172.7, 2.1610}, {208.7, 2.0720}, {208.7, 2.0720},
     {208.7, 2.0720},  {208.7, 2.0720},  {208.7, 2.0720}, {208.7, 2.0720}, {374.6, 1.4200}, {255.5, 1.5460},
     {478.2, 1.3450},  {428.3, 1.3784},  {391.2, 1.4064}, {408.6, 1.3929}, {404.8, 1.3958}, {260.1, 1.5400},
     {648.0, 1.2140},  {466.4, 1.3060},  {411.3, 1.3430}, {210.3, 1.9000}, {219.0, 1.8830}, {220.6, 1.8800},
     {219.8, 1.8815},  {346.5, 1.4900},  {419.3, 1.4282}, {204.9, 1.9110}, {204.9, 1.9110}, {420.5, 1.3840},
     {486.7, 1.3398},  {208.3, 1.9040},  {227.6, 1.8670}, {346.5, 1.4900}, {328.9, 1.6750}, {200.4, 1.8700},
     {200.4, 1.8700},  {249.6, 1.7810},  {261.9, 1.7620}, {193.3, 1.8850}, {202.8, 1.8650}, {653.7, 1.2940},
     {327.3, 1.5090},  {353.0, 1.0810},  {568.1, 1.3350}, {323.5, 1.5130}, {344.3, 1.0870}, {328.3, 1.5080},
     {337.3, 1.4990},  {321.5, 1.5150},  {347.2, 1.3580}, {344.3, 1.0870}, {350.1, 1.0830}, {345.8, 1.0860},
     {347.2, 1.0850},  {309.1, 1.4820},  {318.7, 1.4720}, {350.6, 1.4411}, {329.0, 1.4616}, {336.7, 1.4541},
     {387.4, 1.3610},  {320.1, 1.4200},  {227.6, 1.8670}, {225.3, 1.8220}, {283.7, 1.7310}, {229.2, 1.8150},
     {286.8, 1.5540},  {355.5, 1.3509},  {330.4, 1.0970}, {335.8, 1.0931}, {334.5, 1.0940}, {321.3, 1.4693},
     {307.2, 1.4840},  {325.2, 1.4150},  {308.6, 1.4316}, {209.6, 1.8514}, {211.3, 1.8481}, {487.8, 1.3391},
     {375.7, 1.4100},  {337.5, 1.4440},  {380.6, 1.4060}, {391.7, 1.3970}, {526.8, 1.3080}, {374.5, 1.4110},
     {357.1, 1.4260},  {314.4, 1.4670},  {442.2, 1.3300}, {305.4, 1.4440}, {326.2, 1.4230}, {287.3, 1.5360},
     {254.5, 1.5780},  {246.0, 1.5900},  {253.8, 1.5790}, {244.4, 1.6430}, {233.3, 1.6600}, {282.4, 1.5910},
     {312.1, 1.5560},  {240.4, 1.6490},  {250.5, 1.6340}, {455.1, 0.9860}, {375.5, 1.0290}, {394.1, 1.0180},
     {410.2, 1.0090},  {369.0, 1.0330},  {406.6, 1.0110}, {401.2, 1.0140}, {385.6, 1.0230}, {357.9, 0.9810},
     {369.6, 0.9740},  {385.1, 1.3360},  {303.1, 1.4090}, {368.7, 1.3490}, {305.0, 1.4070}, {286.4, 1.3530},
     {266.4, 1.3750},  {280.8, 1.3590},  {302.2, 1.3370}, {109.2, 2.9170}, {302.1, 2.0600}, {182.6, 2.3040},
     {278.3, 2.0980},  {231.8, 2.1850},  {246.6, 2.1550}, {260.5, 2.1290}, {249.2, 2.1500}, {211.0, 2.2310},
     {323.8, 1.9800},  {247.9, 2.1010},  {233.6, 2.1290}, {108.2, 2.6430}, {123.6, 2.5660}, {183.0, 2.3520},
     {117.3, 2.5960},  {175.1, 2.4300},  {82.8, 2.8700},  {82.8, 2.8700},  {138.5, 2.5600}, {135.9, 2.5710},
     {1221.7, 1.1240}, {857.4, 1.2160},  {535.7, 1.3500}, {518.2, 1.3600}, {535.7, 1.3500}, {857.4, 1.2160},
     {857.4, 1.2160},  {751.9, 1.2520},  {751.9, 1.2520}, {553.9, 1.3400}, {454.8, 1.4000}, {617.5, 1.2770},
     {569.8, 1.3000},  {550.5, 1.3100},  {358.8, 1.6780}, {376.7, 1.6600}, {353.0, 1.6800}, {482.7, 1.5710},
     {604.3, 1.4490},  {328.7, 1.6590},  {336.8, 1.6500}, {670.3, 1.4160}, {376.1, 1.6100}, {376.1, 1.6100},
     {702.7, 1.2710},  {574.8, 1.3290},  {200.8, 1.6790}, {503.9, 1.3685}, {743.9, 1.2550}, {743.9, 1.2550},
     {685.5, 1.2780},  {685.5, 1.2780},  {525.1, 1.3560}, {231.9, 1.6260}, {789.9, 1.2090}, {416.2, 1.3940},
     {400.5, 1.4060},  {438.3, 1.6050},  {286.5, 1.7640}, {317.7, 1.7240}, {445.8, 1.5990}, {527.9, 1.5400},
     {527.9, 1.5400},  {499.0, 1.5120},  {376.1, 1.6100}, {458.1, 1.5410}, {444.6, 1.5513}, {266.6, 1.7380},
     {331.4, 1.6560},  {383.6, 1.4540},  {434.9, 1.4140}, {426.7, 1.4200}, {426.7, 1.4200}, {394.5, 1.4450},
     {564.0, 1.3030},  {413.5, 1.3960},  {359.6, 1.4400}, {366.6, 1.6700}, {312.8, 1.7300}, {341.1, 1.6970},
     {373.6, 1.6630},  {338.1, 1.7003},  {232.3, 1.7920}, {251.3, 1.7610}, {353.8, 1.6320}, {265.9, 1.7390},
     {277.9, 1.7220},  {297.3, 1.6964},  {349.9, 1.4840}, {407.0, 1.4350}, {369.7, 1.4660}, {354.2, 1.4800},
     {463.6, 1.3610},  {408.2, 1.4000},  {381.8, 1.4210}, {185.9, 1.9420}, {215.1, 1.8800}, {187.6, 1.9380},
     {242.9, 1.8300},  {204.2, 1.9020},  {210.3, 1.8320}, {151.0, 1.9720}, {172.7, 1.9140}, {221.5, 1.8110},
     {221.0, 1.8120},  {453.3, 1.4010},  {546.5, 1.3440}, {535.7, 1.3500}, {535.7, 1.3500}, {453.3, 1.4010},
     {401.9, 1.4390},  {644.3, 1.2650},  {412.2, 1.3970}, {355.2, 1.4440}, {297.8, 1.7490}, {288.0, 1.7620},
     {492.4, 1.5640},  {325.3, 1.7150},  {311.1, 1.7320}, {311.1, 1.7320}, {327.8, 1.7120}, {248.7, 1.7650},
     {231.7, 1.7930},  {274.3, 1.7270},  {278.6, 1.7210}, {270.1, 1.7330}, {274.3, 1.7270}, {550.2, 1.3420},
     {461.1, 1.5870},  {486.8, 1.3790},  {602.9, 1.3150}, {414.9, 1.3950}, {433.5, 1.5600}, {439.8, 1.5550},
     {486.8, 1.3790},  {414.9, 1.3950},  {433.5, 1.5600}, {439.8, 1.5550}, {355.3, 1.4790}, {721.6, 1.2635},
     {736.4, 1.2280},  {493.9, 1.5630},  {327.8, 1.7120}, {336.6, 1.7020}, {425.4, 1.6157}, {463.5, 1.5370},
     {207.3, 1.8380},  {257.1, 1.7520},  {355.3, 1.4790}, {736.4, 1.2280}, {493.9, 1.5630}, {327.8, 1.7120},
     {336.6, 1.7020},  {425.4, 1.6157},  {463.5, 1.5370}, {207.3, 1.8380}, {257.1, 1.7520}, {453.3, 1.4010},
     {477.4, 1.3850},  {596.2, 1.2870},  {389.9, 1.4144}, {387.8, 1.4161}, {357.8, 1.6790}, {312.8, 1.7300},
     {333.1, 1.7060},  {365.6, 1.6710},  {237.0, 1.7840}, {259.1, 1.7490}, {297.2, 1.6965}, {288.3, 1.7080},
     {288.3, 1.7080},  {283.5, 1.7144},  {553.9, 1.3400}, {499.7, 1.3710}, {443.3, 1.4080}, {410.8, 1.4320},
     {469.7, 1.3900},  {486.8, 1.3790},  {524.9, 1.3561}, {517.7, 1.3603}, {451.2, 1.4025}, {381.2, 1.4560},
     {646.6, 1.2640},  {395.4, 1.4100},  {138.3, 1.8240}, {761.2, 1.2190}, {400.5, 1.4060}, {379.5, 1.4229},
     {379.5, 1.4229},  {306.3, 1.7380},  {234.7, 1.8440}, {220.4, 1.8700}, {240.5, 1.8340}, {263.8, 1.7420},
     {395.0, 1.4103},  {143.0, 1.9960},  {149.6, 1.9760}, {225.4, 1.8040}, {212.4, 1.8280}, {310.3, 1.7330},
     {282.2, 1.7700},  {309.5, 1.7340},  {331.3, 1.7080}, {304.8, 1.7400}, {304.8, 1.7400}, {247.5, 1.7670},
     {238.2, 1.7820},  {283.0, 1.7151},  {273.6, 1.7280}, {281.6, 1.7170}, {282.9, 1.7152}, {340.5, 1.4690},
     {355.8, 1.4547},  {316.8, 1.6300},  {278.8, 1.6770}, {307.4, 1.6410}, {321.2, 1.6250}, {332.1, 1.6130},
     {190.0, 1.8120},  {256.3, 1.6954},  {344.1, 1.5880}, {258.6, 1.6920}, {265.6, 1.6820}, {290.4, 1.6490},
     {384.3, 1.4300},  {294.6, 1.5170},  {306.3, 1.5040}, {449.7, 1.5080}, {440.4, 1.5150}, {456.4, 1.5030},
     {487.7, 1.4810},  {432.6, 1.5210},  {432.6, 1.5210}, {459.2, 1.5010}, {477.5, 1.4880}, {194.8, 1.8020},
     {333.6, 1.5990},  {448.7, 1.4970},  {541.1, 1.4360}, {328.0, 1.6050}, {343.6, 1.4660}, {371.9, 1.5730},
     {272.2, 1.6860},  {311.6, 1.6360},  {342.5, 1.6020}, {328.5, 1.6170}, {195.8, 1.8000}, {398.5, 1.5370},
     {253.9, 1.6990},  {355.0, 1.5770},  {273.6, 1.6710}, {250.5, 1.7040}, {253.9, 1.6990}, {434.2, 1.5080},
     {493.0, 1.4660},  {490.3, 1.7860},  {211.9, 2.1520}, {200.4, 2.1790}, {199.9, 2.1800}, {401.6, 1.8670},
     {401.6, 1.8670},  {361.6, 1.7720},  {139.4, 2.1900}, {142.3, 2.1800}, {224.0, 1.9710}, {226.6, 1.9660},
     {186.5, 2.2140},  {185.7, 2.2160},  {186.9, 2.2130}, {179.7, 2.0700}, {173.2, 2.0870}, {176.9, 2.0770},
     {157.3, 2.1320},  {161.0, 2.1210},  {273.1, 2.0340}, {178.0, 2.2370}, {152.7, 2.1460}, {123.2, 2.2510},
     {118.9, 2.2690},  {163.1, 2.1150},  {167.0, 2.1040}, {261.4, 2.0540}, {250.8, 1.9220}, {191.9, 2.0400},
     {191.9, 2.0400},  {175.0, 2.0820},  {163.1, 2.1149}, {240.7, 2.0920}, {260.8, 2.0550}, {291.4, 2.0050},
     {278.6, 2.0250},  {374.7, 1.7580},  {145.9, 2.1680}, {133.0, 2.2130}, {240.7, 2.0920}, {291.4, 2.0050},
     {278.6, 2.0250},  {374.7, 1.7580},  {145.9, 2.1680}, {133.0, 2.2130}, {192.3, 2.1990}, {125.4, 2.2420},
     {123.7, 2.2490},  {197.5, 2.1860},  {121.2, 2.2590}, {141.7, 2.1820}, {151.5, 2.0800}, {151.5, 2.0800},
     {125.7, 2.1680},  {126.2, 2.1660},  {151.5, 2.0800}, {142.6, 2.1080}, {139.6, 2.1180}, {158.9, 2.0580},
     {155.8, 2.0670},  {169.0, 2.0300},  {229.2, 1.8970}, {152.8, 2.0760}, {166.0, 2.0380}, {142.0, 2.1100},
     {148.5, 2.0890},  {161.7, 2.0500},  {80.9, 2.3910},  {105.3, 2.2550}, {106.4, 2.2500}}};

static constexpr std::array<std::array<const char*, 3>, 4071> anglesAtomTypes = {
    {{"hw", "ow", "hw"}, {"hw", "hw", "ow"}, {"br", "c1", "br"}, {"br", "c1", "c1"}, {"c1", "c1", "c1"},
     {"c1", "c1", "c2"}, {"c1", "c1", "c3"}, {"c1", "c1", "ca"}, {"c1", "c1", "cl"}, {"c1", "c1", "f"},
     {"c1", "c1", "ha"}, {"c1", "c1", "hc"}, {"c1", "c1", "i"},  {"c1", "c1", "n1"}, {"c1", "c1", "n2"},
     {"c1", "c1", "n3"}, {"c1", "c1", "n4"}, {"c1", "c1", "n"},  {"c1", "c1", "na"}, {"c1", "c1", "nh"},
     {"c1", "c1", "no"}, {"c1", "c1", "o"},  {"c1", "c1", "oh"}, {"c1", "c1", "os"}, {"c1", "c1", "p2"},
     {"c1", "c1", "p3"}, {"c1", "c1", "p4"}, {"c1", "c1", "p5"}, {"c1", "c1", "s4"}, {"c1", "c1", "s6"},
     {"c1", "c1", "s"},  {"c1", "c1", "sh"}, {"c1", "c1", "ss"}, {"c2", "c1", "c2"}, {"c2", "c1", "ce"},
     {"c2", "c1", "n1"}, {"c2", "c1", "o"},  {"c2", "c1", "s2"}, {"c3", "c1", "c3"}, {"c3", "c1", "cg"},
     {"c3", "c1", "n1"}, {"ca", "c1", "ca"}, {"c", "c1", "c1"},  {"cg", "c1", "ha"}, {"ch", "c1", "ha"},
     {"cl", "c1", "cl"}, {"f", "c1", "f"},   {"i", "c1", "i"},   {"n1", "c1", "n1"}, {"n1", "c1", "n3"},
     {"n1", "c1", "nh"}, {"n1", "c1", "os"}, {"n1", "c1", "p3"}, {"n1", "c1", "ss"}, {"n2", "c1", "n2"},
     {"n2", "c1", "o"},  {"n2", "c1", "s"},  {"n3", "c1", "n3"}, {"n4", "c1", "n4"}, {"na", "c1", "na"},
     {"ne", "c1", "o"},  {"ne", "c1", "s"},  {"nf", "c1", "o"},  {"nh", "c1", "nh"}, {"n", "c1", "n"},
     {"no", "c1", "no"}, {"oh", "c1", "oh"}, {"o", "c1", "o"},   {"os", "c1", "os"}, {"p2", "c1", "p2"},
     {"p3", "c1", "p3"}, {"p4", "c1", "p4"}, {"p5", "c1", "p5"}, {"s2", "c1", "s2"}, {"s4", "c1", "s4"},
     {"s6", "c1", "s6"}, {"sh", "c1", "sh"}, {"s", "c1", "s"},   {"ss", "c1", "ss"}, {"br", "c2", "br"},
     {"br", "c2", "c2"}, {"br", "c2", "c3"}, {"br", "c2", "ce"}, {"br", "c2", "h4"}, {"br", "c2", "ha"},
     {"c1", "c2", "c1"}, {"c1", "c2", "c2"}, {"c1", "c2", "c3"}, {"c1", "c2", "f"},  {"c1", "c2", "ha"},
     {"c2", "c2", "c2"}, {"c2", "c2", "c3"}, {"c2", "c2", "ca"}, {"c2", "c2", "cc"}, {"c2", "c2", "cd"},
     {"c2", "c2", "cl"}, {"c2", "c2", "cx"}, {"c2", "c2", "cy"}, {"c2", "c2", "f"},  {"c2", "c2", "h4"},
     {"c2", "c2", "ha"}, {"c2", "c2", "hc"}, {"c2", "c2", "hx"}, {"c2", "c2", "i"},  {"c2", "c2", "n1"},
     {"c2", "c2", "n2"}, {"c2", "c2", "n3"}, {"c2", "c2", "n4"}, {"c2", "c2", "n"},  {"c2", "c2", "na"},
     {"c2", "c2", "nh"}, {"c2", "c2", "no"}, {"c2", "c2", "o"},  {"c2", "c2", "oh"}, {"c2", "c2", "os"},
     {"c2", "c2", "p2"}, {"c2", "c2", "p3"}, {"c2", "c2", "p4"}, {"c2", "c2", "p5"}, {"c2", "c2", "s4"},
     {"c2", "c2", "s6"}, {"c2", "c2", "s"},  {"c2", "c2", "sh"}, {"c2", "c2", "ss"}, {"c3", "c2", "c3"},
     {"c3", "c2", "cc"}, {"c3", "c2", "cd"}, {"c3", "c2", "ce"}, {"c3", "c2", "cf"}, {"c3", "c2", "h4"},
     {"c3", "c2", "ha"}, {"c3", "c2", "hc"}, {"c3", "c2", "n2"}, {"c3", "c2", "n"},  {"c3", "c2", "na"},
     {"c3", "c2", "ne"}, {"c3", "c2", "nf"}, {"c3", "c2", "nh"}, {"c3", "c2", "o"},  {"c3", "c2", "oh"},
     {"c3", "c2", "os"}, {"c3", "c2", "p2"}, {"c3", "c2", "s"},  {"c3", "c2", "ss"}, {"ca", "c2", "ca"},
     {"ca", "c2", "hc"}, {"c", "c2", "c2"},  {"c", "c2", "c3"},  {"c", "c2", "c"},   {"cc", "c2", "h4"},
     {"cc", "c2", "ha"}, {"cc", "c2", "nh"}, {"cc", "c2", "o"},  {"cd", "c2", "ha"}, {"ce", "c2", "cl"},
     {"ce", "c2", "h4"}, {"ce", "c2", "ha"}, {"ce", "c2", "na"}, {"ce", "c2", "nh"}, {"ce", "c2", "no"},
     {"ce", "c2", "o"},  {"ce", "c2", "oh"}, {"ce", "c2", "os"}, {"cf", "c2", "ha"}, {"c", "c2", "ha"},
     {"c", "c2", "hc"},  {"cl", "c2", "cl"}, {"cl", "c2", "h4"}, {"cl", "c2", "ha"}, {"cx", "c2", "ha"},
     {"f", "c2", "f"},   {"f", "c2", "ha"},  {"h4", "c2", "n2"}, {"h4", "c2", "n"},  {"h4", "c2", "na"},
     {"h4", "c2", "ne"}, {"h4", "c2", "nh"}, {"h4", "c2", "no"}, {"h4", "c2", "os"}, {"h4", "c2", "ss"},
     {"h5", "c2", "n2"}, {"h5", "c2", "na"}, {"h5", "c2", "ne"}, {"h5", "c2", "nh"}, {"ha", "c2", "ha"},
     {"ha", "c2", "n1"}, {"ha", "c2", "n2"}, {"ha", "c2", "n3"}, {"ha", "c2", "n"},  {"ha", "c2", "na"},
     {"ha", "c2", "ne"}, {"ha", "c2", "nf"}, {"ha", "c2", "nh"}, {"ha", "c2", "no"}, {"ha", "c2", "o"},
     {"ha", "c2", "oh"}, {"ha", "c2", "os"}, {"ha", "c2", "p2"}, {"ha", "c2", "p3"}, {"ha", "c2", "p4"},
     {"ha", "c2", "p5"}, {"ha", "c2", "pe"}, {"ha", "c2", "pf"}, {"ha", "c2", "s2"}, {"ha", "c2", "s4"},
     {"ha", "c2", "s"},  {"ha", "c2", "s6"}, {"ha", "c2", "sh"}, {"ha", "c2", "ss"}, {"hc", "c2", "hc"},
     {"hc", "c2", "n2"}, {"hc", "c2", "n"},  {"hc", "c2", "na"}, {"hc", "c2", "nh"}, {"hc", "c2", "no"},
     {"hc", "c2", "oh"}, {"hc", "c2", "os"}, {"hc", "c2", "p3"}, {"hc", "c2", "p5"}, {"hc", "c2", "s4"},
     {"hc", "c2", "s6"}, {"hc", "c2", "sh"}, {"hc", "c2", "ss"}, {"hx", "c2", "n4"}, {"i", "c2", "i"},
     {"n1", "c2", "n1"}, {"n2", "c2", "n2"}, {"n2", "c2", "n4"}, {"n2", "c2", "na"}, {"n2", "c2", "nh"},
     {"n2", "c2", "oh"}, {"n2", "c2", "os"}, {"n2", "c2", "ss"}, {"n3", "c2", "n3"}, {"n4", "c2", "n4"},
     {"n4", "c2", "ss"}, {"na", "c2", "na"}, {"ne", "c2", "nh"}, {"ne", "c2", "os"}, {"ne", "c2", "ss"},
     {"nf", "c2", "nh"}, {"nh", "c2", "nh"}, {"nh", "c2", "oh"}, {"nh", "c2", "os"}, {"nh", "c2", "ss"},
     {"n", "c2", "n2"},  {"n", "c2", "n"},   {"n", "c2", "na"},  {"n", "c2", "ne"},  {"n", "c2", "nh"},
     {"no", "c2", "no"}, {"n", "c2", "ss"},  {"oh", "c2", "oh"}, {"o", "c2", "o"},   {"o", "c2", "oh"},
     {"o", "c2", "s"},   {"os", "c2", "os"}, {"p2", "c2", "p2"}, {"p3", "c2", "p3"}, {"p5", "c2", "p5"},
     {"s4", "c2", "s4"}, {"s4", "c2", "s6"}, {"s6", "c2", "s6"}, {"sh", "c2", "sh"}, {"sh", "c2", "ss"},
     {"s", "c2", "s"},   {"ss", "c2", "ss"}, {"br", "c3", "br"}, {"br", "c3", "c1"}, {"br", "c3", "c3"},
     {"br", "c3", "c"},  {"br", "c3", "h1"}, {"br", "c3", "h2"}, {"br", "c3", "hc"}, {"c1", "c3", "c1"},
     {"c1", "c3", "c2"}, {"c1", "c3", "c3"}, {"c1", "c3", "ca"}, {"c1", "c3", "cc"}, {"c1", "c3", "cd"},
     {"c1", "c3", "cl"}, {"c1", "c3", "h1"}, {"c1", "c3", "hc"}, {"c1", "c3", "hx"}, {"c1", "c3", "n3"},
     {"c1", "c3", "n4"}, {"c1", "c3", "n"},  {"c1", "c3", "nh"}, {"c1", "c3", "oh"}, {"c1", "c3", "os"},
     {"c2", "c3", "c2"}, {"c2", "c3", "c3"}, {"c2", "c3", "ca"}, {"c2", "c3", "cc"}, {"c2", "c3", "cd"},
     {"c2", "c3", "ce"}, {"c2", "c3", "cf"}, {"c2", "c3", "cl"}, {"c2", "c3", "cx"}, {"c2", "c3", "cy"},
     {"c2", "c3", "f"},  {"c2", "c3", "h1"}, {"c2", "c3", "h2"}, {"c2", "c3", "hc"}, {"c2", "c3", "hx"},
     {"c2", "c3", "n2"}, {"c2", "c3", "n3"}, {"c2", "c3", "n"},  {"c2", "c3", "na"}, {"c2", "c3", "nh"},
     {"c2", "c3", "oh"}, {"c2", "c3", "os"}, {"c2", "c3", "s4"}, {"c2", "c3", "ss"}, {"c3", "c3", "c3"},
     {"c3", "c3", "ca"}, {"c3", "c3", "cc"}, {"c3", "c3", "cd"}, {"c3", "c3", "ce"}, {"c3", "c3", "cf"},
     {"c3", "c3", "cl"}, {"c3", "c3", "cx"}, {"c3", "c3", "cy"}, {"c3", "c3", "f"},  {"c3", "c3", "h1"},
     {"c3", "c3", "h2"}, {"c3", "c3", "hc"}, {"c3", "c3", "hx"}, {"c3", "c3", "i"},  {"c3", "c3", "n1"},
     {"c3", "c3", "n2"}, {"c3", "c3", "n3"}, {"c3", "c3", "n4"}, {"c3", "c3", "n"},  {"c3", "c3", "na"},
     {"c3", "c3", "nh"}, {"c3", "c3", "no"}, {"c3", "c3", "o"},  {"c3", "c3", "oh"}, {"c3", "c3", "os"},
     {"c3", "c3", "p3"}, {"c3", "c3", "p5"}, {"c3", "c3", "s4"}, {"c3", "c3", "s6"}, {"c3", "c3", "sh"},
     {"c3", "c3", "ss"}, {"c3", "c3", "sy"}, {"ca", "c3", "ca"}, {"ca", "c3", "cc"}, {"ca", "c3", "cd"},
     {"ca", "c3", "ce"}, {"ca", "c3", "cl"}, {"ca", "c3", "cx"}, {"ca", "c3", "f"},  {"ca", "c3", "h1"},
     {"ca", "c3", "h2"}, {"ca", "c3", "hc"}, {"ca", "c3", "hx"}, {"ca", "c3", "n2"}, {"ca", "c3", "n3"},
     {"ca", "c3", "n4"}, {"ca", "c3", "n"},  {"ca", "c3", "na"}, {"ca", "c3", "nc"}, {"ca", "c3", "nd"},
     {"ca", "c3", "nh"}, {"ca", "c3", "oh"}, {"ca", "c3", "os"}, {"ca", "c3", "p5"}, {"ca", "c3", "s6"},
     {"ca", "c3", "ss"}, {"ca", "c3", "sx"}, {"c", "c3", "c1"},  {"c", "c3", "c2"},  {"c", "c3", "c3"},
     {"c", "c3", "c"},   {"c", "c3", "ca"},  {"c", "c3", "cc"},  {"cc", "c3", "cc"}, {"cc", "c3", "cd"},
     {"cc", "c3", "cx"}, {"c", "c3", "cd"},  {"c", "c3", "ce"},  {"cc", "c3", "f"},  {"cc", "c3", "h1"},
     {"cc", "c3", "hc"}, {"cc", "c3", "hx"}, {"c", "c3", "cl"},  {"cc", "c3", "n2"}, {"cc", "c3", "n3"},
     {"cc", "c3", "n4"}, {"cc", "c3", "n"},  {"cc", "c3", "na"}, {"cc", "c3", "nc"}, {"cc", "c3", "nh"},
     {"cc", "c3", "oh"}, {"cc", "c3", "os"}, {"cc", "c3", "p5"}, {"cc", "c3", "sh"}, {"cc", "c3", "ss"},
     {"c", "c3", "cx"},  {"cd", "c3", "cd"}, {"cd", "c3", "f"},  {"cd", "c3", "h1"}, {"cd", "c3", "hc"},
     {"cd", "c3", "n3"}, {"cd", "c3", "n"},  {"cd", "c3", "nd"}, {"cd", "c3", "nh"}, {"cd", "c3", "oh"},
     {"cd", "c3", "os"}, {"cd", "c3", "sh"}, {"cd", "c3", "ss"}, {"ce", "c3", "ce"}, {"ce", "c3", "cy"},
     {"ce", "c3", "h1"}, {"ce", "c3", "hc"}, {"ce", "c3", "n3"}, {"ce", "c3", "n"},  {"ce", "c3", "oh"},
     {"ce", "c3", "os"}, {"ce", "c3", "ss"}, {"c", "c3", "f"},   {"cf", "c3", "cy"}, {"cf", "c3", "h1"},
     {"cf", "c3", "hc"}, {"cf", "c3", "n3"}, {"c", "c3", "h1"},  {"c", "c3", "h2"},  {"c", "c3", "hc"},
     {"c", "c3", "hx"},  {"cl", "c3", "cl"}, {"cl", "c3", "f"},  {"cl", "c3", "h1"}, {"cl", "c3", "h2"},
     {"cl", "c3", "hc"}, {"cl", "c3", "os"}, {"cl", "c3", "ss"}, {"c", "c3", "n2"},  {"c", "c3", "n3"},
     {"c", "c3", "n4"},  {"c", "c3", "n"},   {"c", "c3", "na"},  {"c", "c3", "nh"},  {"c", "c3", "oh"},
     {"c", "c3", "os"},  {"c", "c3", "p5"},  {"c", "c3", "s6"},  {"c", "c3", "sh"},  {"c", "c3", "ss"},
     {"cx", "c3", "cx"}, {"cx", "c3", "h1"}, {"cx", "c3", "hc"}, {"cx", "c3", "hx"}, {"cx", "c3", "n3"},
     {"cx", "c3", "n4"}, {"cx", "c3", "n"},  {"cx", "c3", "oh"}, {"cx", "c3", "os"}, {"cy", "c3", "h1"},
     {"cy", "c3", "hc"}, {"cy", "c3", "n3"}, {"cy", "c3", "oh"}, {"cy", "c3", "os"}, {"f", "c3", "f"},
     {"f", "c3", "h1"},  {"f", "c3", "h2"},  {"f", "c3", "h3"},  {"f", "c3", "hc"},  {"f", "c3", "n2"},
     {"f", "c3", "os"},  {"f", "c3", "p5"},  {"f", "c3", "s6"},  {"f", "c3", "ss"},  {"h1", "c3", "h1"},
     {"h1", "c3", "n1"}, {"h1", "c3", "n2"}, {"h1", "c3", "n3"}, {"h1", "c3", "n"},  {"h1", "c3", "na"},
     {"h1", "c3", "nc"}, {"h1", "c3", "nd"}, {"h1", "c3", "nh"}, {"h1", "c3", "no"}, {"h1", "c3", "o"},
     {"h1", "c3", "oh"}, {"h1", "c3", "os"}, {"h1", "c3", "p5"}, {"h1", "c3", "s4"}, {"h1", "c3", "s"},
     {"h1", "c3", "s6"}, {"h1", "c3", "sh"}, {"h1", "c3", "ss"}, {"h1", "c3", "sx"}, {"h1", "c3", "sy"},
     {"h2", "c3", "h2"}, {"h2", "c3", "i"},  {"h2", "c3", "n2"}, {"h2", "c3", "n3"}, {"h2", "c3", "n"},
     {"h2", "c3", "na"}, {"h2", "c3", "nc"}, {"h2", "c3", "nd"}, {"h2", "c3", "nh"}, {"h2", "c3", "no"},
     {"h2", "c3", "o"},  {"h2", "c3", "oh"}, {"h2", "c3", "os"}, {"h2", "c3", "s4"}, {"h2", "c3", "s"},
     {"h2", "c3", "s6"}, {"h2", "c3", "sh"}, {"h2", "c3", "ss"}, {"h3", "c3", "n3"}, {"h3", "c3", "nc"},
     {"h3", "c3", "nd"}, {"h3", "c3", "nh"}, {"h3", "c3", "os"}, {"h3", "c3", "ss"}, {"hc", "c3", "hc"},
     {"hc", "c3", "i"},  {"hc", "c3", "n2"}, {"hc", "c3", "n3"}, {"hc", "c3", "n4"}, {"hc", "c3", "n"},
     {"hc", "c3", "na"}, {"hc", "c3", "nh"}, {"hc", "c3", "no"}, {"hc", "c3", "oh"}, {"hc", "c3", "os"},
     {"hc", "c3", "p2"}, {"hc", "c3", "p3"}, {"hc", "c3", "p4"}, {"hc", "c3", "p5"}, {"hc", "c3", "px"},
     {"hc", "c3", "py"}, {"hc", "c3", "s4"}, {"hc", "c3", "s6"}, {"hc", "c3", "sh"}, {"hc", "c3", "ss"},
     {"hx", "c3", "hx"}, {"hx", "c3", "n4"}, {"i", "c3", "i"},   {"n1", "c3", "n1"}, {"n2", "c3", "n2"},
     {"n2", "c3", "nh"}, {"n2", "c3", "oh"}, {"n2", "c3", "os"}, {"n3", "c3", "n3"}, {"n3", "c3", "nc"},
     {"n3", "c3", "nd"}, {"n3", "c3", "nh"}, {"n3", "c3", "oh"}, {"n3", "c3", "os"}, {"n3", "c3", "p5"},
     {"n3", "c3", "ss"}, {"n4", "c3", "n4"}, {"na", "c3", "na"}, {"na", "c3", "os"}, {"nc", "c3", "nc"},
     {"nc", "c3", "nh"}, {"nc", "c3", "os"}, {"nd", "c3", "nd"}, {"nd", "c3", "nh"}, {"nd", "c3", "os"},
     {"nh", "c3", "nh"}, {"nh", "c3", "oh"}, {"nh", "c3", "os"}, {"nh", "c3", "p5"}, {"nh", "c3", "ss"},
     {"n", "c3", "n2"},  {"n", "c3", "n3"},  {"n", "c3", "n"},   {"n", "c3", "nh"},  {"n", "c3", "oh"},
     {"no", "c3", "no"}, {"n", "c3", "os"},  {"n", "c3", "p5"},  {"oh", "c3", "oh"}, {"oh", "c3", "os"},
     {"oh", "c3", "p5"}, {"oh", "c3", "sh"}, {"o", "c3", "o"},   {"os", "c3", "os"}, {"os", "c3", "p5"},
     {"os", "c3", "ss"}, {"p2", "c3", "p2"}, {"p3", "c3", "p3"}, {"p5", "c3", "p5"}, {"p5", "c3", "ss"},
     {"s4", "c3", "s4"}, {"s4", "c3", "s6"}, {"s6", "c3", "s6"}, {"sh", "c3", "sh"}, {"sh", "c3", "ss"},
     {"s", "c3", "s"},   {"ss", "c3", "ss"}, {"br", "ca", "br"}, {"br", "ca", "ca"}, {"c1", "ca", "c1"},
     {"c1", "ca", "ca"}, {"c2", "ca", "c2"}, {"c2", "ca", "ca"}, {"c3", "ca", "c2"}, {"c3", "ca", "c3"},
     {"c3", "ca", "ca"}, {"c3", "ca", "cp"}, {"c3", "ca", "cq"}, {"c3", "ca", "na"}, {"c3", "ca", "nb"},
     {"ca", "ca", "ca"}, {"ca", "ca", "cc"}, {"ca", "ca", "cd"}, {"ca", "ca", "ce"}, {"ca", "ca", "cf"},
     {"ca", "ca", "cg"}, {"ca", "ca", "ch"}, {"ca", "ca", "cl"}, {"ca", "ca", "cp"}, {"ca", "ca", "cq"},
     {"ca", "ca", "cx"}, {"ca", "ca", "cy"}, {"ca", "ca", "f"},  {"ca", "ca", "h4"}, {"ca", "ca", "ha"},
     {"ca", "ca", "i"},  {"ca", "ca", "n1"}, {"ca", "ca", "n2"}, {"ca", "ca", "n4"}, {"ca", "ca", "n"},
     {"ca", "ca", "na"}, {"ca", "ca", "nb"}, {"ca", "ca", "nc"}, {"ca", "ca", "nd"}, {"ca", "ca", "ne"},
     {"ca", "ca", "nf"}, {"ca", "ca", "nh"}, {"ca", "ca", "no"}, {"ca", "ca", "o"},  {"ca", "ca", "oh"},
     {"ca", "ca", "os"}, {"ca", "ca", "p2"}, {"ca", "ca", "p3"}, {"ca", "ca", "p4"}, {"ca", "ca", "p5"},
     {"ca", "ca", "pe"}, {"ca", "ca", "pf"}, {"ca", "ca", "px"}, {"ca", "ca", "py"}, {"ca", "ca", "s4"},
     {"ca", "ca", "s6"}, {"ca", "ca", "s"},  {"ca", "ca", "sh"}, {"ca", "ca", "ss"}, {"ca", "ca", "sx"},
     {"ca", "ca", "sy"}, {"c", "ca", "c3"},  {"c", "ca", "c"},   {"c", "ca", "ca"},  {"cc", "ca", "cp"},
     {"cc", "ca", "nb"}, {"cd", "ca", "nb"}, {"ce", "ca", "na"}, {"ce", "ca", "nb"}, {"cf", "ca", "nb"},
     {"cg", "ca", "cp"}, {"c", "ca", "ha"},  {"cl", "ca", "cl"}, {"cl", "ca", "cp"}, {"cl", "ca", "nb"},
     {"c", "ca", "nb"},  {"c", "ca", "nc"},  {"c", "ca", "nd"},  {"cp", "ca", "f"},  {"cp", "ca", "h4"},
     {"cp", "ca", "ha"}, {"cp", "ca", "na"}, {"cp", "ca", "nb"}, {"cp", "ca", "nh"}, {"cp", "ca", "oh"},
     {"cp", "ca", "ss"}, {"cp", "ca", "sy"}, {"cq", "ca", "ha"}, {"cq", "ca", "sy"}, {"f", "ca", "f"},
     {"f", "ca", "nb"},  {"h4", "ca", "n"},  {"h4", "ca", "na"}, {"h4", "ca", "nb"}, {"h4", "ca", "nc"},
     {"h4", "ca", "nd"}, {"h4", "ca", "os"}, {"h4", "ca", "ss"}, {"h5", "ca", "nb"}, {"h5", "ca", "nc"},
     {"h5", "ca", "nd"}, {"ha", "ca", "n2"}, {"ha", "ca", "p2"}, {"i", "ca", "i"},   {"n1", "ca", "n1"},
     {"n2", "ca", "n2"}, {"n2", "ca", "na"}, {"n4", "ca", "n4"}, {"na", "ca", "na"}, {"na", "ca", "nb"},
     {"na", "ca", "nh"}, {"nb", "ca", "nb"}, {"nb", "ca", "nc"}, {"nb", "ca", "nd"}, {"nb", "ca", "nh"},
     {"nb", "ca", "oh"}, {"nb", "ca", "os"}, {"nb", "ca", "sh"}, {"nb", "ca", "ss"}, {"nc", "ca", "nc"},
     {"nc", "ca", "nh"}, {"nd", "ca", "nd"}, {"nd", "ca", "nh"}, {"nh", "ca", "nh"}, {"n", "ca", "nc"},
     {"n", "ca", "nd"},  {"n", "ca", "nh"},  {"no", "ca", "no"}, {"oh", "ca", "oh"}, {"o", "ca", "o"},
     {"os", "ca", "os"}, {"p2", "ca", "p2"}, {"p3", "ca", "p3"}, {"p5", "ca", "p5"}, {"s4", "ca", "s4"},
     {"s6", "ca", "s6"}, {"sh", "ca", "sh"}, {"s", "ca", "s"},   {"ss", "ca", "ss"}, {"br", "c", "br"},
     {"br", "c", "c3"},  {"br", "c", "o"},   {"c1", "c", "c1"},  {"c1", "c", "o"},   {"c2", "c", "c2"},
     {"c2", "c", "ha"},  {"c2", "c", "o"},   {"c2", "c", "s"},   {"c3", "c", "c3"},  {"c3", "c", "ca"},
     {"c3", "c", "cc"},  {"c3", "c", "cd"},  {"c3", "c", "ce"},  {"c3", "c", "cf"},  {"c3", "c", "cg"},
     {"c3", "c", "ch"},  {"c3", "c", "cl"},  {"c3", "c", "f"},   {"c3", "c", "h4"},  {"c3", "c", "ha"},
     {"c3", "c", "i"},   {"c3", "c", "n2"},  {"c3", "c", "n4"},  {"c3", "c", "n"},   {"c3", "c", "ne"},
     {"c3", "c", "nf"},  {"c3", "c", "o"},   {"c3", "c", "oh"},  {"c3", "c", "os"},  {"c3", "c", "p3"},
     {"c3", "c", "p5"},  {"c3", "c", "pe"},  {"c3", "c", "pf"},  {"c3", "c", "px"},  {"c3", "c", "py"},
     {"c3", "c", "s4"},  {"c3", "c", "s6"},  {"c3", "c", "s"},   {"c3", "c", "sh"},  {"c3", "c", "ss"},
     {"c3", "c", "sx"},  {"c3", "c", "sy"},  {"ca", "c", "ca"},  {"ca", "c", "cc"},  {"ca", "c", "cd"},
     {"ca", "c", "ce"},  {"ca", "c", "cf"},  {"ca", "c", "h4"},  {"ca", "c", "ha"},  {"ca", "c", "n"},
     {"ca", "c", "ne"},  {"ca", "c", "o"},   {"ca", "c", "oh"},  {"ca", "c", "os"},  {"ca", "c", "s"},
     {"ca", "c", "sh"},  {"ca", "c", "ss"},  {"br", "cc", "c"},  {"br", "cc", "cc"}, {"br", "cc", "cd"},
     {"br", "cc", "na"}, {"c2", "cc", "c3"}, {"c2", "cc", "ca"}, {"c2", "cc", "cc"}, {"c2", "cc", "cd"},
     {"c2", "cc", "ha"}, {"c2", "cc", "n"},  {"c2", "cc", "os"}, {"c", "c", "c3"},   {"c3", "cc", "ca"},
     {"c3", "cc", "cc"}, {"c3", "cc", "cd"}, {"c3", "cc", "cf"}, {"c3", "cc", "ha"}, {"c3", "cc", "n2"},
     {"c3", "cc", "n"},  {"c3", "cc", "na"}, {"c3", "cc", "nc"}, {"c3", "cc", "nd"}, {"c3", "cc", "os"},
     {"c3", "cc", "ss"}, {"c", "c", "c"},    {"c", "c", "ca"},   {"ca", "cc", "cc"}, {"ca", "cc", "cd"},
     {"ca", "cc", "ce"}, {"ca", "cc", "h4"}, {"ca", "cc", "ha"}, {"ca", "cc", "n"},  {"ca", "cc", "nc"},
     {"ca", "cc", "nd"}, {"ca", "cc", "nh"}, {"ca", "cc", "oh"}, {"ca", "cc", "os"}, {"ca", "cc", "ss"},
     {"c", "cc", "c2"},  {"c", "cc", "c3"},  {"c", "cc", "c"},   {"c", "c", "cc"},   {"c", "cc", "ca"},
     {"c", "cc", "cc"},  {"cc", "c", "cc"},  {"cc", "cc", "cc"}, {"cc", "cc", "cd"}, {"cc", "cc", "ce"},
     {"cc", "cc", "cf"}, {"cc", "cc", "cg"}, {"c", "cc", "cd"},  {"cc", "c", "cd"},  {"c", "cc", "ce"},
     {"cc", "c", "ce"},  {"cc", "cc", "f"},  {"c", "cc", "cg"},  {"cc", "cc", "h4"}, {"cc", "cc", "ha"},
     {"c", "cc", "cl"},  {"cc", "cc", "n2"}, {"cc", "cc", "n"},  {"cc", "cc", "na"}, {"cc", "cc", "nc"},
     {"cc", "cc", "nd"}, {"cc", "cc", "nh"}, {"cc", "cc", "oh"}, {"cc", "cc", "os"}, {"cc", "cc", "pd"},
     {"cc", "cc", "ss"}, {"cc", "cc", "sy"}, {"c", "c", "cd"},   {"cd", "cc", "cd"}, {"cd", "cc", "ce"},
     {"cd", "cc", "cl"}, {"cd", "cc", "f"},  {"cd", "cc", "h4"}, {"cd", "cc", "ha"}, {"cd", "cc", "n"},
     {"cd", "cc", "na"}, {"cd", "cc", "nc"}, {"cd", "cc", "nh"}, {"cd", "cc", "no"}, {"cd", "cc", "oh"},
     {"cd", "cc", "os"}, {"cd", "cc", "ss"}, {"cd", "cc", "sy"}, {"ce", "cc", "na"}, {"ce", "cc", "nc"},
     {"ce", "cc", "nd"}, {"ce", "cc", "os"}, {"ce", "cc", "ss"}, {"c", "cc", "f"},   {"cg", "cc", "na"},
     {"cg", "cc", "ss"}, {"cc", "c", "h4"},  {"c", "cc", "ha"},  {"cl", "cc", "na"}, {"cl", "cc", "nd"},
     {"cl", "cc", "ss"}, {"c", "cc", "n2"},  {"c", "cc", "n"},   {"cc", "c", "n"},   {"c", "cc", "nc"},
     {"cc", "c", "nd"},  {"c", "cc", "nd"},  {"c", "cc", "ne"},  {"cc", "c", "o"},   {"c", "cc", "oh"},
     {"cc", "c", "oh"},  {"c", "cc", "os"},  {"cc", "c", "os"},  {"cc", "c", "s"},   {"cc", "c", "ss"},
     {"cx", "cc", "nd"}, {"cx", "cc", "os"}, {"cd", "c", "cd"},  {"cd", "c", "cx"},  {"cd", "c", "n"},
     {"cd", "c", "nc"},  {"cd", "c", "nd"},  {"cd", "c", "o"},   {"cd", "c", "oh"},  {"cd", "c", "os"},
     {"ce", "c", "ce"},  {"ce", "c", "cf"},  {"ce", "c", "cx"},  {"ce", "c", "h4"},  {"ce", "c", "ha"},
     {"ce", "c", "n"},   {"ce", "c", "o"},   {"ce", "c", "oh"},  {"ce", "c", "os"},  {"ce", "c", "s"},
     {"ce", "c", "ss"},  {"cf", "c", "cf"},  {"cf", "c", "ha"},  {"cf", "c", "n"},   {"cf", "c", "o"},
     {"cf", "c", "oh"},  {"cf", "c", "os"},  {"cf", "c", "s"},   {"cg", "c", "cg"},  {"cg", "c", "ha"},
     {"cg", "c", "o"},   {"c", "c", "h4"},   {"h4", "cc", "n"},  {"h4", "cc", "na"}, {"h4", "cc", "nc"},
     {"h4", "cc", "nd"}, {"h4", "cc", "os"}, {"h4", "cc", "ss"}, {"h5", "cc", "n"},  {"h5", "cc", "na"},
     {"h5", "cc", "nc"}, {"h5", "cc", "nd"}, {"h5", "cc", "os"}, {"h5", "cc", "ss"}, {"c", "c", "ha"},
     {"ha", "cc", "na"}, {"ha", "cc", "nc"}, {"ha", "cc", "nd"}, {"ha", "cc", "os"}, {"ha", "cc", "pd"},
     {"ha", "cc", "ss"}, {"ch", "c", "ch"},  {"ch", "c", "ha"},  {"ch", "c", "o"},   {"cl", "c", "cl"},
     {"cl", "c", "f"},   {"cl", "c", "ha"},  {"cl", "c", "o"},   {"cl", "c", "s"},   {"c", "c", "n"},
     {"na", "cc", "nc"}, {"na", "cc", "nd"}, {"na", "cc", "no"}, {"na", "cc", "oh"}, {"na", "cc", "sx"},
     {"na", "cc", "sy"}, {"n", "cc", "c"},   {"nc", "cc", "nd"}, {"nc", "cc", "nh"}, {"nc", "cc", "no"},
     {"nc", "cc", "ss"}, {"nd", "cc", "nd"}, {"nd", "cc", "ne"}, {"nd", "cc", "nh"}, {"nd", "cc", "no"},
     {"nd", "cc", "oh"}, {"nd", "cc", "os"}, {"nd", "cc", "sh"}, {"nd", "cc", "ss"}, {"nd", "cc", "sx"},
     {"nd", "cc", "sy"}, {"ne", "cc", "ss"}, {"nh", "cc", "nh"}, {"nh", "cc", "os"}, {"nh", "cc", "ss"},
     {"n", "cc", "n2"},  {"n", "cc", "na"},  {"n", "cc", "nc"},  {"n", "cc", "nd"},  {"n", "cc", "nh"},
     {"no", "cc", "os"}, {"no", "cc", "ss"}, {"n", "cc", "ss"},  {"c", "c", "o"},    {"c", "c", "oh"},
     {"c", "c", "os"},   {"os", "cc", "ss"}, {"ss", "cc", "ss"}, {"ss", "cc", "sy"}, {"cx", "c", "cx"},
     {"cx", "c", "n"},   {"cx", "c", "o"},   {"cx", "c", "oh"},  {"cx", "c", "os"},  {"cy", "c", "cy"},
     {"cy", "c", "n"},   {"cy", "c", "o"},   {"cy", "c", "oh"},  {"cy", "c", "os"},  {"c2", "cd", "c3"},
     {"c2", "cd", "ca"}, {"c2", "cd", "cc"}, {"c2", "cd", "cd"}, {"c2", "cd", "ha"}, {"c2", "cd", "n"},
     {"c2", "cd", "os"}, {"c3", "cd", "ca"}, {"c3", "cd", "cc"}, {"c3", "cd", "cd"}, {"c3", "cd", "ce"},
     {"c3", "cd", "ha"}, {"c3", "cd", "n2"}, {"c3", "cd", "n"},  {"c3", "cd", "na"}, {"c3", "cd", "nc"},
     {"c3", "cd", "nd"}, {"c3", "cd", "os"}, {"c3", "cd", "ss"}, {"ca", "cd", "cc"}, {"ca", "cd", "cd"},
     {"ca", "cd", "ce"}, {"ca", "cd", "h4"}, {"ca", "cd", "ha"}, {"ca", "cd", "n"},  {"ca", "cd", "na"},
     {"ca", "cd", "nc"}, {"ca", "cd", "nd"}, {"ca", "cd", "oh"}, {"ca", "cd", "os"}, {"ca", "cd", "ss"},
     {"c", "cd", "c2"},  {"c", "cd", "c3"},  {"c", "cd", "c"},   {"c", "cd", "ca"},  {"c", "cd", "cc"},
     {"cc", "cd", "cc"}, {"cc", "cd", "cd"}, {"cc", "cd", "cf"}, {"cc", "cd", "ch"}, {"cc", "cd", "cl"},
     {"cc", "cd", "cy"}, {"c", "cd", "cd"},  {"c", "cd", "cf"},  {"cc", "cd", "h4"}, {"cc", "cd", "ha"},
     {"c", "cd", "cl"},  {"cc", "cd", "n"},  {"cc", "cd", "na"}, {"cc", "cd", "nc"}, {"cc", "cd", "nd"},
     {"cc", "cd", "nh"}, {"cc", "cd", "oh"}, {"cc", "cd", "os"}, {"cc", "cd", "ss"}, {"cc", "cd", "sy"},
     {"cd", "cd", "cd"}, {"cd", "cd", "ce"}, {"cd", "cd", "cf"}, {"cd", "cd", "ch"}, {"cd", "cd", "cy"},
     {"cd", "cd", "h4"}, {"cd", "cd", "ha"}, {"cd", "cd", "n2"}, {"cd", "cd", "n"},  {"cd", "cd", "na"},
     {"cd", "cd", "nc"}, {"cd", "cd", "nd"}, {"cd", "cd", "nh"}, {"cd", "cd", "oh"}, {"cd", "cd", "os"},
     {"cd", "cd", "pc"}, {"cd", "cd", "ss"}, {"ce", "cd", "nd"}, {"cf", "cd", "na"}, {"cf", "cd", "nc"},
     {"cf", "cd", "nd"}, {"cf", "cd", "os"}, {"cf", "cd", "ss"}, {"c", "cd", "h4"},  {"c", "cd", "ha"},
     {"cl", "cd", "nc"}, {"c", "cd", "n2"},  {"c", "cd", "n"},   {"c", "cd", "nc"},  {"c", "cd", "nd"},
     {"c", "cd", "oh"},  {"c", "cd", "os"},  {"h4", "cd", "n"},  {"h4", "cd", "na"}, {"h4", "cd", "nc"},
     {"h4", "cd", "nd"}, {"h4", "cd", "os"}, {"h4", "cd", "ss"}, {"h5", "cd", "n"},  {"h5", "cd", "na"},
     {"h5", "cd", "nc"}, {"h5", "cd", "nd"}, {"h5", "cd", "os"}, {"h5", "cd", "ss"}, {"ha", "cd", "na"},
     {"ha", "cd", "nc"}, {"ha", "cd", "nd"}, {"ha", "cd", "os"}, {"ha", "cd", "pc"}, {"ha", "cd", "ss"},
     {"na", "cd", "nc"}, {"na", "cd", "nd"}, {"na", "cd", "nh"}, {"na", "cd", "ss"}, {"nc", "cd", "nd"},
     {"nc", "cd", "nh"}, {"nc", "cd", "oh"}, {"nc", "cd", "os"}, {"nc", "cd", "ss"}, {"nd", "cd", "nd"},
     {"nd", "cd", "nh"}, {"nd", "cd", "ss"}, {"nh", "cd", "nh"}, {"nh", "cd", "os"}, {"nh", "cd", "ss"},
     {"n", "cd", "na"},  {"n", "cd", "nc"},  {"n", "cd", "nd"},  {"n", "cd", "nh"},  {"n", "cd", "ss"},
     {"oh", "cd", "os"}, {"os", "cd", "ss"}, {"ss", "cd", "ss"}, {"ss", "cd", "sy"}, {"c2", "ce", "c3"},
     {"c2", "ce", "ca"}, {"c2", "ce", "cc"}, {"c2", "ce", "ce"}, {"c2", "ce", "cg"}, {"c2", "ce", "cl"},
     {"c2", "ce", "h4"}, {"c2", "ce", "ha"}, {"c2", "ce", "n1"}, {"c2", "ce", "n2"}, {"c2", "ce", "na"},
     {"c2", "ce", "ne"}, {"c2", "ce", "oh"}, {"c2", "ce", "p2"}, {"c2", "ce", "pe"}, {"c2", "ce", "px"},
     {"c2", "ce", "py"}, {"c2", "ce", "sx"}, {"c2", "ce", "sy"}, {"c3", "ce", "ca"}, {"c3", "ce", "cc"},
     {"c3", "ce", "ce"}, {"c3", "ce", "cf"}, {"c3", "ce", "cg"}, {"c3", "ce", "n2"}, {"c3", "ce", "nf"},
     {"c3", "ce", "nh"}, {"ca", "ce", "ca"}, {"ca", "ce", "cc"}, {"ca", "ce", "ce"}, {"ca", "ce", "cf"},
     {"ca", "ce", "cl"}, {"ca", "ce", "h4"}, {"ca", "ce", "ha"}, {"ca", "ce", "n2"}, {"ca", "ce", "nf"},
     {"ca", "ce", "nh"}, {"ca", "ce", "oh"}, {"ca", "ce", "os"}, {"ca", "ce", "ss"}, {"c", "ce", "c2"},
     {"c", "ce", "c3"},  {"c", "ce", "c"},   {"c", "ce", "ca"},  {"cc", "ce", "cd"}, {"cc", "ce", "cf"},
     {"c", "ce", "cd"},  {"c", "ce", "ce"},  {"c", "ce", "cf"},  {"c", "ce", "cg"},  {"cc", "ce", "h4"},
     {"cc", "ce", "ha"}, {"c", "ce", "cl"},  {"cc", "ce", "n2"}, {"cc", "ce", "nh"}, {"c", "ce", "cy"},
     {"cd", "ce", "ce"}, {"cd", "ce", "ha"}, {"ce", "ce", "ce"}, {"ce", "ce", "cf"}, {"ce", "ce", "cl"},
     {"ce", "ce", "h4"}, {"ce", "ce", "ha"}, {"ce", "ce", "n1"}, {"ce", "ce", "n2"}, {"ce", "ce", "oh"},
     {"cf", "ce", "cg"}, {"cf", "ce", "cy"}, {"cf", "ce", "h4"}, {"cf", "ce", "ha"}, {"cf", "ce", "n1"},
     {"cf", "ce", "n"},  {"cf", "ce", "nh"}, {"cf", "ce", "oh"}, {"cg", "ce", "cg"}, {"cg", "ce", "ha"},
     {"cg", "ce", "n1"}, {"cg", "ce", "n2"}, {"c", "ce", "ha"},  {"c", "ce", "n"},   {"c", "ce", "nh"},
     {"c", "ce", "oh"},  {"c", "ce", "os"},  {"h4", "ce", "n1"}, {"h4", "ce", "n2"}, {"h4", "ce", "ne"},
     {"ha", "ce", "n1"}, {"ha", "ce", "n2"}, {"ha", "ce", "ne"}, {"ha", "ce", "nh"}, {"ha", "ce", "p2"},
     {"ha", "ce", "pe"}, {"ha", "ce", "px"}, {"ha", "ce", "py"}, {"ha", "ce", "sx"}, {"ha", "ce", "sy"},
     {"n2", "ce", "nh"}, {"n2", "ce", "os"}, {"n2", "ce", "ss"}, {"ne", "ce", "ne"}, {"ne", "ce", "nh"},
     {"nf", "ce", "nh"}, {"pe", "ce", "pe"}, {"py", "ce", "py"}, {"sx", "ce", "sx"}, {"sy", "ce", "sy"},
     {"c2", "cf", "c3"}, {"c2", "cf", "ca"}, {"c2", "cf", "cd"}, {"c2", "cf", "cf"}, {"c2", "cf", "ch"},
     {"c2", "cf", "ha"}, {"c2", "cf", "n2"}, {"c2", "cf", "nf"}, {"c2", "cf", "p2"}, {"c2", "cf", "pf"},
     {"c2", "cf", "px"}, {"c2", "cf", "py"}, {"c2", "cf", "sx"}, {"c2", "cf", "sy"}, {"c3", "cf", "ca"},
     {"c3", "cf", "cd"}, {"c3", "cf", "ce"}, {"c3", "cf", "cf"}, {"c3", "cf", "n2"}, {"ca", "cf", "ca"},
     {"ca", "cf", "cc"}, {"ca", "cf", "cd"}, {"ca", "cf", "ce"}, {"ca", "cf", "ha"}, {"ca", "cf", "n2"},
     {"ca", "cf", "ne"}, {"ca", "cf", "oh"}, {"c", "cf", "c2"},  {"c", "cf", "c3"},  {"c", "cf", "c"},
     {"c", "cf", "cc"},  {"cc", "cf", "cf"}, {"c", "cf", "cd"},  {"c", "cf", "ce"},  {"cc", "cf", "ha"},
     {"cd", "cf", "ce"}, {"cd", "cf", "ha"}, {"cd", "cf", "n2"}, {"ce", "cf", "cf"}, {"ce", "cf", "ch"},
     {"ce", "cf", "ha"}, {"ce", "cf", "n"},  {"ce", "cf", "oh"}, {"cf", "cf", "cf"}, {"cf", "cf", "h4"},
     {"cf", "cf", "ha"}, {"cf", "cf", "n1"}, {"cf", "cf", "n2"}, {"c", "cf", "ha"},  {"ch", "cf", "ch"},
     {"ch", "cf", "ha"}, {"ch", "cf", "n1"}, {"c", "cf", "n2"},  {"c", "cf", "n"},   {"c", "cf", "nh"},
     {"f", "c", "f"},    {"h4", "cf", "n2"}, {"h4", "cf", "ne"}, {"ha", "cf", "n1"}, {"ha", "cf", "n2"},
     {"ha", "cf", "nf"}, {"ha", "cf", "nh"}, {"ha", "cf", "p2"}, {"ha", "cf", "pf"}, {"ha", "cf", "px"},
     {"ha", "cf", "py"}, {"ha", "cf", "sx"}, {"ha", "cf", "sy"}, {"n2", "cf", "nh"}, {"nf", "cf", "nf"},
     {"f", "c", "o"},    {"pf", "cf", "pf"}, {"py", "cf", "py"}, {"f", "c", "s"},    {"sx", "cf", "sx"},
     {"sy", "cf", "sy"}, {"c1", "cg", "ca"}, {"c1", "cg", "cc"}, {"c1", "cg", "ce"}, {"c1", "cg", "cg"},
     {"c1", "cg", "ne"}, {"c1", "cg", "pe"}, {"ca", "cg", "ch"}, {"ca", "cg", "n1"}, {"c", "cg", "c1"},
     {"cc", "cg", "n1"}, {"ce", "cg", "ch"}, {"ce", "cg", "n1"}, {"n1", "cg", "ne"}, {"h4", "c", "o"},
     {"h5", "c", "n"},   {"h5", "c", "o"},   {"ha", "c", "ha"},  {"ha", "c", "i"},   {"ha", "c", "n"},
     {"ha", "c", "o"},   {"ha", "c", "oh"},  {"ha", "c", "os"},  {"ha", "c", "s"},   {"c1", "ch", "ca"},
     {"c1", "ch", "cf"}, {"c1", "ch", "ch"}, {"c1", "ch", "nf"}, {"c1", "ch", "pf"}, {"ca", "ch", "cg"},
     {"ca", "ch", "n1"}, {"c", "ch", "c1"},  {"cd", "ch", "n1"}, {"cf", "ch", "cg"}, {"cf", "ch", "n1"},
     {"cg", "ch", "ch"}, {"n1", "ch", "nf"}, {"i", "c", "i"},    {"i", "c", "o"},    {"f", "cl", "f"},
     {"n2", "c", "n2"},  {"n2", "c", "o"},   {"n4", "c", "n4"},  {"n4", "c", "o"},   {"nc", "c", "o"},
     {"nd", "c", "o"},   {"ne", "c", "ne"},  {"ne", "c", "o"},   {"nf", "c", "nf"},  {"nf", "c", "o"},
     {"n", "c", "n"},    {"n", "c", "nc"},   {"n", "c", "nd"},   {"n", "c", "ne"},   {"n", "c", "o"},
     {"n", "c", "oh"},   {"no", "c", "no"},  {"no", "c", "o"},   {"n", "c", "os"},   {"n", "c", "s"},
     {"n", "c", "sh"},   {"n", "c", "ss"},   {"oh", "c", "oh"},  {"oh", "c", "s"},   {"o", "c", "o"},
     {"o", "c", "oh"},   {"o", "c", "os"},   {"o", "c", "p2"},   {"o", "c", "p3"},   {"o", "c", "p5"},
     {"o", "c", "pe"},   {"o", "c", "pf"},   {"o", "c", "px"},   {"o", "c", "py"},   {"o", "c", "s4"},
     {"o", "c", "s6"},   {"o", "c", "s"},    {"o", "c", "sh"},   {"os", "c", "os"},  {"o", "c", "ss"},
     {"os", "c", "s"},   {"os", "c", "ss"},  {"o", "c", "sx"},   {"o", "c", "sy"},   {"p2", "c", "p2"},
     {"p3", "c", "p3"},  {"p3", "c", "py"},  {"p5", "c", "p5"},  {"ca", "cp", "ca"}, {"ca", "cp", "cp"},
     {"ca", "cp", "na"}, {"ca", "cp", "nb"}, {"cp", "cp", "cp"}, {"cp", "cp", "cq"}, {"cp", "cp", "nb"},
     {"pe", "c", "pe"},  {"pf", "c", "pf"},  {"nb", "cp", "nb"}, {"py", "c", "py"},  {"ca", "cq", "ca"},
     {"ca", "cq", "cq"}, {"ca", "cq", "nb"}, {"cp", "cq", "cq"}, {"cq", "cq", "cq"}, {"cq", "cq", "nb"},
     {"s4", "c", "s4"},  {"s6", "c", "s6"},  {"sh", "c", "sh"},  {"s", "c", "s"},    {"s", "c", "sh"},
     {"s", "c", "ss"},   {"ss", "c", "ss"},  {"sx", "c", "sx"},  {"sy", "c", "sy"},  {"c2", "cu", "cx"},
     {"c", "cu", "cu"},  {"cu", "cu", "cx"}, {"cu", "cu", "ha"}, {"cv", "cv", "cy"}, {"cv", "cv", "ha"},
     {"cx", "cv", "cx"}, {"cy", "cv", "ha"}, {"c1", "cx", "cx"}, {"c2", "cx", "cx"}, {"c2", "cx", "h1"},
     {"c2", "cx", "hc"}, {"c2", "cx", "os"}, {"c3", "cx", "c3"}, {"c3", "cx", "cx"}, {"c3", "cx", "h1"},
     {"c3", "cx", "hc"}, {"c3", "cx", "n3"}, {"c3", "cx", "os"}, {"ca", "cx", "cx"}, {"ca", "cx", "h1"},
     {"ca", "cx", "hc"}, {"ca", "cx", "oh"}, {"ca", "cx", "os"}, {"c", "cx", "c3"},  {"cc", "cx", "cx"},
     {"cc", "cx", "hc"}, {"c", "cx", "cx"},  {"cd", "cx", "cx"}, {"c", "cx", "h1"},  {"c", "cx", "hc"},
     {"cl", "cx", "cl"}, {"cl", "cx", "cx"}, {"cl", "cx", "h1"}, {"cl", "cx", "hc"}, {"c", "cx", "os"},
     {"cu", "cx", "cu"}, {"cu", "cx", "cx"}, {"cu", "cx", "hc"}, {"cx", "cx", "cx"}, {"cx", "cx", "cy"},
     {"cx", "cx", "f"},  {"cx", "cx", "h1"}, {"cx", "cx", "hc"}, {"cx", "cx", "hx"}, {"cx", "cx", "n3"},
     {"cx", "cx", "na"}, {"cx", "cx", "nh"}, {"cx", "cx", "os"}, {"cy", "cx", "hc"}, {"f", "cx", "f"},
     {"f", "cx", "h1"},  {"f", "cx", "hc"},  {"h1", "cx", "h1"}, {"h1", "cx", "n3"}, {"h1", "cx", "n"},
     {"h1", "cx", "na"}, {"h1", "cx", "nh"}, {"h1", "cx", "os"}, {"h2", "cx", "h2"}, {"h2", "cx", "n2"},
     {"hc", "cx", "hc"}, {"hc", "cx", "os"}, {"hx", "cx", "n4"}, {"n2", "cx", "n2"}, {"n", "cx", "oh"},
     {"n", "cx", "os"},  {"oh", "cx", "oh"}, {"oh", "cx", "os"}, {"os", "cx", "os"}, {"c2", "cy", "cy"},
     {"c3", "cy", "c3"}, {"c3", "cy", "cy"}, {"c3", "cy", "h1"}, {"c3", "cy", "hc"}, {"c3", "cy", "n3"},
     {"c3", "cy", "n"},  {"c3", "cy", "os"}, {"c", "cy", "c3"},  {"cc", "cy", "cy"}, {"c", "cy", "cy"},
     {"cd", "cy", "cy"}, {"ce", "cy", "h2"}, {"ce", "cy", "n"},  {"ce", "cy", "ss"}, {"c", "cy", "h1"},
     {"c", "cy", "hc"},  {"cl", "cy", "cy"}, {"cl", "cy", "h1"}, {"cl", "cy", "hc"}, {"c", "cy", "n"},
     {"c", "cy", "os"},  {"cv", "cy", "cy"}, {"cv", "cy", "hc"}, {"cx", "cy", "cy"}, {"cx", "cy", "hc"},
     {"cy", "cy", "cy"}, {"cy", "cy", "f"},  {"cy", "cy", "h1"}, {"cy", "cy", "h2"}, {"cy", "cy", "hc"},
     {"cy", "cy", "n3"}, {"cy", "cy", "n"},  {"cy", "cy", "na"}, {"cy", "cy", "oh"}, {"cy", "cy", "os"},
     {"cy", "cy", "s6"}, {"cy", "cy", "ss"}, {"h1", "cy", "h1"}, {"h1", "cy", "n3"}, {"h1", "cy", "n"},
     {"h1", "cy", "oh"}, {"h1", "cy", "os"}, {"h1", "cy", "s6"}, {"h2", "cy", "n"},  {"h2", "cy", "os"},
     {"h2", "cy", "s6"}, {"h2", "cy", "ss"}, {"hc", "cy", "hc"}, {"n", "cy", "os"},  {"n", "cy", "s6"},
     {"n", "cy", "ss"},  {"nh", "cz", "nh"}, {"br", "n1", "c1"}, {"c1", "n1", "c1"}, {"c1", "n1", "c2"},
     {"c1", "n1", "c3"}, {"c1", "n1", "ca"}, {"c1", "n1", "cl"}, {"c1", "n1", "f"},  {"c1", "n1", "hn"},
     {"c1", "n1", "i"},  {"c1", "n1", "n1"}, {"c1", "n1", "n2"}, {"c1", "n1", "n3"}, {"c1", "n1", "n4"},
     {"c1", "n1", "na"}, {"c1", "n1", "nh"}, {"c1", "n1", "o"},  {"c1", "n1", "oh"}, {"c1", "n1", "os"},
     {"c1", "n1", "p2"}, {"c1", "n1", "p3"}, {"c1", "n1", "p4"}, {"c1", "n1", "p5"}, {"c1", "n1", "s2"},
     {"c1", "n1", "s4"}, {"c1", "n1", "s"},  {"c1", "n1", "s6"}, {"c1", "n1", "sh"}, {"c1", "n1", "ss"},
     {"c2", "n1", "n1"}, {"c2", "n1", "o"},  {"c2", "n1", "s"},  {"c3", "n1", "n1"}, {"ca", "n1", "n1"},
     {"ce", "n1", "o"},  {"ce", "n1", "s"},  {"cf", "n1", "o"},  {"cf", "n1", "s"},  {"cl", "n1", "n1"},
     {"f", "n1", "n1"},  {"hn", "n1", "n1"}, {"i", "n1", "n1"},  {"n1", "n1", "n1"}, {"n1", "n1", "n2"},
     {"n1", "n1", "n3"}, {"n1", "n1", "n4"}, {"n1", "n1", "na"}, {"n1", "n1", "nh"}, {"n1", "n1", "o"},
     {"n1", "n1", "oh"}, {"n1", "n1", "os"}, {"n1", "n1", "p2"}, {"n1", "n1", "p3"}, {"n1", "n1", "s"},
     {"n1", "n1", "sh"}, {"n1", "n1", "ss"}, {"o", "n1", "p2"},  {"p2", "n1", "s"},  {"br", "n2", "br"},
     {"br", "n2", "c2"}, {"br", "n2", "n2"}, {"br", "n2", "o"},  {"br", "n2", "p2"}, {"br", "n2", "s"},
     {"c1", "n2", "c1"}, {"c1", "n2", "c3"}, {"c1", "n2", "cl"}, {"c1", "n2", "hn"}, {"c1", "n2", "n2"},
     {"c1", "n2", "o"},  {"c1", "n2", "p2"}, {"c1", "n2", "s"},  {"c2", "n2", "c2"}, {"c2", "n2", "c3"},
     {"c2", "n2", "ca"}, {"c2", "n2", "cl"}, {"c2", "n2", "f"},  {"c2", "n2", "hn"}, {"c2", "n2", "i"},
     {"c2", "n2", "n1"}, {"c2", "n2", "n2"}, {"c2", "n2", "n3"}, {"c2", "n2", "n4"}, {"c2", "n2", "n"},
     {"c2", "n2", "na"}, {"c2", "n2", "nh"}, {"c2", "n2", "no"}, {"c2", "n2", "o"},  {"c2", "n2", "oh"},
     {"c2", "n2", "os"}, {"c2", "n2", "p2"}, {"c2", "n2", "p3"}, {"c2", "n2", "p4"}, {"c2", "n2", "s4"},
     {"c2", "n2", "s6"}, {"c2", "n2", "s"},  {"c2", "n2", "sh"}, {"c2", "n2", "ss"}, {"c3", "n2", "c3"},
     {"c3", "n2", "ca"}, {"c3", "n2", "ce"}, {"c3", "n2", "cf"}, {"c3", "n2", "hn"}, {"c3", "n2", "n1"},
     {"c3", "n2", "n2"}, {"c3", "n2", "nh"}, {"c3", "n2", "o"},  {"c3", "n2", "p2"}, {"c3", "n2", "s6"},
     {"c3", "n2", "s"},  {"ca", "n2", "ca"}, {"ca", "n2", "hn"}, {"ca", "n2", "n2"}, {"ca", "n2", "o"},
     {"ca", "n2", "p2"}, {"ca", "n2", "s"},  {"c", "n2", "c2"},  {"c", "n2", "c"},   {"c", "n2", "ca"},
     {"cc", "n2", "cl"}, {"cc", "n2", "hn"}, {"cc", "n2", "na"}, {"cc", "n2", "nh"}, {"cd", "n2", "cl"},
     {"cd", "n2", "hn"}, {"ce", "n2", "hn"}, {"ce", "n2", "n"},  {"ce", "n2", "nh"}, {"ce", "n2", "o"},
     {"ce", "n2", "oh"}, {"ce", "n2", "os"}, {"ce", "n2", "s"},  {"cf", "n2", "hn"}, {"cf", "n2", "n"},
     {"cf", "n2", "nh"}, {"cf", "n2", "o"},  {"cf", "n2", "oh"}, {"cf", "n2", "os"}, {"cf", "n2", "s"},
     {"cl", "n2", "n1"}, {"cl", "n2", "n2"}, {"cl", "n2", "o"},  {"cl", "n2", "p2"}, {"cl", "n2", "s"},
     {"cx", "n2", "n2"}, {"f", "n2", "n2"},  {"f", "n2", "o"},   {"f", "n2", "p2"},  {"f", "n2", "s"},
     {"hn", "n2", "hn"}, {"hn", "n2", "n1"}, {"hn", "n2", "n2"}, {"hn", "n2", "ne"}, {"hn", "n2", "nf"},
     {"hn", "n2", "o"},  {"hn", "n2", "p2"}, {"hn", "n2", "p4"}, {"hn", "n2", "p5"}, {"hn", "n2", "pe"},
     {"hn", "n2", "pf"}, {"hn", "n2", "s2"}, {"hn", "n2", "s4"}, {"hn", "n2", "s"},  {"hn", "n2", "s6"},
     {"i", "n2", "n2"},  {"i", "n2", "o"},   {"i", "n2", "p2"},  {"i", "n2", "s"},   {"n1", "n2", "n1"},
     {"n2", "n2", "n1"}, {"n2", "n2", "n2"}, {"n2", "n2", "n3"}, {"n2", "n2", "n4"}, {"n2", "n2", "na"},
     {"n2", "n2", "nh"}, {"n2", "n2", "no"}, {"n2", "n2", "o"},  {"n2", "n2", "oh"}, {"n2", "n2", "os"},
     {"n2", "n2", "p2"}, {"n2", "n2", "p3"}, {"n2", "n2", "p4"}, {"n2", "n2", "p5"}, {"n2", "n2", "s4"},
     {"n2", "n2", "s6"}, {"n2", "n2", "s"},  {"n2", "n2", "sh"}, {"n2", "n2", "ss"}, {"n3", "n2", "n3"},
     {"n3", "n2", "o"},  {"n3", "n2", "p2"}, {"n3", "n2", "s"},  {"n4", "n2", "n4"}, {"n4", "n2", "o"},
     {"n4", "n2", "p2"}, {"n4", "n2", "s"},  {"na", "n2", "na"}, {"na", "n2", "o"},  {"na", "n2", "p2"},
     {"na", "n2", "s"},  {"ne", "n2", "nh"}, {"ne", "n2", "o"},  {"ne", "n2", "s"},  {"nf", "n2", "nh"},
     {"nf", "n2", "o"},  {"nf", "n2", "s"},  {"nh", "n2", "nh"}, {"nh", "n2", "o"},  {"nh", "n2", "p2"},
     {"nh", "n2", "s"},  {"n", "n2", "n2"},  {"n", "n2", "o"},   {"no", "n2", "no"}, {"no", "n2", "o"},
     {"no", "n2", "p2"}, {"n", "n2", "p2"},  {"n", "n2", "s"},   {"oh", "n2", "oh"}, {"oh", "n2", "p2"},
     {"oh", "n2", "s"},  {"o", "n2", "o"},   {"o", "n2", "oh"},  {"o", "n2", "os"},  {"o", "n2", "p2"},
     {"o", "n2", "p3"},  {"o", "n2", "p4"},  {"o", "n2", "p5"},  {"o", "n2", "pe"},  {"o", "n2", "pf"},
     {"o", "n2", "s4"},  {"o", "n2", "s6"},  {"o", "n2", "s"},   {"o", "n2", "sh"},  {"os", "n2", "os"},
     {"os", "n2", "p2"}, {"o", "n2", "ss"},  {"os", "n2", "s"},  {"p2", "n2", "p2"}, {"p2", "n2", "p3"},
     {"p2", "n2", "p4"}, {"p2", "n2", "p5"}, {"p2", "n2", "s4"}, {"p2", "n2", "s6"}, {"p2", "n2", "s"},
     {"p2", "n2", "sh"}, {"p2", "n2", "ss"}, {"p3", "n2", "p3"}, {"p3", "n2", "s"},  {"p4", "n2", "s"},
     {"p5", "n2", "p5"}, {"p5", "n2", "s"},  {"pe", "n2", "s"},  {"pf", "n2", "s"},  {"s4", "n2", "s4"},
     {"s4", "n2", "s6"}, {"s6", "n2", "s6"}, {"sh", "n2", "sh"}, {"sh", "n2", "ss"}, {"s", "n2", "s"},
     {"s", "n2", "s4"},  {"s", "n2", "s6"},  {"s", "n2", "sh"},  {"s", "n2", "ss"},  {"ss", "n2", "ss"},
     {"br", "n3", "br"}, {"br", "n3", "c3"}, {"c1", "n3", "c1"}, {"c1", "n3", "f"},  {"c1", "n3", "hn"},
     {"c1", "n3", "o"},  {"c2", "n3", "c2"}, {"c2", "n3", "hn"}, {"c3", "n3", "c3"}, {"c3", "n3", "cl"},
     {"c3", "n3", "cx"}, {"c3", "n3", "cy"}, {"c3", "n3", "f"},  {"c3", "n3", "hn"}, {"c3", "n3", "i"},
     {"c3", "n3", "n2"}, {"c3", "n3", "n3"}, {"c3", "n3", "n4"}, {"c3", "n3", "n"},  {"c3", "n3", "nh"},
     {"c3", "n3", "no"}, {"c3", "n3", "o"},  {"c3", "n3", "oh"}, {"c3", "n3", "os"}, {"c3", "n3", "p3"},
     {"c3", "n3", "p5"}, {"c3", "n3", "s4"}, {"c3", "n3", "s6"}, {"c3", "n3", "s"},  {"c3", "n3", "sh"},
     {"c3", "n3", "ss"}, {"c3", "n3", "sy"}, {"cl", "n3", "cl"}, {"cl", "n3", "hn"}, {"cl", "n3", "n3"},
     {"cx", "n3", "cx"}, {"cx", "n3", "hn"}, {"cx", "n3", "p5"}, {"cx", "n3", "py"}, {"cy", "n3", "cy"},
     {"cy", "n3", "hn"}, {"f", "n3", "f"},   {"f", "n3", "hn"},  {"hn", "n3", "hn"}, {"hn", "n3", "i"},
     {"hn", "n3", "n1"}, {"hn", "n3", "n2"}, {"hn", "n3", "n3"}, {"hn", "n3", "n4"}, {"hn", "n3", "n"},
     {"hn", "n3", "na"}, {"hn", "n3", "nh"}, {"hn", "n3", "no"}, {"hn", "n3", "o"},  {"hn", "n3", "oh"},
     {"hn", "n3", "os"}, {"hn", "n3", "p2"}, {"hn", "n3", "p3"}, {"hn", "n3", "p4"}, {"hn", "n3", "p5"},
     {"hn", "n3", "s4"}, {"hn", "n3", "s"},  {"hn", "n3", "s6"}, {"hn", "n3", "sh"}, {"hn", "n3", "ss"},
     {"hn", "n3", "sy"}, {"i", "n3", "i"},   {"n1", "n3", "n1"}, {"n2", "n3", "n2"}, {"n2", "n3", "o"},
     {"n3", "n3", "n3"}, {"n4", "n3", "n4"}, {"n4", "n3", "nh"}, {"na", "n3", "na"}, {"nh", "n3", "nh"},
     {"n", "n3", "n"},   {"no", "n3", "no"}, {"oh", "n3", "oh"}, {"o", "n3", "o"},   {"o", "n3", "p2"},
     {"o", "n3", "p4"},  {"o", "n3", "s4"},  {"o", "n3", "s6"},  {"o", "n3", "s"},   {"os", "n3", "os"},
     {"p2", "n3", "p2"}, {"p3", "n3", "p3"}, {"p4", "n3", "p4"}, {"p5", "n3", "p5"}, {"s4", "n3", "s4"},
     {"s4", "n3", "s6"}, {"s6", "n3", "s6"}, {"sh", "n3", "sh"}, {"sh", "n3", "ss"}, {"s", "n3", "s"},
     {"ss", "n3", "ss"}, {"br", "n4", "br"}, {"br", "n4", "hn"}, {"c1", "n4", "c1"}, {"c1", "n4", "hn"},
     {"c2", "n4", "c2"}, {"c2", "n4", "c3"}, {"c2", "n4", "hn"}, {"c3", "n4", "c3"}, {"c3", "n4", "ca"},
     {"c3", "n4", "cc"}, {"c3", "n4", "cl"}, {"c3", "n4", "hn"}, {"c3", "n4", "n3"}, {"c3", "n4", "n4"},
     {"c3", "n4", "n"},  {"c3", "n4", "nh"}, {"c3", "n4", "no"}, {"c3", "n4", "o"},  {"c3", "n4", "oh"},
     {"c3", "n4", "os"}, {"c3", "n4", "p2"}, {"c3", "n4", "p3"}, {"c3", "n4", "p5"}, {"c3", "n4", "s4"},
     {"c3", "n4", "s6"}, {"c3", "n4", "s"},  {"c3", "n4", "sh"}, {"c3", "n4", "ss"}, {"ca", "n4", "ca"},
     {"ca", "n4", "hn"}, {"c", "n4", "c"},   {"c", "n4", "hn"},  {"cl", "n4", "cl"}, {"cl", "n4", "hn"},
     {"f", "n4", "f"},   {"f", "n4", "hn"},  {"hn", "n4", "hn"}, {"hn", "n4", "i"},  {"hn", "n4", "n1"},
     {"hn", "n4", "n2"}, {"hn", "n4", "n3"}, {"hn", "n4", "n4"}, {"hn", "n4", "n"},  {"hn", "n4", "na"},
     {"hn", "n4", "nh"}, {"hn", "n4", "no"}, {"hn", "n4", "o"},  {"hn", "n4", "oh"}, {"hn", "n4", "os"},
     {"hn", "n4", "p2"}, {"hn", "n4", "p3"}, {"hn", "n4", "p4"}, {"hn", "n4", "p5"}, {"hn", "n4", "py"},
     {"hn", "n4", "s4"}, {"hn", "n4", "s"},  {"hn", "n4", "s6"}, {"hn", "n4", "sh"}, {"hn", "n4", "ss"},
     {"i", "n4", "i"},   {"n1", "n4", "n1"}, {"n2", "n4", "n2"}, {"n3", "n4", "n3"}, {"n4", "n4", "n4"},
     {"na", "n4", "na"}, {"nh", "n4", "nh"}, {"n", "n4", "n"},   {"oh", "n4", "oh"}, {"o", "n4", "o"},
     {"os", "n4", "os"}, {"p2", "n4", "p2"}, {"p3", "n4", "p3"}, {"p5", "n4", "p5"}, {"py", "n4", "py"},
     {"s4", "n4", "s4"}, {"s6", "n4", "s6"}, {"sh", "n4", "sh"}, {"s", "n4", "s"},   {"ss", "n4", "ss"},
     {"br", "na", "br"}, {"br", "na", "c2"}, {"br", "na", "ca"}, {"br", "na", "cc"}, {"br", "na", "cd"},
     {"br", "na", "nc"}, {"br", "na", "nd"}, {"br", "na", "os"}, {"br", "na", "p2"}, {"br", "na", "pc"},
     {"br", "na", "pd"}, {"br", "na", "ss"}, {"c1", "na", "c1"}, {"c1", "na", "c2"}, {"c1", "na", "ca"},
     {"c1", "na", "cc"}, {"c1", "na", "cd"}, {"c1", "na", "nc"}, {"c1", "na", "nd"}, {"c1", "na", "os"},
     {"c1", "na", "p2"}, {"c1", "na", "pc"}, {"c1", "na", "pd"}, {"c1", "na", "ss"}, {"c2", "na", "c2"},
     {"c2", "na", "c3"}, {"c2", "na", "ca"}, {"c2", "na", "cc"}, {"c2", "na", "cd"}, {"c2", "na", "cl"},
     {"c2", "na", "f"},  {"c2", "na", "hn"}, {"c2", "na", "i"},  {"c2", "na", "n1"}, {"c2", "na", "n2"},
     {"c2", "na", "n3"}, {"c2", "na", "n4"}, {"c2", "na", "n"},  {"c2", "na", "na"}, {"c2", "na", "nc"},
     {"c2", "na", "nd"}, {"c2", "na", "nh"}, {"c2", "na", "no"}, {"c2", "na", "o"},  {"c2", "na", "oh"},
     {"c2", "na", "os"}, {"c2", "na", "p2"}, {"c2", "na", "p3"}, {"c2", "na", "p4"}, {"c2", "na", "p5"},
     {"c2", "na", "pc"}, {"c2", "na", "pd"}, {"c2", "na", "s4"}, {"c2", "na", "s6"}, {"c2", "na", "s"},
     {"c2", "na", "sh"}, {"c2", "na", "ss"}, {"c3", "na", "c3"}, {"c3", "na", "ca"}, {"c3", "na", "cc"},
     {"c3", "na", "cd"}, {"c3", "na", "cp"}, {"c3", "na", "n2"}, {"c3", "na", "n"},  {"c3", "na", "nc"},
     {"c3", "na", "nd"}, {"c3", "na", "os"}, {"c3", "na", "p2"}, {"c3", "na", "pc"}, {"c3", "na", "pd"},
     {"c3", "na", "sh"}, {"c3", "na", "ss"}, {"ca", "na", "ca"}, {"ca", "na", "cc"}, {"ca", "na", "cd"},
     {"ca", "na", "cl"}, {"ca", "na", "cp"}, {"ca", "na", "cx"}, {"ca", "na", "f"},  {"ca", "na", "hn"},
     {"ca", "na", "i"},  {"ca", "na", "n2"}, {"ca", "na", "n4"}, {"ca", "na", "n"},  {"ca", "na", "na"},
     {"ca", "na", "nb"}, {"ca", "na", "nc"}, {"ca", "na", "nd"}, {"ca", "na", "nh"}, {"ca", "na", "o"},
     {"ca", "na", "oh"}, {"ca", "na", "os"}, {"ca", "na", "p2"}, {"ca", "na", "p3"}, {"ca", "na", "p4"},
     {"ca", "na", "p5"}, {"ca", "na", "pc"}, {"ca", "na", "pd"}, {"ca", "na", "py"}, {"ca", "na", "s4"},
     {"ca", "na", "s6"}, {"ca", "na", "s"},  {"ca", "na", "sh"}, {"ca", "na", "ss"}, {"cc", "na", "cc"},
     {"cc", "na", "cd"}, {"cc", "na", "ce"}, {"cc", "na", "cl"}, {"cc", "na", "f"},  {"cc", "na", "hn"},
     {"cc", "na", "i"},  {"cc", "na", "n2"}, {"cc", "na", "n4"}, {"cc", "na", "n"},  {"cc", "na", "na"},
     {"cc", "na", "nc"}, {"cc", "na", "nd"}, {"cc", "na", "nh"}, {"cc", "na", "no"}, {"cc", "na", "o"},
     {"cc", "na", "oh"}, {"cc", "na", "os"}, {"cc", "na", "p2"}, {"cc", "na", "p3"}, {"cc", "na", "p4"},
     {"cc", "na", "p5"}, {"cc", "na", "s4"}, {"cc", "na", "s6"}, {"cc", "na", "s"},  {"cc", "na", "sh"},
     {"cc", "na", "ss"}, {"cd", "na", "cd"}, {"cd", "na", "cl"}, {"cd", "na", "f"},  {"cd", "na", "hn"},
     {"cd", "na", "i"},  {"cd", "na", "n2"}, {"cd", "na", "n4"}, {"cd", "na", "n"},  {"cd", "na", "na"},
     {"cd", "na", "nc"}, {"cd", "na", "nd"}, {"cd", "na", "nh"}, {"cd", "na", "no"}, {"cd", "na", "o"},
     {"cd", "na", "oh"}, {"cd", "na", "os"}, {"cd", "na", "p2"}, {"cd", "na", "p3"}, {"cd", "na", "p4"},
     {"cd", "na", "p5"}, {"cd", "na", "s4"}, {"cd", "na", "s6"}, {"cd", "na", "s"},  {"cd", "na", "sh"},
     {"cd", "na", "ss"}, {"cl", "na", "cl"}, {"cl", "na", "nc"}, {"cl", "na", "nd"}, {"cl", "na", "os"},
     {"cl", "na", "p2"}, {"cl", "na", "pc"}, {"cl", "na", "pd"}, {"cl", "na", "ss"}, {"f", "na", "f"},
     {"f", "na", "nc"},  {"f", "na", "nd"},  {"f", "na", "os"},  {"f", "na", "p2"},  {"f", "na", "pc"},
     {"f", "na", "pd"},  {"f", "na", "ss"},  {"hn", "na", "hn"}, {"hn", "na", "n"},  {"hn", "na", "nc"},
     {"hn", "na", "nd"}, {"hn", "na", "os"}, {"hn", "na", "p2"}, {"hn", "na", "pc"}, {"hn", "na", "pd"},
     {"hn", "na", "ss"}, {"i", "na", "i"},   {"i", "na", "nc"},  {"i", "na", "nd"},  {"i", "na", "os"},
     {"i", "na", "p2"},  {"i", "na", "pc"},  {"i", "na", "pd"},  {"i", "na", "ss"},  {"n2", "na", "n2"},
     {"n2", "na", "nc"}, {"n2", "na", "nd"}, {"n2", "na", "os"}, {"n2", "na", "p2"}, {"n2", "na", "pc"},
     {"n2", "na", "pd"}, {"n2", "na", "ss"}, {"n3", "na", "n3"}, {"n4", "na", "n4"}, {"n4", "na", "nc"},
     {"n4", "na", "nd"}, {"n4", "na", "os"}, {"n4", "na", "p2"}, {"n4", "na", "pc"}, {"n4", "na", "pd"},
     {"na", "na", "na"}, {"na", "na", "nc"}, {"na", "na", "nd"}, {"na", "na", "os"}, {"na", "na", "p2"},
     {"na", "na", "pc"}, {"na", "na", "pd"}, {"na", "na", "ss"}, {"nc", "na", "nc"}, {"nc", "na", "nd"},
     {"nc", "na", "nh"}, {"nc", "na", "no"}, {"nc", "na", "o"},  {"nc", "na", "oh"}, {"nc", "na", "os"},
     {"nc", "na", "p2"}, {"nc", "na", "p3"}, {"nc", "na", "p4"}, {"nc", "na", "p5"}, {"nc", "na", "pc"},
     {"nc", "na", "s4"}, {"nc", "na", "s6"}, {"nc", "na", "s"},  {"nc", "na", "sh"}, {"nc", "na", "ss"},
     {"nd", "na", "nd"}, {"nd", "na", "nh"}, {"nd", "na", "no"}, {"nd", "na", "o"},  {"nd", "na", "oh"},
     {"nd", "na", "os"}, {"nd", "na", "p2"}, {"nd", "na", "p3"}, {"nd", "na", "p4"}, {"nd", "na", "p5"},
     {"nd", "na", "pd"}, {"nd", "na", "s4"}, {"nd", "na", "s6"}, {"nd", "na", "s"},  {"nd", "na", "sh"},
     {"nd", "na", "ss"}, {"nh", "na", "nh"}, {"nh", "na", "os"}, {"nh", "na", "p2"}, {"nh", "na", "pc"},
     {"nh", "na", "pd"}, {"nh", "na", "ss"}, {"n", "na", "n"},   {"n", "na", "nc"},  {"n", "na", "nd"},
     {"no", "na", "no"}, {"no", "na", "os"}, {"no", "na", "pc"}, {"no", "na", "pd"}, {"n", "na", "os"},
     {"no", "na", "ss"}, {"n", "na", "p2"},  {"n", "na", "pc"},  {"n", "na", "pd"},  {"n", "na", "ss"},
     {"oh", "na", "oh"}, {"oh", "na", "p2"}, {"oh", "na", "pc"}, {"oh", "na", "pd"}, {"oh", "na", "ss"},
     {"o", "na", "o"},   {"o", "na", "os"},  {"o", "na", "p2"},  {"o", "na", "pc"},  {"o", "na", "pd"},
     {"os", "na", "os"}, {"os", "na", "p2"}, {"os", "na", "p3"}, {"os", "na", "p5"}, {"os", "na", "pc"},
     {"os", "na", "pd"}, {"os", "na", "s4"}, {"os", "na", "s6"}, {"os", "na", "ss"}, {"p2", "na", "p2"},
     {"p2", "na", "p3"}, {"p2", "na", "p5"}, {"p2", "na", "pc"}, {"p2", "na", "pd"}, {"p2", "na", "s4"},
     {"p2", "na", "s6"}, {"p2", "na", "s"},  {"p2", "na", "sh"}, {"p2", "na", "ss"}, {"p3", "na", "p3"},
     {"p3", "na", "pc"}, {"p3", "na", "pd"}, {"p5", "na", "p5"}, {"p5", "na", "pc"}, {"p5", "na", "pd"},
     {"p5", "na", "ss"}, {"pc", "na", "pc"}, {"pc", "na", "s4"}, {"pc", "na", "s6"}, {"pc", "na", "s"},
     {"pc", "na", "sh"}, {"pc", "na", "ss"}, {"pd", "na", "pd"}, {"pd", "na", "s4"}, {"pd", "na", "s6"},
     {"pd", "na", "s"},  {"pd", "na", "sh"}, {"pd", "na", "ss"}, {"py", "na", "py"}, {"s4", "na", "s4"},
     {"s4", "na", "s6"}, {"s4", "na", "ss"}, {"s6", "na", "s6"}, {"s6", "na", "ss"}, {"sh", "na", "sh"},
     {"sh", "na", "ss"}, {"s", "na", "s"},   {"s", "na", "ss"},  {"ss", "na", "ss"}, {"sy", "na", "sy"},
     {"ca", "nb", "ca"}, {"ca", "nb", "cp"}, {"ca", "nb", "cq"}, {"ca", "nb", "nb"}, {"cp", "nb", "nb"},
     {"nb", "nb", "nb"}, {"br", "n", "br"},  {"br", "n", "c"},   {"br", "n", "ca"},  {"br", "n", "cc"},
     {"br", "n", "cd"},  {"c1", "n", "c1"},  {"c1", "n", "ca"},  {"c1", "n", "cc"},  {"c1", "n", "cd"},
     {"c2", "n", "c2"},  {"c2", "n", "c3"},  {"c2", "n", "ca"},  {"c2", "n", "cc"},  {"c2", "n", "cd"},
     {"c2", "n", "hn"},  {"c3", "n", "c3"},  {"c3", "n", "ca"},  {"c3", "n", "cc"},  {"c3", "n", "cd"},
     {"c3", "n", "cy"},  {"c3", "n", "hn"},  {"c3", "n", "n2"},  {"c3", "n", "n"},   {"c3", "n", "nc"},
     {"c3", "n", "nd"},  {"c3", "n", "oh"},  {"c3", "n", "os"},  {"c3", "n", "sy"},  {"ca", "n", "ca"},
     {"ca", "n", "cc"},  {"ca", "n", "cd"},  {"ca", "n", "cl"},  {"ca", "n", "f"},   {"ca", "n", "hn"},
     {"ca", "n", "i"},   {"ca", "n", "n2"},  {"ca", "n", "n4"},  {"ca", "n", "n"},   {"ca", "n", "na"},
     {"ca", "n", "nc"},  {"ca", "n", "nd"},  {"ca", "n", "nh"},  {"ca", "n", "p2"},  {"ca", "n", "p3"},
     {"ca", "n", "s4"},  {"ca", "n", "s6"},  {"ca", "n", "ss"},  {"c", "n", "c1"},   {"c", "n", "c2"},
     {"c", "n", "c3"},   {"c3", "nc", "cd"}, {"c", "n", "c"},    {"c", "n", "ca"},   {"ca", "nc", "ca"},
     {"ca", "nc", "cd"}, {"ca", "nc", "n"},  {"ca", "nc", "na"}, {"ca", "nc", "os"}, {"ca", "nc", "ss"},
     {"c", "n", "cc"},   {"c", "nc", "ca"},  {"cc", "n", "cc"},  {"cc", "nc", "cc"}, {"cc", "nc", "cd"},
     {"c", "nc", "cd"},  {"cc", "n", "cl"},  {"cc", "nc", "na"}, {"cc", "nc", "nd"}, {"c", "n", "cd"},
     {"cd", "nc", "cd"}, {"cd", "nc", "n"},  {"cd", "nc", "na"}, {"cd", "nc", "nc"}, {"cd", "nc", "os"},
     {"cd", "nc", "ss"}, {"c", "n", "ce"},   {"cc", "n", "f"},   {"cc", "n", "hn"},  {"cc", "n", "i"},
     {"c", "n", "cl"},   {"cc", "n", "n2"},  {"cc", "n", "n"},   {"cc", "n", "na"},  {"cc", "n", "nc"},
     {"cc", "n", "nh"},  {"cc", "n", "no"},  {"cc", "n", "o"},   {"cc", "n", "oh"},  {"cc", "n", "os"},
     {"cc", "n", "p2"},  {"cc", "n", "p3"},  {"cc", "n", "p5"},  {"cc", "n", "s4"},  {"cc", "n", "s6"},
     {"cc", "n", "s"},   {"cc", "n", "sh"},  {"cc", "n", "ss"},  {"c", "n", "cx"},   {"c", "n", "cy"},
     {"cd", "n", "cd"},  {"cd", "n", "cl"},  {"cd", "n", "f"},   {"cd", "n", "hn"},  {"cd", "n", "i"},
     {"cd", "n", "n2"},  {"cd", "n", "n"},   {"cd", "n", "na"},  {"cd", "n", "nd"},  {"cd", "n", "nh"},
     {"cd", "n", "no"},  {"cd", "n", "o"},   {"cd", "n", "oh"},  {"cd", "n", "os"},  {"cd", "n", "p2"},
     {"cd", "n", "p3"},  {"cd", "n", "p5"},  {"cd", "n", "s4"},  {"cd", "n", "s6"},  {"cd", "n", "s"},
     {"cd", "n", "sh"},  {"cd", "n", "ss"},  {"ce", "n", "cy"},  {"c", "n", "f"},    {"cf", "n", "cy"},
     {"c", "n", "hn"},   {"c", "n", "i"},    {"cl", "n", "cl"},  {"c", "n", "n2"},   {"c", "n", "n3"},
     {"c", "n", "n4"},   {"c", "n", "n"},    {"c", "n", "na"},   {"na", "nc", "nd"}, {"c", "n", "nc"},
     {"nc", "nc", "nd"}, {"c", "n", "nd"},   {"nd", "nc", "os"}, {"c", "n", "nh"},   {"c", "n", "no"},
     {"c", "n", "o"},    {"c", "n", "oh"},   {"c", "n", "os"},   {"c", "n", "p2"},   {"c", "n", "p3"},
     {"c", "n", "p4"},   {"c", "n", "p5"},   {"c", "n", "pc"},   {"c", "n", "pd"},   {"c", "n", "s4"},
     {"c", "n", "s6"},   {"c", "n", "s"},    {"c", "n", "sh"},   {"c", "n", "ss"},   {"c", "n", "sy"},
     {"cx", "n", "hn"},  {"cx", "n", "os"},  {"cy", "n", "hn"},  {"c3", "nd", "cc"}, {"ca", "nd", "ca"},
     {"ca", "nd", "cc"}, {"ca", "nd", "n"},  {"ca", "nd", "na"}, {"ca", "nd", "nc"}, {"ca", "nd", "os"},
     {"ca", "nd", "ss"}, {"c", "nd", "ca"},  {"c", "nd", "cc"},  {"cc", "nd", "cc"}, {"cc", "nd", "cd"},
     {"cc", "nd", "n"},  {"cc", "nd", "na"}, {"cc", "nd", "nd"}, {"cc", "nd", "os"}, {"cc", "nd", "ss"},
     {"cd", "nd", "cd"}, {"cd", "nd", "na"}, {"cd", "nd", "nc"}, {"na", "nd", "nc"}, {"nc", "nd", "nd"},
     {"nc", "nd", "os"}, {"c1", "ne", "ca"}, {"c1", "ne", "cg"}, {"c2", "ne", "ca"}, {"c2", "ne", "ce"},
     {"c2", "ne", "cg"}, {"c2", "ne", "n2"}, {"c2", "ne", "ne"}, {"c2", "ne", "p2"}, {"c2", "ne", "pe"},
     {"c2", "ne", "px"}, {"c2", "ne", "py"}, {"c2", "ne", "sx"}, {"c2", "ne", "sy"}, {"ca", "ne", "cf"},
     {"ca", "ne", "n2"}, {"ca", "ne", "nf"}, {"ca", "ne", "o"},  {"ca", "ne", "p2"}, {"ca", "ne", "s"},
     {"c", "ne", "c2"},  {"ce", "ne", "n2"}, {"ce", "ne", "o"},  {"ce", "ne", "p2"}, {"ce", "ne", "s"},
     {"cg", "ne", "n1"}, {"cg", "ne", "n2"}, {"cg", "ne", "o"},  {"cg", "ne", "p2"}, {"cg", "ne", "s"},
     {"c", "ne", "sy"},  {"n2", "ne", "n2"}, {"n2", "ne", "ne"}, {"n2", "ne", "o"},  {"n2", "ne", "p2"},
     {"n2", "ne", "pe"}, {"n2", "ne", "px"}, {"n2", "ne", "py"}, {"n2", "ne", "s"},  {"n2", "ne", "sx"},
     {"n2", "ne", "sy"}, {"ne", "ne", "o"},  {"ne", "ne", "p2"}, {"ne", "ne", "s"},  {"o", "ne", "o"},
     {"o", "ne", "pe"},  {"o", "ne", "px"},  {"o", "ne", "py"},  {"o", "ne", "s"},   {"o", "ne", "sx"},
     {"o", "ne", "sy"},  {"p2", "ne", "pe"}, {"p2", "ne", "px"}, {"p2", "ne", "py"}, {"p2", "ne", "sx"},
     {"p2", "ne", "sy"}, {"pe", "ne", "s"},  {"px", "ne", "s"},  {"py", "ne", "s"},  {"s", "ne", "s"},
     {"s", "ne", "sx"},  {"s", "ne", "sy"},  {"c1", "nf", "ca"}, {"c1", "nf", "ch"}, {"c2", "nf", "ca"},
     {"c2", "nf", "cf"}, {"c2", "nf", "n2"}, {"c2", "nf", "nf"}, {"c2", "nf", "p2"}, {"c2", "nf", "pf"},
     {"c2", "nf", "px"}, {"c2", "nf", "py"}, {"c2", "nf", "sx"}, {"c2", "nf", "sy"}, {"ca", "nf", "ce"},
     {"ca", "nf", "n2"}, {"ca", "nf", "ne"}, {"ca", "nf", "o"},  {"ca", "nf", "p2"}, {"ca", "nf", "s"},
     {"c", "nf", "c2"},  {"cf", "nf", "n2"}, {"cf", "nf", "o"},  {"cf", "nf", "p2"}, {"cf", "nf", "s"},
     {"ch", "nf", "n1"}, {"ch", "nf", "n2"}, {"ch", "nf", "o"},  {"ch", "nf", "p2"}, {"ch", "nf", "s"},
     {"f", "n", "f"},    {"n2", "nf", "n2"}, {"n2", "nf", "nf"}, {"n2", "nf", "o"},  {"n2", "nf", "p2"},
     {"n2", "nf", "pf"}, {"n2", "nf", "px"}, {"n2", "nf", "py"}, {"n2", "nf", "s"},  {"n2", "nf", "sx"},
     {"n2", "nf", "sy"}, {"nf", "nf", "o"},  {"nf", "nf", "p2"}, {"nf", "nf", "s"},  {"o", "nf", "o"},
     {"o", "nf", "pf"},  {"o", "nf", "px"},  {"o", "nf", "py"},  {"o", "nf", "s"},   {"o", "nf", "sx"},
     {"o", "nf", "sy"},  {"p2", "nf", "pf"}, {"p2", "nf", "px"}, {"p2", "nf", "py"}, {"p2", "nf", "sx"},
     {"p2", "nf", "sy"}, {"pf", "nf", "s"},  {"px", "nf", "s"},  {"py", "nf", "s"},  {"s", "nf", "s"},
     {"s", "nf", "sx"},  {"s", "nf", "sy"},  {"br", "nh", "br"}, {"br", "nh", "ca"}, {"br", "nh", "hn"},
     {"c1", "nh", "c1"}, {"c1", "nh", "c2"}, {"c1", "nh", "ca"}, {"c1", "nh", "hn"}, {"c2", "nh", "c2"},
     {"c2", "nh", "c3"}, {"c2", "nh", "ca"}, {"c2", "nh", "cc"}, {"c2", "nh", "cd"}, {"c2", "nh", "cx"},
     {"c2", "nh", "hn"}, {"c2", "nh", "n2"}, {"c2", "nh", "n3"}, {"c2", "nh", "no"}, {"c2", "nh", "oh"},
     {"c2", "nh", "os"}, {"c2", "nh", "sy"}, {"c3", "nh", "c3"}, {"c3", "nh", "ca"}, {"c3", "nh", "cc"},
     {"c3", "nh", "cd"}, {"c3", "nh", "cf"}, {"c3", "nh", "cz"}, {"c3", "nh", "hn"}, {"c3", "nh", "n2"},
     {"c3", "nh", "n"},  {"c3", "nh", "na"}, {"c3", "nh", "p2"}, {"c3", "nh", "sy"}, {"ca", "nh", "ca"},
     {"ca", "nh", "cc"}, {"ca", "nh", "cd"}, {"ca", "nh", "cl"}, {"ca", "nh", "cx"}, {"ca", "nh", "f"},
     {"ca", "nh", "hn"}, {"ca", "nh", "i"},  {"ca", "nh", "n1"}, {"ca", "nh", "n2"}, {"ca", "nh", "n3"},
     {"ca", "nh", "n4"}, {"ca", "nh", "n"},  {"ca", "nh", "na"}, {"ca", "nh", "nh"}, {"ca", "nh", "no"},
     {"ca", "nh", "o"},  {"ca", "nh", "oh"}, {"ca", "nh", "os"}, {"ca", "nh", "p2"}, {"ca", "nh", "p3"},
     {"ca", "nh", "p4"}, {"ca", "nh", "p5"}, {"ca", "nh", "s4"}, {"ca", "nh", "s6"}, {"ca", "nh", "s"},
     {"ca", "nh", "sh"}, {"ca", "nh", "ss"}, {"ca", "nh", "sy"}, {"cc", "nh", "cx"}, {"cc", "nh", "hn"},
     {"cc", "nh", "n2"}, {"cc", "nh", "sy"}, {"cd", "nh", "cx"}, {"cd", "nh", "hn"}, {"ce", "nh", "hn"},
     {"ce", "nh", "o"},  {"ce", "nh", "sy"}, {"cf", "nh", "hn"}, {"cf", "nh", "o"},  {"cl", "nh", "cl"},
     {"cl", "nh", "hn"}, {"cx", "nh", "cx"}, {"cx", "nh", "hn"}, {"cz", "nh", "hn"}, {"f", "nh", "f"},
     {"f", "nh", "hn"},  {"hn", "nh", "hn"}, {"hn", "nh", "i"},  {"hn", "nh", "n1"}, {"hn", "nh", "n2"},
     {"hn", "nh", "n3"}, {"hn", "nh", "n4"}, {"hn", "nh", "n"},  {"hn", "nh", "na"}, {"hn", "nh", "nh"},
     {"hn", "nh", "no"}, {"hn", "nh", "o"},  {"hn", "nh", "oh"}, {"hn", "nh", "os"}, {"hn", "nh", "p2"},
     {"hn", "nh", "p3"}, {"hn", "nh", "p4"}, {"hn", "nh", "p5"}, {"hn", "nh", "s4"}, {"hn", "nh", "s"},
     {"hn", "nh", "s6"}, {"hn", "nh", "sh"}, {"hn", "nh", "ss"}, {"hn", "nh", "sy"}, {"i", "nh", "i"},
     {"n1", "nh", "n1"}, {"n2", "nh", "n2"}, {"n2", "nh", "n3"}, {"n2", "nh", "o"},  {"n3", "nh", "n3"},
     {"n4", "nh", "n4"}, {"na", "nh", "na"}, {"hn", "n", "hn"},  {"nh", "nh", "nh"}, {"hn", "n", "i"},
     {"hn", "n", "n2"},  {"hn", "n", "n3"},  {"hn", "n", "n4"},  {"hn", "n", "n"},   {"hn", "n", "na"},
     {"hn", "n", "nc"},  {"hn", "n", "nh"},  {"hn", "n", "no"},  {"hn", "n", "o"},   {"n", "nh", "o"},
     {"hn", "n", "oh"},  {"no", "nh", "no"}, {"hn", "n", "os"},  {"hn", "n", "p2"},  {"hn", "n", "p3"},
     {"hn", "n", "p4"},  {"hn", "n", "p5"},  {"hn", "n", "s4"},  {"hn", "n", "s"},   {"hn", "n", "s6"},
     {"hn", "n", "sh"},  {"hn", "n", "ss"},  {"hn", "n", "sy"},  {"oh", "nh", "oh"}, {"o", "nh", "o"},
     {"os", "nh", "os"}, {"p2", "nh", "p2"}, {"p3", "nh", "p3"}, {"p5", "nh", "p5"}, {"s4", "nh", "s4"},
     {"s6", "nh", "s6"}, {"sh", "nh", "sh"}, {"s", "nh", "s"},   {"ss", "nh", "ss"}, {"i", "n", "i"},
     {"n2", "n", "n2"},  {"n3", "n", "n3"},  {"n4", "n", "n4"},  {"na", "n", "na"},  {"nc", "n", "nc"},
     {"nc", "n", "p2"},  {"nc", "n", "pc"},  {"nd", "n", "nd"},  {"nd", "n", "p2"},  {"nd", "n", "pd"},
     {"nh", "n", "nh"},  {"n", "n", "n"},    {"no", "n", "no"},  {"br", "no", "o"},  {"c1", "no", "o"},
     {"c2", "no", "o"},  {"c3", "no", "o"},  {"ca", "no", "o"},  {"cc", "no", "o"},  {"cl", "no", "o"},
     {"c", "no", "o"},   {"hn", "no", "o"},  {"oh", "n", "oh"},  {"i", "no", "o"},   {"n1", "no", "o"},
     {"n2", "no", "o"},  {"n3", "no", "o"},  {"n4", "no", "o"},  {"na", "no", "o"},  {"nh", "no", "o"},
     {"n", "no", "o"},   {"no", "no", "o"},  {"o", "n", "o"},    {"o", "no", "o"},   {"o", "no", "oh"},
     {"o", "no", "os"},  {"o", "no", "p2"},  {"o", "no", "p3"},  {"o", "no", "p4"},  {"o", "no", "p5"},
     {"o", "no", "s4"},  {"o", "no", "s6"},  {"o", "no", "s"},   {"o", "no", "sh"},  {"o", "no", "ss"},
     {"os", "n", "os"},  {"p2", "n", "p2"},  {"p3", "n", "p3"},  {"p4", "n", "p4"},  {"p5", "n", "p5"},
     {"pc", "n", "pc"},  {"pd", "n", "pd"},  {"s4", "n", "s4"},  {"s6", "n", "s6"},  {"sh", "n", "sh"},
     {"s", "n", "s"},    {"ss", "n", "ss"},  {"br", "oh", "ho"}, {"c1", "oh", "ho"}, {"c2", "oh", "ho"},
     {"c3", "oh", "ho"}, {"ca", "oh", "ho"}, {"cc", "oh", "ho"}, {"cd", "oh", "ho"}, {"ce", "oh", "ho"},
     {"cf", "oh", "ho"}, {"c", "oh", "ho"},  {"cl", "oh", "ho"}, {"cx", "oh", "ho"}, {"cy", "oh", "ho"},
     {"f", "oh", "ho"},  {"ho", "oh", "ho"}, {"ho", "oh", "i"},  {"ho", "oh", "n1"}, {"ho", "oh", "n2"},
     {"ho", "oh", "n3"}, {"ho", "oh", "n4"}, {"ho", "oh", "n"},  {"ho", "oh", "na"}, {"ho", "oh", "nh"},
     {"ho", "oh", "no"}, {"ho", "oh", "o"},  {"ho", "oh", "oh"}, {"ho", "oh", "os"}, {"ho", "oh", "p2"},
     {"ho", "oh", "p3"}, {"ho", "oh", "p4"}, {"ho", "oh", "p5"}, {"ho", "oh", "py"}, {"ho", "oh", "s4"},
     {"ho", "oh", "s"},  {"ho", "oh", "s6"}, {"ho", "oh", "sh"}, {"ho", "oh", "ss"}, {"ho", "oh", "sy"},
     {"br", "os", "br"}, {"c1", "os", "c1"}, {"c1", "os", "c3"}, {"c2", "os", "c2"}, {"c2", "os", "c3"},
     {"c2", "os", "ca"}, {"c2", "os", "n2"}, {"c2", "os", "na"}, {"c2", "os", "os"}, {"c2", "os", "p5"},
     {"c2", "os", "ss"}, {"c3", "os", "c3"}, {"c3", "os", "ca"}, {"c3", "os", "cc"}, {"c3", "os", "cd"},
     {"c3", "os", "ce"}, {"c3", "os", "cf"}, {"c3", "os", "cl"}, {"c3", "os", "cy"}, {"c3", "os", "i"},
     {"c3", "os", "n1"}, {"c3", "os", "n2"}, {"c3", "os", "n3"}, {"c3", "os", "n4"}, {"c3", "os", "n"},
     {"c3", "os", "na"}, {"c3", "os", "nc"}, {"c3", "os", "nd"}, {"c3", "os", "nh"}, {"c3", "os", "no"},
     {"c3", "os", "o"},  {"c3", "os", "oh"}, {"c3", "os", "os"}, {"c3", "os", "p2"}, {"c3", "os", "p3"},
     {"c3", "os", "p4"}, {"c3", "os", "p5"}, {"c3", "os", "py"}, {"c3", "os", "s4"}, {"c3", "os", "s6"},
     {"c3", "os", "s"},  {"c3", "os", "sh"}, {"c3", "os", "ss"}, {"ca", "os", "ca"}, {"ca", "os", "cc"},
     {"ca", "os", "cd"}, {"ca", "os", "n3"}, {"ca", "os", "na"}, {"ca", "os", "nc"}, {"ca", "os", "nd"},
     {"ca", "os", "p5"}, {"ca", "os", "s6"}, {"c", "os", "c2"},  {"c", "os", "c3"},  {"c", "os", "c"},
     {"c", "os", "ca"},  {"c", "os", "cc"},  {"cc", "os", "cc"}, {"cc", "os", "cd"}, {"c", "os", "cd"},
     {"cc", "os", "na"}, {"cc", "os", "nc"}, {"cc", "os", "os"}, {"cc", "os", "ss"}, {"c", "os", "cy"},
     {"cd", "os", "cd"}, {"cd", "os", "na"}, {"cd", "os", "nd"}, {"cd", "os", "os"}, {"cd", "os", "ss"},
     {"cl", "os", "cl"}, {"c", "os", "n2"},  {"c", "os", "n"},   {"c", "os", "oh"},  {"c", "os", "os"},
     {"c", "os", "p5"},  {"c", "os", "sy"},  {"cx", "os", "cx"}, {"cx", "os", "n"},  {"cx", "os", "os"},
     {"cy", "os", "cy"}, {"f", "os", "f"},   {"f", "os", "os"},  {"i", "os", "i"},   {"n1", "os", "n1"},
     {"n2", "os", "n2"}, {"n2", "os", "s6"}, {"n3", "os", "n3"}, {"n4", "os", "n4"}, {"na", "os", "na"},
     {"na", "os", "ss"}, {"nc", "os", "nc"}, {"nc", "os", "ss"}, {"nd", "os", "nd"}, {"nd", "os", "ss"},
     {"nh", "os", "nh"}, {"n", "os", "n"},   {"no", "os", "no"}, {"n", "os", "s6"},  {"o", "os", "o"},
     {"p2", "os", "p2"}, {"p2", "os", "p5"}, {"p3", "os", "p3"}, {"p3", "os", "py"}, {"p5", "os", "p5"},
     {"s4", "os", "s4"}, {"s6", "os", "s6"}, {"sh", "os", "sh"}, {"s", "os", "s"},   {"ss", "os", "ss"},
     {"br", "p2", "br"}, {"br", "p2", "c2"}, {"br", "p2", "n2"}, {"br", "p2", "o"},  {"br", "p2", "p2"},
     {"br", "p2", "s"},  {"c1", "p2", "c1"}, {"c1", "p2", "c2"}, {"c1", "p2", "n2"}, {"c1", "p2", "o"},
     {"c1", "p2", "p2"}, {"c1", "p2", "s"},  {"c2", "p2", "c2"}, {"c2", "p2", "c3"}, {"c2", "p2", "ca"},
     {"c2", "p2", "cl"}, {"c2", "p2", "f"},  {"c2", "p2", "hp"}, {"c2", "p2", "i"},  {"c2", "p2", "n2"},
     {"c2", "p2", "n3"}, {"c2", "p2", "n4"}, {"c2", "p2", "n"},  {"c2", "p2", "na"}, {"c2", "p2", "nh"},
     {"c2", "p2", "no"}, {"c2", "p2", "o"},  {"c2", "p2", "oh"}, {"c2", "p2", "os"}, {"c2", "p2", "p2"},
     {"c2", "p2", "p3"}, {"c2", "p2", "p4"}, {"c2", "p2", "p5"}, {"c2", "p2", "s4"}, {"c2", "p2", "s6"},
     {"c2", "p2", "s"},  {"c2", "p2", "sh"}, {"c2", "p2", "ss"}, {"c3", "p2", "c3"}, {"c3", "p2", "n2"},
     {"c3", "p2", "o"},  {"c3", "p2", "os"}, {"c3", "p2", "p2"}, {"c3", "p2", "s"},  {"ca", "p2", "ca"},
     {"ca", "p2", "n2"}, {"ca", "p2", "n"},  {"ca", "p2", "na"}, {"ca", "p2", "o"},  {"ca", "p2", "s"},
     {"c", "p2", "c2"},  {"c", "p2", "c"},   {"ce", "p2", "o"},  {"ce", "p2", "s"},  {"cf", "p2", "o"},
     {"cf", "p2", "s"},  {"cl", "p2", "cl"}, {"cl", "p2", "n2"}, {"cl", "p2", "o"},  {"cl", "p2", "p2"},
     {"cl", "p2", "s"},  {"f", "p2", "f"},   {"f", "p2", "n2"},  {"f", "p2", "o"},   {"f", "p2", "p2"},
     {"f", "p2", "s"},   {"hp", "p2", "hp"}, {"hp", "p2", "n1"}, {"hp", "p2", "n2"}, {"hp", "p2", "ne"},
     {"hp", "p2", "nf"}, {"hp", "p2", "o"},  {"hp", "p2", "p2"}, {"hp", "p2", "p4"}, {"hp", "p2", "p5"},
     {"hp", "p2", "pe"}, {"hp", "p2", "pf"}, {"hp", "p2", "s4"}, {"hp", "p2", "s"},  {"hp", "p2", "s6"},
     {"i", "p2", "i"},   {"i", "p2", "n2"},  {"i", "p2", "o"},   {"i", "p2", "p2"},  {"i", "p2", "s"},
     {"n1", "p2", "n1"}, {"n2", "p2", "n2"}, {"n2", "p2", "n3"}, {"n2", "p2", "n4"}, {"n2", "p2", "na"},
     {"n2", "p2", "nh"}, {"n2", "p2", "no"}, {"n2", "p2", "o"},  {"n2", "p2", "oh"}, {"n2", "p2", "os"},
     {"n2", "p2", "p3"}, {"n2", "p2", "p4"}, {"n2", "p2", "p5"}, {"n2", "p2", "s4"}, {"n2", "p2", "s6"},
     {"n2", "p2", "s"},  {"n2", "p2", "sh"}, {"n2", "p2", "ss"}, {"n3", "p2", "n3"}, {"n3", "p2", "o"},
     {"n3", "p2", "p2"}, {"n3", "p2", "s"},  {"n4", "p2", "n4"}, {"n4", "p2", "o"},  {"n4", "p2", "p2"},
     {"n4", "p2", "s"},  {"na", "p2", "na"}, {"na", "p2", "o"},  {"na", "p2", "s"},  {"ne", "p2", "o"},
     {"ne", "p2", "s"},  {"nf", "p2", "o"},  {"nf", "p2", "s"},  {"nh", "p2", "nh"}, {"nh", "p2", "o"},
     {"nh", "p2", "p2"}, {"nh", "p2", "s"},  {"n", "p2", "n2"},  {"n", "p2", "o"},   {"no", "p2", "no"},
     {"no", "p2", "o"},  {"no", "p2", "p2"}, {"no", "p2", "s"},  {"n", "p2", "p2"},  {"n", "p2", "s"},
     {"oh", "p2", "oh"}, {"oh", "p2", "p2"}, {"oh", "p2", "s"},  {"o", "p2", "o"},   {"o", "p2", "oh"},
     {"o", "p2", "os"},  {"o", "p2", "p2"},  {"o", "p2", "p3"},  {"o", "p2", "p4"},  {"o", "p2", "p5"},
     {"o", "p2", "pe"},  {"o", "p2", "pf"},  {"o", "p2", "s4"},  {"o", "p2", "s6"},  {"o", "p2", "s"},
     {"o", "p2", "sh"},  {"os", "p2", "os"}, {"os", "p2", "p2"}, {"o", "p2", "ss"},  {"os", "p2", "s"},
     {"p2", "p2", "n2"}, {"p2", "p2", "p3"}, {"p2", "p2", "p4"}, {"p2", "p2", "p5"}, {"p2", "p2", "s4"},
     {"p2", "p2", "s6"}, {"p2", "p2", "s"},  {"p2", "p2", "sh"}, {"p3", "p2", "p3"}, {"p3", "p2", "s"},
     {"p4", "p2", "s"},  {"p5", "p2", "p5"}, {"p5", "p2", "s"},  {"pe", "p2", "s"},  {"pf", "p2", "s"},
     {"s4", "p2", "s4"}, {"s6", "p2", "s6"}, {"sh", "p2", "sh"}, {"s", "p2", "s"},   {"s", "p2", "s4"},
     {"s", "p2", "s6"},  {"s", "p2", "sh"},  {"s", "p2", "ss"},  {"ss", "p2", "ss"}, {"br", "p3", "br"},
     {"br", "p3", "hp"}, {"c1", "p3", "c1"}, {"c1", "p3", "f"},  {"c1", "p3", "hp"}, {"c2", "p3", "c2"},
     {"c2", "p3", "hp"}, {"c3", "p3", "c3"}, {"c3", "p3", "ca"}, {"c3", "p3", "cl"}, {"c3", "p3", "f"},
     {"c3", "p3", "hp"}, {"c3", "p3", "n2"}, {"c3", "p3", "n3"}, {"c3", "p3", "n4"}, {"c3", "p3", "n"},
     {"c3", "p3", "na"}, {"c3", "p3", "nh"}, {"c3", "p3", "no"}, {"c3", "p3", "o"},  {"c3", "p3", "oh"},
     {"c3", "p3", "os"}, {"c3", "p3", "p3"}, {"c3", "p3", "p5"}, {"c3", "p3", "s4"}, {"c3", "p3", "s6"},
     {"c3", "p3", "sh"}, {"c3", "p3", "ss"}, {"ca", "p3", "ca"}, {"ca", "p3", "hp"}, {"c", "p3", "c3"},
     {"c", "p3", "c"},   {"c", "p3", "hp"},  {"cl", "p3", "cl"}, {"cl", "p3", "f"},  {"cl", "p3", "hp"},
     {"c", "p3", "os"},  {"cx", "p3", "hp"}, {"f", "p3", "f"},   {"f", "p3", "hp"},  {"f", "p3", "n3"},
     {"f", "p3", "os"},  {"f", "p3", "p3"},  {"hp", "p3", "hp"}, {"hp", "p3", "i"},  {"hp", "p3", "n1"},
     {"hp", "p3", "n2"}, {"hp", "p3", "n3"}, {"hp", "p3", "n4"}, {"hp", "p3", "n"},  {"hp", "p3", "na"},
     {"hp", "p3", "nh"}, {"hp", "p3", "no"}, {"hp", "p3", "o"},  {"hp", "p3", "oh"}, {"hp", "p3", "os"},
     {"hp", "p3", "p2"}, {"hp", "p3", "p3"}, {"hp", "p3", "p4"}, {"hp", "p3", "p5"}, {"hp", "p3", "s4"},
     {"hp", "p3", "s6"}, {"hp", "p3", "sh"}, {"hp", "p3", "ss"}, {"i", "p3", "i"},   {"n1", "p3", "n1"},
     {"n2", "p3", "n2"}, {"n3", "p3", "n3"}, {"n3", "p3", "o"},  {"n3", "p3", "oh"}, {"n4", "p3", "n4"},
     {"na", "p3", "na"}, {"nh", "p3", "nh"}, {"n", "p3", "n"},   {"n", "p3", "o"},   {"no", "p3", "no"},
     {"oh", "p3", "oh"}, {"o", "p3", "o"},   {"o", "p3", "p3"},  {"o", "p3", "p5"},  {"o", "p3", "s4"},
     {"o", "p3", "s6"},  {"os", "p3", "os"}, {"p2", "p3", "p2"}, {"p3", "p3", "p3"}, {"p4", "p3", "p4"},
     {"p5", "p3", "p5"}, {"s4", "p3", "s4"}, {"s6", "p3", "s6"}, {"sh", "p3", "sh"}, {"s", "p3", "s"},
     {"ss", "p3", "ss"}, {"br", "p4", "br"}, {"br", "p4", "o"},  {"c2", "p4", "c2"}, {"c2", "p4", "hp"},
     {"c2", "p4", "o"},  {"c3", "p4", "c3"}, {"c3", "p4", "n2"}, {"c3", "p4", "n3"}, {"c3", "p4", "n4"},
     {"c3", "p4", "n"},  {"c3", "p4", "na"}, {"c3", "p4", "nh"}, {"c3", "p4", "no"}, {"c3", "p4", "o"},
     {"c3", "p4", "oh"}, {"c3", "p4", "os"}, {"c3", "p4", "p2"}, {"c3", "p4", "p3"}, {"c3", "p4", "p4"},
     {"c3", "p4", "p5"}, {"c3", "p4", "sh"}, {"c3", "p4", "ss"}, {"ca", "p4", "ca"}, {"ca", "p4", "o"},
     {"cl", "p4", "cl"}, {"cl", "p4", "o"},  {"hp", "p4", "hp"}, {"hp", "p4", "n1"}, {"hp", "p4", "o"},
     {"hp", "p4", "p3"}, {"hp", "p4", "s"},  {"i", "p4", "i"},   {"i", "p4", "o"},   {"n1", "p4", "n1"},
     {"n1", "p4", "o"},  {"n2", "p4", "n2"}, {"n2", "p4", "o"},  {"n3", "p4", "o"},  {"n4", "p4", "o"},
     {"na", "p4", "o"},  {"nh", "p4", "nh"}, {"nh", "p4", "o"},  {"n", "p4", "o"},   {"no", "p4", "o"},
     {"oh", "p4", "oh"}, {"o", "p4", "o"},   {"o", "p4", "oh"},  {"o", "p4", "os"},  {"o", "p4", "p2"},
     {"o", "p4", "p3"},  {"o", "p4", "p4"},  {"o", "p4", "p5"},  {"o", "p4", "s4"},  {"o", "p4", "s6"},
     {"o", "p4", "s"},   {"o", "p4", "sh"},  {"os", "p4", "os"}, {"o", "p4", "ss"},  {"p2", "p4", "p2"},
     {"p3", "p4", "p3"}, {"p4", "p4", "p4"}, {"p5", "p4", "p5"}, {"s4", "p4", "s4"}, {"s6", "p4", "s6"},
     {"sh", "p4", "sh"}, {"s", "p4", "s"},   {"ss", "p4", "ss"}, {"br", "p5", "br"}, {"br", "p5", "o"},
     {"br", "p5", "oh"}, {"c1", "p5", "c1"}, {"c1", "p5", "o"},  {"c1", "p5", "oh"}, {"c2", "p5", "c2"},
     {"c2", "p5", "o"},  {"c2", "p5", "oh"}, {"c2", "p5", "os"}, {"c3", "p5", "c3"}, {"c3", "p5", "hp"},
     {"c3", "p5", "n3"}, {"c3", "p5", "o"},  {"c3", "p5", "oh"}, {"c3", "p5", "os"}, {"c3", "p5", "p4"},
     {"c3", "p5", "s"},  {"c3", "p5", "ss"}, {"ca", "p5", "ca"}, {"ca", "p5", "o"},  {"ca", "p5", "oh"},
     {"ca", "p5", "os"}, {"c", "p5", "c"},   {"cl", "p5", "cl"}, {"cl", "p5", "o"},  {"cl", "p5", "oh"},
     {"c", "p5", "o"},   {"c", "p5", "oh"},  {"f", "p5", "f"},   {"f", "p5", "o"},   {"f", "p5", "oh"},
     {"f", "p5", "os"},  {"f", "p5", "s"},   {"hp", "p5", "hp"}, {"hp", "p5", "n1"}, {"hp", "p5", "o"},
     {"hp", "p5", "oh"}, {"hp", "p5", "s"},  {"i", "p5", "i"},   {"i", "p5", "o"},   {"i", "p5", "oh"},
     {"n1", "p5", "n1"}, {"n1", "p5", "o"},  {"n2", "p5", "n2"}, {"n2", "p5", "o"},  {"n2", "p5", "oh"},
     {"n3", "p5", "n3"}, {"n3", "p5", "nh"}, {"n3", "p5", "o"},  {"n3", "p5", "oh"}, {"n3", "p5", "os"},
     {"n3", "p5", "s"},  {"n4", "p5", "n4"}, {"n4", "p5", "o"},  {"n4", "p5", "oh"}, {"n4", "p5", "os"},
     {"na", "p5", "na"}, {"na", "p5", "o"},  {"na", "p5", "oh"}, {"na", "p5", "os"}, {"nh", "p5", "nh"},
     {"nh", "p5", "o"},  {"nh", "p5", "oh"}, {"nh", "p5", "os"}, {"n", "p5", "n3"},  {"n", "p5", "n"},
     {"n", "p5", "o"},   {"n", "p5", "oh"},  {"no", "p5", "no"}, {"no", "p5", "o"},  {"no", "p5", "oh"},
     {"no", "p5", "os"}, {"n", "p5", "os"},  {"oh", "p5", "oh"}, {"oh", "p5", "os"}, {"oh", "p5", "p2"},
     {"oh", "p5", "p3"}, {"oh", "p5", "p4"}, {"oh", "p5", "p5"}, {"oh", "p5", "s4"}, {"oh", "p5", "s6"},
     {"oh", "p5", "s"},  {"oh", "p5", "sh"}, {"oh", "p5", "ss"}, {"o", "p5", "o"},   {"o", "p5", "oh"},
     {"o", "p5", "os"},  {"o", "p5", "p2"},  {"o", "p5", "p3"},  {"o", "p5", "p4"},  {"o", "p5", "p5"},
     {"o", "p5", "s4"},  {"o", "p5", "s6"},  {"o", "p5", "s"},   {"o", "p5", "sh"},  {"os", "p5", "os"},
     {"os", "p5", "p3"}, {"os", "p5", "p5"}, {"os", "p5", "s4"}, {"os", "p5", "s6"}, {"o", "p5", "ss"},
     {"os", "p5", "s"},  {"os", "p5", "sh"}, {"os", "p5", "ss"}, {"p2", "p5", "p2"}, {"p3", "p5", "p3"},
     {"p4", "p5", "p4"}, {"p5", "p5", "p5"}, {"s6", "p5", "s6"}, {"sh", "p5", "sh"}, {"sh", "p5", "ss"},
     {"s", "p5", "s"},   {"ss", "p5", "ss"}, {"cd", "pc", "n"},  {"cd", "pc", "na"}, {"cc", "pd", "n"},
     {"cc", "pd", "na"}, {"c2", "pe", "ca"}, {"c2", "pe", "ce"}, {"c2", "pe", "cg"}, {"c2", "pe", "n2"},
     {"c2", "pe", "ne"}, {"c2", "pe", "o"},  {"c2", "pe", "p2"}, {"c2", "pe", "pe"}, {"c2", "pe", "px"},
     {"c2", "pe", "py"}, {"c2", "pe", "s"},  {"c2", "pe", "sx"}, {"c2", "pe", "sy"}, {"ca", "pe", "n2"},
     {"ca", "pe", "o"},  {"ca", "pe", "p2"}, {"ca", "pe", "pf"}, {"ca", "pe", "s"},  {"c", "pe", "c2"},
     {"ce", "pe", "n2"}, {"ce", "pe", "o"},  {"ce", "pe", "p2"}, {"ce", "pe", "s"},  {"cg", "pe", "n2"},
     {"cg", "pe", "o"},  {"cg", "pe", "p2"}, {"cg", "pe", "s"},  {"n2", "pe", "n2"}, {"n2", "pe", "ne"},
     {"n2", "pe", "o"},  {"n2", "pe", "p2"}, {"n2", "pe", "pe"}, {"n2", "pe", "px"}, {"n2", "pe", "py"},
     {"n2", "pe", "s"},  {"n2", "pe", "sx"}, {"n2", "pe", "sy"}, {"ne", "pe", "o"},  {"ne", "pe", "p2"},
     {"ne", "pe", "s"},  {"o", "pe", "o"},   {"o", "pe", "p2"},  {"o", "pe", "pe"},  {"o", "pe", "px"},
     {"o", "pe", "py"},  {"o", "pe", "s"},   {"o", "pe", "sx"},  {"o", "pe", "sy"},  {"p2", "pe", "pe"},
     {"p2", "pe", "px"}, {"p2", "pe", "py"}, {"p2", "pe", "s"},  {"p2", "pe", "sx"}, {"p2", "pe", "sy"},
     {"pe", "pe", "s"},  {"px", "pe", "s"},  {"py", "pe", "s"},  {"s", "pe", "s"},   {"s", "pe", "sx"},
     {"s", "pe", "sy"},  {"c2", "pf", "ca"}, {"c2", "pf", "cf"}, {"c2", "pf", "ch"}, {"c2", "pf", "n2"},
     {"c2", "pf", "nf"}, {"c2", "pf", "o"},  {"c2", "pf", "p2"}, {"c2", "pf", "pf"}, {"c2", "pf", "px"},
     {"c2", "pf", "py"}, {"c2", "pf", "s"},  {"c2", "pf", "sx"}, {"c2", "pf", "sy"}, {"ca", "pf", "n2"},
     {"ca", "pf", "o"},  {"ca", "pf", "p2"}, {"ca", "pf", "pe"}, {"ca", "pf", "s"},  {"c", "pf", "c2"},
     {"cf", "pf", "n2"}, {"cf", "pf", "o"},  {"cf", "pf", "p2"}, {"cf", "pf", "s"},  {"ch", "pf", "n2"},
     {"ch", "pf", "o"},  {"ch", "pf", "p2"}, {"ch", "pf", "s"},  {"n2", "pf", "n2"}, {"n2", "pf", "nf"},
     {"n2", "pf", "o"},  {"n2", "pf", "p2"}, {"n2", "pf", "pf"}, {"n2", "pf", "px"}, {"n2", "pf", "py"},
     {"n2", "pf", "s"},  {"n2", "pf", "sx"}, {"n2", "pf", "sy"}, {"nf", "pf", "o"},  {"nf", "pf", "p2"},
     {"nf", "pf", "s"},  {"o", "pf", "o"},   {"o", "pf", "p2"},  {"o", "pf", "pf"},  {"o", "pf", "px"},
     {"o", "pf", "py"},  {"o", "pf", "s"},   {"o", "pf", "sx"},  {"o", "pf", "sy"},  {"p2", "pf", "pf"},
     {"p2", "pf", "px"}, {"p2", "pf", "py"}, {"p2", "pf", "s"},  {"p2", "pf", "sx"}, {"p2", "pf", "sy"},
     {"pf", "pf", "s"},  {"px", "pf", "s"},  {"py", "pf", "s"},  {"s", "pf", "s"},   {"s", "pf", "sx"},
     {"s", "pf", "sy"},  {"c3", "px", "ca"}, {"c3", "px", "ce"}, {"c3", "px", "cf"}, {"c3", "px", "ne"},
     {"c3", "px", "nf"}, {"c3", "px", "o"},  {"c3", "px", "pe"}, {"c3", "px", "pf"}, {"c3", "px", "py"},
     {"c3", "px", "sx"}, {"c3", "px", "sy"}, {"ca", "px", "ca"}, {"ca", "px", "o"},  {"c", "px", "c3"},
     {"ce", "px", "ce"}, {"ce", "px", "o"},  {"cf", "px", "cf"}, {"cf", "px", "o"},  {"c", "px", "o"},
     {"ne", "px", "ne"}, {"ne", "px", "o"},  {"nf", "px", "nf"}, {"nf", "px", "o"},  {"o", "px", "pe"},
     {"o", "px", "pf"},  {"o", "px", "py"},  {"o", "px", "sx"},  {"o", "px", "sy"},  {"pe", "px", "pe"},
     {"pf", "px", "pf"}, {"py", "px", "py"}, {"sx", "px", "sx"}, {"sy", "px", "sy"}, {"c3", "py", "n4"},
     {"c3", "py", "na"}, {"c3", "py", "o"},  {"c3", "py", "oh"}, {"c3", "py", "os"}, {"c3", "py", "px"},
     {"c3", "py", "py"}, {"c3", "py", "sx"}, {"ca", "py", "ca"}, {"ca", "py", "o"},  {"ca", "py", "oh"},
     {"ca", "py", "os"}, {"c", "py", "c3"},  {"c", "py", "c"},   {"ce", "py", "ce"}, {"ce", "py", "o"},
     {"ce", "py", "oh"}, {"ce", "py", "os"}, {"cf", "py", "cf"}, {"cf", "py", "o"},  {"cf", "py", "oh"},
     {"cf", "py", "os"}, {"c", "py", "o"},   {"c", "py", "oh"},  {"c", "py", "os"},  {"n3", "py", "ne"},
     {"n4", "py", "o"},  {"n4", "py", "py"}, {"na", "py", "o"},  {"na", "py", "py"}, {"ne", "py", "ne"},
     {"ne", "py", "o"},  {"ne", "py", "oh"}, {"ne", "py", "os"}, {"nf", "py", "nf"}, {"nf", "py", "o"},
     {"nf", "py", "oh"}, {"nf", "py", "os"}, {"oh", "py", "oh"}, {"oh", "py", "pe"}, {"oh", "py", "pf"},
     {"oh", "py", "px"}, {"oh", "py", "py"}, {"oh", "py", "sx"}, {"oh", "py", "sy"}, {"o", "py", "oh"},
     {"o", "py", "os"},  {"o", "py", "pe"},  {"o", "py", "pf"},  {"o", "py", "px"},  {"o", "py", "py"},
     {"os", "py", "os"}, {"os", "py", "py"}, {"os", "py", "sx"}, {"os", "py", "sy"}, {"o", "py", "sx"},
     {"o", "py", "sy"},  {"pe", "py", "pe"}, {"pf", "py", "pf"}, {"py", "py", "py"}, {"py", "py", "sx"},
     {"sy", "py", "sy"}, {"c1", "s2", "o"},  {"c2", "s2", "n2"}, {"c2", "s2", "o"},  {"cl", "s2", "n1"},
     {"f", "s2", "n1"},  {"n1", "s2", "o"},  {"n2", "s2", "o"},  {"o", "s2", "o"},   {"o", "s2", "s"},
     {"s", "s2", "s"},   {"br", "s4", "br"}, {"br", "s4", "c3"}, {"br", "s4", "o"},  {"c1", "s4", "c1"},
     {"c1", "s4", "o"},  {"c2", "s4", "c2"}, {"c2", "s4", "c3"}, {"c2", "s4", "o"},  {"c3", "s4", "c3"},
     {"c3", "s4", "ca"}, {"c3", "s4", "f"},  {"c3", "s4", "hs"}, {"c3", "s4", "i"},  {"c3", "s4", "n2"},
     {"c3", "s4", "n3"}, {"c3", "s4", "n"},  {"c3", "s4", "n4"}, {"c3", "s4", "na"}, {"c3", "s4", "nh"},
     {"c3", "s4", "no"}, {"c3", "s4", "o"},  {"c3", "s4", "oh"}, {"c3", "s4", "os"}, {"c3", "s4", "p2"},
     {"c3", "s4", "p3"}, {"c3", "s4", "p4"}, {"c3", "s4", "p5"}, {"c3", "s4", "s4"}, {"c3", "s4", "s"},
     {"c3", "s4", "s6"}, {"c3", "s4", "sh"}, {"c3", "s4", "ss"}, {"ca", "s4", "ca"}, {"ca", "s4", "o"},
     {"c", "s4", "c3"},  {"c", "s4", "c"},   {"cl", "s4", "cl"}, {"cl", "s4", "o"},  {"c", "s4", "o"},
     {"cx", "s4", "cx"}, {"cx", "s4", "o"},  {"f", "s4", "f"},   {"f", "s4", "o"},   {"f", "s4", "s"},
     {"hs", "s4", "hs"}, {"hs", "s4", "n1"}, {"hs", "s4", "o"},  {"i", "s4", "i"},   {"i", "s4", "o"},
     {"n1", "s4", "n1"}, {"n1", "s4", "o"},  {"n2", "s4", "n2"}, {"n2", "s4", "o"},  {"n3", "s4", "n3"},
     {"n3", "s4", "o"},  {"n4", "s4", "n4"}, {"n4", "s4", "o"},  {"na", "s4", "na"}, {"na", "s4", "o"},
     {"nh", "s4", "nh"}, {"nh", "s4", "o"},  {"n", "s4", "n"},   {"n", "s4", "o"},   {"no", "s4", "no"},
     {"no", "s4", "o"},  {"oh", "s4", "oh"}, {"o", "s4", "o"},   {"o", "s4", "oh"},  {"o", "s4", "os"},
     {"o", "s4", "p2"},  {"o", "s4", "p3"},  {"o", "s4", "p4"},  {"o", "s4", "p5"},  {"o", "s4", "s4"},
     {"o", "s4", "s"},   {"o", "s4", "s6"},  {"o", "s4", "sh"},  {"os", "s4", "os"}, {"o", "s4", "ss"},
     {"p2", "s4", "p2"}, {"p3", "s4", "p3"}, {"p5", "s4", "p5"}, {"s4", "s4", "s4"}, {"s4", "s4", "s6"},
     {"s6", "s4", "s6"}, {"sh", "s4", "sh"}, {"sh", "s4", "ss"}, {"s", "s4", "s"},   {"ss", "s4", "ss"},
     {"br", "s6", "br"}, {"br", "s6", "c3"}, {"br", "s6", "f"},  {"br", "s6", "o"},  {"c1", "s6", "c1"},
     {"c1", "s6", "o"},  {"c2", "s6", "c2"}, {"c2", "s6", "c3"}, {"c2", "s6", "o"},  {"c3", "s6", "c3"},
     {"c3", "s6", "ca"}, {"c3", "s6", "cy"}, {"c3", "s6", "f"},  {"c3", "s6", "hs"}, {"c3", "s6", "i"},
     {"c3", "s6", "n2"}, {"c3", "s6", "n3"}, {"c3", "s6", "n"},  {"c3", "s6", "n4"}, {"c3", "s6", "na"},
     {"c3", "s6", "nh"}, {"c3", "s6", "no"}, {"c3", "s6", "o"},  {"c3", "s6", "oh"}, {"c3", "s6", "os"},
     {"c3", "s6", "p2"}, {"c3", "s6", "p3"}, {"c3", "s6", "p4"}, {"c3", "s6", "p5"}, {"c3", "s6", "s4"},
     {"c3", "s6", "s"},  {"c3", "s6", "s6"}, {"c3", "s6", "sh"}, {"c3", "s6", "ss"}, {"ca", "s6", "ca"},
     {"ca", "s6", "o"},  {"c", "s6", "c3"},  {"c", "s6", "c"},   {"cc", "s6", "o"},  {"cl", "s6", "cl"},
     {"cl", "s6", "f"},  {"cl", "s6", "o"},  {"c", "s6", "o"},   {"c", "s6", "os"},  {"cx", "s6", "cx"},
     {"cy", "s6", "o"},  {"f", "s6", "f"},   {"f", "s6", "o"},   {"hs", "s6", "hs"}, {"hs", "s6", "n1"},
     {"hs", "s6", "o"},  {"i", "s6", "i"},   {"i", "s6", "o"},   {"n1", "s6", "n1"}, {"n1", "s6", "o"},
     {"n2", "s6", "n2"}, {"n2", "s6", "o"},  {"n2", "s6", "oh"}, {"n2", "s6", "os"}, {"n3", "s6", "n3"},
     {"n3", "s6", "o"},  {"n3", "s6", "os"}, {"n4", "s6", "n4"}, {"n4", "s6", "o"},  {"na", "s6", "na"},
     {"na", "s6", "o"},  {"nh", "s6", "nh"}, {"nh", "s6", "o"},  {"n", "s6", "n"},   {"n", "s6", "o"},
     {"no", "s6", "no"}, {"no", "s6", "o"},  {"n", "s6", "os"},  {"oh", "s6", "oh"}, {"oh", "s6", "os"},
     {"oh", "s6", "p2"}, {"o", "s6", "o"},   {"o", "s6", "oh"},  {"o", "s6", "os"},  {"o", "s6", "p2"},
     {"o", "s6", "p3"},  {"o", "s6", "p4"},  {"o", "s6", "p5"},  {"o", "s6", "s4"},  {"o", "s6", "s"},
     {"o", "s6", "s6"},  {"o", "s6", "sh"},  {"os", "s6", "os"}, {"o", "s6", "ss"},  {"p3", "s6", "p3"},
     {"p5", "s6", "p5"}, {"s4", "s6", "s4"}, {"s4", "s6", "s6"}, {"s6", "s6", "s6"}, {"sh", "s6", "sh"},
     {"sh", "s6", "ss"}, {"s", "s6", "s"},   {"ss", "s6", "ss"}, {"br", "sh", "hs"}, {"c1", "sh", "hs"},
     {"c2", "sh", "hs"}, {"c3", "sh", "hs"}, {"ca", "sh", "hs"}, {"cc", "sh", "hs"}, {"c", "sh", "hs"},
     {"f", "sh", "hs"},  {"hs", "sh", "hs"}, {"hs", "sh", "i"},  {"hs", "sh", "n1"}, {"hs", "sh", "n2"},
     {"hs", "sh", "n"},  {"hs", "sh", "n3"}, {"hs", "sh", "n4"}, {"hs", "sh", "na"}, {"hs", "sh", "nh"},
     {"hs", "sh", "no"}, {"hs", "sh", "o"},  {"hs", "sh", "oh"}, {"hs", "sh", "os"}, {"hs", "sh", "p2"},
     {"hs", "sh", "p3"}, {"hs", "sh", "p4"}, {"hs", "sh", "p5"}, {"hs", "sh", "s"},  {"hs", "sh", "s4"},
     {"hs", "sh", "s6"}, {"hs", "sh", "sh"}, {"hs", "sh", "ss"}, {"br", "ss", "br"}, {"br", "ss", "c3"},
     {"c1", "ss", "c1"}, {"c1", "ss", "c3"}, {"c2", "ss", "c2"}, {"c2", "ss", "c3"}, {"c2", "ss", "cy"},
     {"c2", "ss", "n2"}, {"c2", "ss", "na"}, {"c2", "ss", "os"}, {"c2", "ss", "ss"}, {"c3", "ss", "c3"},
     {"c3", "ss", "ca"}, {"c3", "ss", "cc"}, {"c3", "ss", "cd"}, {"c3", "ss", "cl"}, {"c3", "ss", "cy"},
     {"c3", "ss", "f"},  {"c3", "ss", "i"},  {"c3", "ss", "n1"}, {"c3", "ss", "n2"}, {"c3", "ss", "n3"},
     {"c3", "ss", "n"},  {"c3", "ss", "n4"}, {"c3", "ss", "na"}, {"c3", "ss", "nh"}, {"c3", "ss", "no"},
     {"c3", "ss", "o"},  {"c3", "ss", "oh"}, {"c3", "ss", "os"}, {"c3", "ss", "p2"}, {"c3", "ss", "p3"},
     {"c3", "ss", "p4"}, {"c3", "ss", "p5"}, {"c3", "ss", "s4"}, {"c3", "ss", "s"},  {"c3", "ss", "s6"},
     {"c3", "ss", "sh"}, {"c3", "ss", "ss"}, {"ca", "ss", "ca"}, {"ca", "ss", "cc"}, {"ca", "ss", "cd"},
     {"ca", "ss", "cl"}, {"ca", "ss", "n"},  {"ca", "ss", "na"}, {"ca", "ss", "nc"}, {"ca", "ss", "nd"},
     {"ca", "ss", "ss"}, {"c", "ss", "c2"},  {"c", "ss", "c3"},  {"c", "ss", "c"},   {"c", "ss", "cc"},
     {"cc", "ss", "cc"}, {"cc", "ss", "cd"}, {"cc", "ss", "n"},  {"cc", "ss", "na"}, {"cc", "ss", "nc"},
     {"cc", "ss", "os"}, {"cc", "ss", "ss"}, {"cd", "ss", "cd"}, {"cd", "ss", "n"},  {"cd", "ss", "na"},
     {"cd", "ss", "nd"}, {"cd", "ss", "os"}, {"cd", "ss", "ss"}, {"cl", "ss", "cl"}, {"cx", "ss", "cx"},
     {"f", "ss", "f"},   {"f", "ss", "ss"},  {"i", "ss", "i"},   {"n1", "ss", "n1"}, {"n2", "ss", "n2"},
     {"n3", "ss", "n3"}, {"n4", "ss", "n4"}, {"na", "ss", "na"}, {"nc", "ss", "nc"}, {"nd", "ss", "nd"},
     {"nh", "ss", "nh"}, {"n", "ss", "n"},   {"no", "ss", "no"}, {"oh", "ss", "oh"}, {"o", "ss", "o"},
     {"o", "ss", "p5"},  {"o", "ss", "s6"},  {"os", "ss", "os"}, {"o", "ss", "ss"},  {"p2", "ss", "p2"},
     {"p3", "ss", "p3"}, {"p5", "ss", "p5"}, {"s4", "ss", "s4"}, {"s4", "ss", "s6"}, {"s6", "ss", "s6"},
     {"sh", "ss", "sh"}, {"sh", "ss", "ss"}, {"s", "ss", "s"},   {"ss", "ss", "ss"}, {"c3", "sx", "ca"},
     {"c3", "sx", "cc"}, {"c3", "sx", "ce"}, {"c3", "sx", "cf"}, {"c3", "sx", "ne"}, {"c3", "sx", "nf"},
     {"c3", "sx", "o"},  {"c3", "sx", "pe"}, {"c3", "sx", "pf"}, {"c3", "sx", "px"}, {"c3", "sx", "py"},
     {"c3", "sx", "sx"}, {"c3", "sx", "sy"}, {"ca", "sx", "ca"}, {"ca", "sx", "o"},  {"c", "sx", "c3"},
     {"c", "sx", "c"},   {"cc", "sx", "o"},  {"ce", "sx", "ce"}, {"ce", "sx", "o"},  {"cf", "sx", "cf"},
     {"cf", "sx", "o"},  {"c", "sx", "o"},   {"ne", "sx", "ne"}, {"ne", "sx", "o"},  {"nf", "sx", "nf"},
     {"nf", "sx", "o"},  {"o", "sx", "pe"},  {"o", "sx", "pf"},  {"o", "sx", "px"},  {"o", "sx", "py"},
     {"o", "sx", "sx"},  {"o", "sx", "sy"},  {"pe", "sx", "pe"}, {"pf", "sx", "pf"}, {"py", "sx", "py"},
     {"sx", "sx", "sx"}, {"sy", "sx", "sy"}, {"c3", "sy", "ca"}, {"c3", "sy", "cc"}, {"c3", "sy", "ce"},
     {"c3", "sy", "cf"}, {"c3", "sy", "ne"}, {"c3", "sy", "nf"}, {"c3", "sy", "o"},  {"c3", "sy", "pe"},
     {"c3", "sy", "pf"}, {"c3", "sy", "px"}, {"c3", "sy", "py"}, {"c3", "sy", "sx"}, {"c3", "sy", "sy"},
     {"ca", "sy", "ca"}, {"ca", "sy", "cc"}, {"ca", "sy", "n3"}, {"ca", "sy", "n"},  {"ca", "sy", "ne"},
     {"ca", "sy", "nh"}, {"ca", "sy", "o"},  {"ca", "sy", "oh"}, {"ca", "sy", "os"}, {"c", "sy", "c3"},
     {"c", "sy", "c"},   {"cc", "sy", "n3"}, {"cc", "sy", "o"},  {"cd", "sy", "n3"}, {"cd", "sy", "nh"},
     {"cd", "sy", "o"},  {"ce", "sy", "ce"}, {"ce", "sy", "o"},  {"cf", "sy", "cf"}, {"cf", "sy", "o"},
     {"c", "sy", "o"},   {"f", "sy", "o"},   {"n2", "sy", "o"},  {"n3", "sy", "ne"}, {"n3", "sy", "o"},
     {"na", "sy", "na"}, {"nc", "sy", "nc"}, {"nd", "sy", "nd"}, {"ne", "sy", "ne"}, {"ne", "sy", "o"},
     {"nf", "sy", "nf"}, {"nf", "sy", "o"},  {"nh", "sy", "o"},  {"n", "sy", "o"},   {"o", "sy", "o"},
     {"o", "sy", "oh"},  {"o", "sy", "os"},  {"o", "sy", "pe"},  {"o", "sy", "pf"},  {"o", "sy", "px"},
     {"o", "sy", "py"},  {"o", "sy", "sx"},  {"o", "sy", "sy"},  {"py", "sy", "py"}, {"sx", "sy", "sx"},
     {"sy", "sy", "sy"}}};

static constexpr std::array<std::array<double, 2>, 4071> anglesParameters = {
    {{42.730, 104.520},  {0.000, 127.740},   {57.760, 180.000},  {54.930, 180.000},  {64.410, 180.000},
     {60.840, 180.000},  {56.280, 178.460},  {56.920, 180.000},  {55.270, 180.000},  {61.020, 180.000},
     {44.840, 178.380},  {44.730, 180.000},  {49.800, 180.000},  {67.170, 180.000},  {65.170, 180.000},
     {59.770, 180.000},  {59.090, 179.560},  {62.130, 177.180},  {61.230, 176.750},  {61.440, 179.270},
     {59.380, 180.000},  {66.790, 180.000},  {62.700, 176.650},  {62.770, 176.420},  {51.510, 180.000},
     {52.470, 169.630},  {50.940, 180.000},  {52.560, 176.170},  {68.490, 167.470},  {68.020, 174.380},
     {70.430, 179.970},  {68.520, 180.000},  {69.890, 173.220},  {58.200, 180.000},  {58.180, 179.010},
     {63.140, 180.000},  {63.070, 179.500},  {71.800, 172.980},  {51.750, 180.000},  {55.790, 178.520},
     {58.100, 178.500},  {52.830, 180.000},  {56.330, 180.000},  {43.980, 177.410},  {43.980, 177.410},
     {53.920, 180.000},  {58.190, 180.000},  {53.410, 180.000},  {93.200, 102.010},  {63.710, 169.700},
     {64.020, 177.430},  {64.720, 178.590},  {53.480, 171.200},  {70.640, 178.680},  {65.990, 180.000},
     {69.150, 171.790},  {72.750, 176.010},  {57.360, 180.000},  {56.350, 180.000},  {58.620, 180.000},
     {69.390, 172.330},  {72.880, 175.810},  {69.390, 172.330},  {59.550, 180.000},  {60.030, 180.000},
     {56.830, 180.000},  {60.910, 180.000},  {69.270, 180.000},  {60.960, 180.000},  {50.310, 180.000},
     {49.750, 180.000},  {49.750, 180.000},  {50.800, 180.000},  {89.430, 180.000},  {81.700, 180.000},
     {82.840, 180.000},  {84.910, 180.000},  {87.510, 180.000},  {84.960, 180.000},  {68.560, 115.060},
     {63.970, 118.960},  {63.710, 115.330},  {63.210, 121.590},  {43.040, 113.940},  {43.180, 113.280},
     {72.260, 116.770},  {70.340, 121.620},  {64.220, 124.920},  {67.990, 124.900},  {50.430, 121.370},
     {69.840, 121.810},  {64.330, 123.420},  {66.880, 117.000},  {70.220, 117.210},  {70.220, 117.210},
     {62.820, 122.850},  {64.500, 125.400},  {70.420, 103.300},  {68.110, 122.920},  {49.750, 122.540},
     {50.040, 120.940},  {50.300, 119.700},  {48.980, 126.450},  {56.280, 121.030},  {71.690, 122.980},
     {71.290, 126.010},  {70.330, 124.550},  {67.180, 121.520},  {68.860, 123.200},  {69.830, 121.380},
     {69.800, 124.990},  {67.520, 124.090},  {71.920, 130.890},  {71.640, 122.070},  {71.040, 121.890},
     {66.940, 115.100},  {59.410, 124.830},  {61.010, 119.760},  {58.230, 125.970},  {79.550, 119.840},
     {79.490, 120.010},  {77.520, 129.370},  {77.030, 125.700},  {79.470, 122.860},  {62.700, 116.520},
     {63.220, 125.380},  {63.160, 125.640},  {64.190, 123.020},  {63.960, 123.870},  {45.300, 119.250},
     {45.660, 117.300},  {45.150, 120.000},  {66.470, 123.520},  {66.790, 114.800},  {64.950, 122.540},
     {66.960, 122.150},  {66.960, 122.150},  {66.690, 118.590},  {67.880, 123.180},  {68.500, 115.040},
     {68.770, 112.690},  {62.400, 122.740},  {79.470, 115.440},  {77.990, 119.660},  {63.510, 117.880},
     {45.280, 123.300},  {67.930, 120.700},  {63.870, 119.700},  {66.570, 118.880},  {49.190, 120.330},
     {49.070, 120.760},  {69.460, 122.960},  {72.800, 123.590},  {49.070, 120.760},  {62.430, 123.900},
     {49.380, 122.290},  {49.570, 121.190},  {68.820, 123.710},  {70.640, 120.720},  {68.450, 119.650},
     {73.660, 123.080},  {70.900, 123.270},  {70.470, 122.520},  {49.570, 121.190},  {47.670, 121.330},
     {48.000, 119.700},  {64.100, 114.270},  {43.820, 113.770},  {43.940, 113.200},  {46.610, 115.890},
     {70.670, 109.600},  {51.250, 110.000},  {52.400, 120.690},  {50.480, 113.570},  {51.030, 113.220},
     {52.870, 119.630},  {51.550, 115.640},  {49.390, 113.380},  {52.230, 113.700},  {54.230, 118.470},
     {52.410, 120.160},  {48.230, 126.390},  {52.760, 119.620},  {51.850, 113.930},  {38.020, 117.650},
     {51.830, 120.760},  {52.390, 120.540},  {52.440, 113.540},  {50.490, 113.400},  {51.180, 112.420},
     {52.480, 121.180},  {52.480, 121.180},  {51.290, 116.680},  {49.640, 112.140},  {55.300, 117.230},
     {52.340, 116.180},  {52.430, 112.690},  {44.050, 121.480},  {41.120, 114.310},  {40.790, 117.860},
     {39.360, 120.100},  {43.490, 121.460},  {43.490, 121.460},  {58.460, 118.740},  {54.190, 115.300},
     {54.950, 115.700},  {53.880, 116.600},  {54.480, 111.740},  {54.640, 116.720},  {37.810, 118.920},
     {52.420, 120.400},  {50.350, 114.040},  {49.730, 119.100},  {52.030, 113.360},  {49.640, 112.120},
     {52.330, 116.220},  {51.650, 116.110},  {40.610, 117.190},  {39.440, 119.580},  {54.000, 116.120},
     {54.150, 115.450},  {53.550, 115.630},  {54.900, 115.620},  {48.420, 113.030},  {60.960, 117.940},
     {73.610, 124.150},  {77.960, 113.820},  {72.030, 113.050},  {71.710, 123.620},  {72.620, 124.270},
     {74.360, 122.080},  {74.320, 119.820},  {79.560, 129.770},  {73.450, 118.470},  {67.720, 113.930},
     {81.510, 116.260},  {73.650, 109.330},  {73.020, 123.570},  {74.860, 118.760},  {82.780, 120.060},
     {73.280, 122.720},  {74.460, 112.720},  {74.050, 117.160},  {74.320, 114.290},  {85.090, 111.550},
     {70.560, 125.950},  {71.550, 113.230},  {74.570, 105.420},  {70.890, 125.380},  {74.200, 109.140},
     {69.430, 113.900},  {84.580, 111.060},  {76.030, 114.330},  {80.230, 121.690},  {76.690, 121.230},
     {81.200, 127.680},  {74.210, 115.800},  {62.800, 129.800},  {60.610, 115.540},  {58.010, 121.850},
     {99.130, 120.320},  {99.290, 119.950},  {99.280, 119.970},  {102.460, 110.480}, {100.350, 117.820},
     {100.060, 121.670}, {100.540, 120.240}, {67.460, 109.030},  {62.770, 111.800},  {63.030, 109.250},
     {62.920, 110.370},  {43.120, 103.040},  {42.340, 107.100},  {42.400, 106.500},  {66.500, 109.000},
     {65.000, 111.110},  {64.290, 111.420},  {64.930, 110.950},  {64.290, 114.290},  {64.360, 114.060},
     {62.890, 110.630},  {48.350, 109.290},  {48.250, 109.750},  {47.760, 112.050},  {67.030, 112.590},
     {66.530, 112.040},  {67.410, 112.080},  {67.250, 112.790},  {69.490, 109.140},  {69.270, 108.880},
     {63.930, 112.080},  {63.530, 111.440},  {63.710, 112.450},  {64.000, 112.490},  {64.460, 110.890},
     {64.080, 111.750},  {63.960, 112.190},  {62.050, 112.070},  {63.650, 112.620},  {66.760, 101.330},
     {66.520, 110.960},  {47.030, 110.460},  {46.840, 111.190},  {47.030, 110.490},  {46.830, 111.450},
     {67.090, 108.990},  {66.470, 111.520},  {66.730, 111.380},  {66.240, 113.300},  {67.100, 110.270},
     {68.180, 110.210},  {68.450, 108.480},  {79.190, 109.730},  {80.520, 104.970},  {63.210, 110.630},
     {63.250, 112.090},  {63.570, 111.920},  {64.690, 108.100},  {63.650, 111.220},  {63.900, 110.370},
     {62.200, 110.330},  {63.300, 111.820},  {63.630, 109.620},  {66.220, 109.410},  {46.360, 110.070},
     {46.020, 111.590},  {46.370, 110.050},  {46.020, 111.740},  {58.480, 110.960},  {66.640, 108.860},
     {66.400, 109.160},  {66.180, 110.380},  {64.450, 114.320},  {65.850, 112.130},  {65.730, 112.810},
     {66.390, 110.450},  {65.210, 109.270},  {68.590, 112.970},  {67.720, 109.430},  {67.780, 108.420},
     {60.410, 113.190},  {61.390, 112.320},  {78.670, 110.070},  {79.700, 110.000},  {77.180, 113.020},
     {77.330, 112.690},  {79.490, 109.910},  {63.660, 112.260},  {63.760, 112.940},  {65.180, 108.080},
     {63.810, 112.330},  {62.200, 111.310},  {63.690, 112.100},  {66.140, 111.760},  {46.780, 110.950},
     {47.030, 109.660},  {46.960, 110.150},  {46.690, 111.440},  {65.920, 112.490},  {66.180, 112.130},
     {64.870, 114.540},  {66.290, 112.430},  {66.270, 112.810},  {68.200, 106.510},  {68.200, 106.510},
     {66.640, 111.410},  {67.940, 110.550},  {68.190, 108.890},  {61.350, 113.410},  {79.570, 111.360},
     {78.350, 110.660},  {78.680, 110.800},  {64.560, 112.640},  {64.140, 111.320},  {63.790, 110.530},
     {64.060, 111.610},  {64.130, 110.990},  {63.940, 112.690},  {63.640, 114.440},  {67.300, 102.350},
     {63.850, 112.550},  {63.810, 113.170},  {64.020, 111.980},  {66.730, 111.130},  {47.030, 111.620},
     {47.200, 110.860},  {47.170, 111.020},  {62.300, 111.160},  {66.850, 110.470},  {66.670, 111.570},
     {64.880, 115.580},  {66.740, 112.050},  {66.430, 113.390},  {68.370, 107.040},  {66.500, 113.020},
     {68.010, 111.510},  {68.570, 108.820},  {60.750, 116.230},  {77.340, 114.020},  {78.390, 111.090},
     {64.080, 111.090},  {65.520, 107.990},  {66.530, 111.800},  {47.030, 111.620},  {47.200, 110.860},
     {66.960, 110.590},  {67.110, 110.830},  {68.370, 107.040},  {67.060, 111.110},  {68.280, 110.640},
     {67.810, 111.280},  {77.340, 114.020},  {78.450, 110.910},  {64.240, 111.440},  {66.340, 102.820},
     {47.280, 109.650},  {47.000, 110.980},  {66.430, 111.900},  {67.090, 110.410},  {68.000, 111.050},
     {68.640, 108.100},  {78.300, 111.100},  {66.820, 109.980},  {66.330, 102.850},  {47.350, 109.340},
     {47.000, 110.980},  {66.510, 111.640},  {47.630, 107.660},  {47.160, 109.690},  {47.200, 109.680},
     {47.230, 109.540},  {62.700, 111.030},  {63.600, 109.020},  {43.710, 105.930},  {43.490, 107.140},
     {43.360, 107.650},  {64.920, 111.400},  {78.390, 112.940},  {66.920, 109.550},  {66.590, 111.140},
     {65.070, 114.210},  {66.670, 111.560},  {66.810, 111.370},  {67.360, 109.430},  {68.650, 108.700},
     {68.030, 109.820},  {62.230, 110.410},  {80.060, 110.220},  {79.050, 108.820},  {78.090, 111.580},
     {63.530, 112.580},  {47.040, 109.640},  {46.920, 110.200},  {46.380, 112.810},  {65.830, 113.220},
     {68.880, 101.510},  {66.220, 112.590},  {68.100, 109.970},  {68.400, 108.160},  {47.000, 107.880},
     {46.510, 110.170},  {65.630, 112.720},  {67.220, 111.560},  {68.450, 106.790},  {71.260, 107.160},
     {51.570, 107.850},  {51.360, 108.410},  {51.050, 110.010},  {51.330, 108.920},  {69.230, 110.400},
     {70.660, 110.610},  {63.700, 107.250},  {81.220, 109.670},  {78.640, 111.890},  {39.180, 109.550},
     {49.990, 107.310},  {49.260, 109.610},  {49.390, 109.920},  {49.820, 109.320},  {49.900, 109.450},
     {50.110, 108.570},  {50.110, 108.570},  {49.730, 109.960},  {48.660, 105.150},  {52.530, 117.190},
     {50.970, 109.880},  {50.840, 108.820},  {42.870, 107.990},  {54.280, 108.660},  {52.120, 112.600},
     {55.510, 108.110},  {53.660, 109.210},  {53.660, 109.340},  {54.210, 108.690},  {55.250, 108.090},
     {39.000, 109.190},  {38.690, 104.990},  {49.080, 110.220},  {49.370, 109.800},  {50.220, 107.380},
     {50.270, 107.660},  {49.850, 109.470},  {49.850, 109.470},  {49.600, 110.330},  {47.830, 108.690},
     {54.380, 108.970},  {51.290, 108.300},  {50.840, 108.580},  {54.330, 108.580},  {53.560, 106.750},
     {55.940, 106.540},  {54.020, 107.870},  {53.590, 109.750},  {49.730, 108.390},  {49.910, 109.370},
     {49.910, 109.370},  {49.530, 110.780},  {50.090, 112.030},  {53.680, 109.270},  {39.430, 108.350},
     {38.620, 104.990},  {49.290, 109.500},  {49.420, 109.800},  {49.010, 107.900},  {49.780, 109.500},
     {49.900, 109.500},  {49.380, 111.540},  {48.190, 107.200},  {51.070, 109.500},  {50.870, 108.700},
     {41.380, 110.180},  {41.660, 110.140},  {42.040, 109.590},  {42.540, 109.640},  {42.240, 109.740},
     {42.560, 109.540},  {54.570, 107.500},  {55.480, 108.200},  {53.990, 107.870},  {53.800, 108.760},
     {39.040, 110.740},  {49.020, 107.910},  {61.980, 113.120},  {71.090, 105.070},  {69.890, 107.700},
     {69.260, 111.060},  {70.150, 111.820},  {70.040, 111.230},  {69.610, 109.590},  {68.790, 113.290},
     {68.790, 113.290},  {69.740, 110.080},  {70.710, 110.630},  {71.150, 108.330},  {64.440, 109.510},
     {81.950, 107.730},  {67.130, 113.320},  {69.060, 113.490},  {71.270, 109.060},  {69.960, 110.610},
     {69.340, 112.430},  {69.280, 115.410},  {69.960, 110.610},  {69.340, 112.430},  {69.280, 115.410},
     {71.410, 105.870},  {70.470, 112.360},  {71.260, 108.930},  {63.700, 112.500},  {81.670, 108.880},
     {68.820, 112.340},  {69.390, 111.030},  {68.780, 113.810},  {70.540, 108.340},  {70.360, 112.540},
     {68.370, 104.470},  {71.140, 109.160},  {64.380, 110.050},  {72.710, 109.230},  {72.380, 109.210},
     {65.440, 108.860},  {80.110, 115.460},  {74.430, 122.300},  {71.720, 110.240},  {65.470, 108.360},
     {82.720, 107.980},  {61.280, 110.480},  {61.730, 110.160},  {62.800, 110.130},  {78.880, 111.300},
     {99.950, 112.290},  {100.300, 113.520}, {102.050, 111.750}, {97.420, 116.260},  {99.850, 110.730},
     {93.400, 123.350},  {99.950, 110.570},  {67.310, 117.600},  {63.480, 118.130},  {64.700, 120.000},
     {65.860, 120.000},  {62.950, 120.000},  {64.690, 120.600},  {62.240, 120.000},  {62.410, 116.800},
     {63.840, 120.630},  {63.700, 120.630},  {63.590, 120.630},  {66.590, 118.780},  {67.330, 116.660},
     {67.180, 119.970},  {65.990, 120.100},  {65.990, 120.100},  {64.880, 120.660},  {64.880, 120.660},
     {65.900, 120.050},  {65.900, 120.050},  {62.920, 119.400},  {67.240, 119.070},  {67.090, 119.070},
     {64.480, 120.830},  {63.770, 120.860},  {67.510, 118.950},  {48.240, 121.090},  {48.460, 120.010},
     {58.590, 118.470},  {68.920, 118.500},  {70.950, 119.570},  {67.280, 118.410},  {67.970, 119.890},
     {70.210, 118.340},  {69.160, 122.630},  {70.140, 119.720},  {70.140, 119.720},  {67.740, 119.880},
     {67.740, 119.880},  {69.340, 120.130},  {66.880, 119.540},  {71.850, 123.290},  {69.850, 119.940},
     {69.790, 119.200},  {61.520, 114.360},  {60.320, 120.730},  {60.930, 120.300},  {61.240, 120.280},
     {60.250, 120.450},  {60.250, 120.450},  {60.340, 120.530},  {61.180, 119.980},  {78.120, 119.150},
     {78.690, 120.540},  {78.750, 122.550},  {77.610, 121.780},  {78.500, 119.930},  {76.800, 119.180},
     {78.020, 119.890},  {62.610, 118.060},  {62.650, 120.000},  {64.640, 120.140},  {64.690, 124.300},
     {69.060, 118.450},  {69.340, 117.500},  {67.440, 119.850},  {68.300, 117.380},  {68.080, 118.140},
     {65.330, 121.530},  {46.510, 115.900},  {62.630, 118.720},  {62.600, 120.310},  {65.810, 116.150},
     {67.710, 117.940},  {64.400, 130.800},  {64.400, 130.800},  {67.180, 119.390},  {48.230, 120.030},
     {48.030, 121.080},  {73.000, 108.790},  {68.640, 123.720},  {68.740, 121.520},  {69.340, 120.960},
     {80.870, 112.750},  {80.930, 111.180},  {47.860, 121.080},  {80.860, 111.180},  {68.050, 117.500},
     {71.690, 114.580},  {49.480, 116.020},  {51.880, 114.650},  {51.820, 115.940},  {51.460, 118.360},
     {51.460, 118.360},  {52.300, 111.150},  {53.660, 116.190},  {51.760, 116.350},  {50.700, 122.110},
     {50.700, 122.110},  {52.970, 116.000},  {39.570, 122.560},  {62.290, 119.280},  {70.730, 117.030},
     {75.050, 120.000},  {73.800, 119.600},  {67.650, 116.820},  {76.480, 107.650},  {70.600, 127.070},
     {72.480, 118.620},  {70.780, 127.190},  {70.900, 127.320},  {71.250, 126.080},  {73.200, 116.950},
     {73.570, 117.300},  {72.540, 119.660},  {81.390, 117.590},  {81.120, 119.300},  {70.670, 128.740},
     {72.770, 118.860},  {70.670, 128.740},  {72.770, 118.860},  {71.400, 120.980},  {69.660, 123.860},
     {69.660, 123.860},  {71.290, 116.160},  {67.420, 117.140},  {72.630, 120.000},  {78.210, 126.820},
     {74.010, 113.730},  {58.980, 121.200},  {59.440, 121.460},  {60.760, 120.000},  {104.060, 105.810},
     {105.770, 105.810}, {98.150, 120.240},  {98.380, 125.140},  {100.760, 115.150}, {66.910, 113.100},
     {63.340, 110.740},  {63.190, 121.460},  {65.090, 115.320},  {69.920, 122.340},  {67.170, 116.780},
     {48.650, 115.950},  {72.770, 119.120},  {81.850, 119.160},  {62.820, 116.050},  {62.590, 118.540},
     {63.240, 118.000},  {63.500, 117.020},  {63.470, 116.250},  {63.300, 116.860},  {64.260, 115.000},
     {64.260, 115.000},  {62.560, 111.990},  {66.930, 110.700},  {46.110, 114.400},  {46.010, 115.220},
     {56.870, 112.940},  {66.620, 114.530},  {64.610, 112.260},  {67.860, 115.150},  {68.090, 111.390},
     {67.430, 113.380},  {68.030, 123.110},  {69.840, 112.200},  {69.260, 111.960},  {58.900, 116.420},
     {58.320, 118.900},  {58.620, 114.850},  {58.620, 114.850},  {58.600, 115.600},  {58.850, 118.160},
     {75.480, 114.790},  {75.500, 114.720},  {78.510, 123.730},  {78.430, 114.210},  {78.990, 114.320},
     {75.280, 113.970},  {75.800, 114.280},  {63.030, 118.580},  {64.370, 115.570},  {63.940, 117.130},
     {63.290, 118.610},  {62.800, 120.470},  {46.520, 115.140},  {46.800, 114.120},  {68.470, 115.140},
     {67.750, 114.390},  {68.670, 123.440},  {70.110, 113.440},  {68.780, 115.540},  {79.130, 123.040},
     {77.270, 118.630},  {79.040, 115.130},  {63.980, 115.680},  {61.820, 124.890},  {62.260, 124.560},
     {64.600, 121.420},  {63.270, 126.110},  {65.400, 124.420},  {66.340, 121.390},  {69.090, 117.020},
     {48.690, 122.720},  {67.740, 126.900},  {70.020, 121.060},  {61.720, 116.860},  {61.830, 126.430},
     {64.660, 115.970},  {64.810, 119.450},  {65.450, 117.840},  {45.110, 121.520},  {65.940, 126.280},
     {66.540, 118.360},  {65.440, 122.990},  {65.880, 121.000},  {65.890, 123.750},  {67.480, 117.090},
     {77.460, 121.680},  {62.300, 111.680},  {61.730, 118.340},  {67.660, 111.040},  {68.230, 113.510},
     {62.580, 127.870},  {45.570, 128.660},  {46.400, 124.040},  {68.240, 118.420},  {67.790, 120.310},
     {67.840, 123.280},  {67.460, 122.450},  {70.020, 116.510},  {69.540, 116.090},  {78.690, 120.980},
     {65.620, 120.880},  {64.900, 112.750},  {63.420, 121.160},  {64.020, 111.670},  {63.550, 122.950},
     {63.720, 122.690},  {64.820, 115.970},  {67.880, 110.700},  {68.160, 114.190},  {63.140, 126.050},
     {65.650, 123.920},  {64.740, 121.850},  {65.230, 121.510},  {65.730, 112.790},  {63.360, 122.370},
     {64.640, 115.680},  {66.350, 119.410},  {64.980, 118.140},  {45.560, 129.470},  {47.460, 119.260},
     {62.790, 116.010},  {69.460, 121.150},  {67.950, 119.890},  {72.210, 106.800},  {69.950, 113.420},
     {71.150, 112.560},  {68.510, 119.190},  {69.230, 119.670},  {69.380, 117.090},  {63.840, 115.360},
     {80.780, 115.020},  {74.830, 128.360},  {64.020, 111.670},  {67.630, 121.160},  {63.480, 129.500},
     {61.780, 123.720},  {67.420, 121.080},  {47.190, 129.110},  {48.350, 122.890},  {70.720, 115.520},
     {72.910, 109.420},  {70.990, 114.980},  {68.380, 125.040},  {65.780, 128.950},  {69.580, 124.030},
     {69.960, 120.300},  {82.940, 111.220},  {76.410, 125.160},  {66.420, 124.140},  {66.980, 121.700},
     {67.220, 123.910},  {68.210, 119.170},  {78.460, 120.940},  {66.160, 116.870},  {67.510, 122.350},
     {78.880, 120.700},  {47.130, 115.450},  {46.990, 117.020},  {63.840, 121.610},  {63.930, 122.510},
     {79.050, 119.850},  {68.530, 120.890},  {68.110, 116.330},  {70.190, 111.860},  {66.280, 123.150},
     {67.520, 116.400},  {70.070, 112.910},  {67.110, 119.880},  {68.910, 125.710},  {70.150, 113.450},
     {71.160, 112.580},  {67.710, 119.810},  {70.500, 112.300},  {78.050, 127.940},  {80.330, 112.520},
     {65.680, 127.750},  {68.010, 118.080},  {64.770, 116.170},  {63.880, 117.460},  {70.190, 111.860},
     {68.310, 115.760},  {68.300, 113.750},  {68.910, 125.710},  {70.770, 113.840},  {70.500, 112.300},
     {64.340, 115.790},  {64.040, 116.890},  {63.950, 116.250},  {46.930, 114.880},  {46.930, 115.220},
     {68.880, 115.010},  {69.270, 122.920},  {70.250, 114.300},  {70.050, 112.620},  {81.120, 117.800},
     {80.920, 110.390},  {64.070, 116.780},  {46.930, 115.220},  {68.800, 115.290},  {69.270, 122.920},
     {70.490, 113.530},  {70.720, 110.510},  {81.120, 117.800},  {65.440, 115.380},  {47.800, 113.900},
     {70.210, 122.310},  {44.620, 116.360},  {50.390, 117.620},  {50.220, 119.660},  {50.000, 120.030},
     {51.390, 119.110},  {52.270, 111.890},  {54.360, 117.750},  {50.870, 115.610},  {49.760, 122.100},
     {49.290, 123.700},  {50.130, 125.380},  {51.300, 116.330},  {53.390, 122.000},  {44.850, 115.430},
     {49.820, 121.500},  {50.730, 116.540},  {51.410, 118.880},  {52.490, 110.860},  {42.350, 121.760},
     {53.490, 121.640},  {65.440, 115.380},  {47.800, 113.900},  {70.210, 122.310},  {63.330, 111.300},
     {63.490, 112.000},  {43.460, 109.900},  {64.280, 121.510},  {77.210, 127.600},  {67.530, 112.140},
     {70.660, 121.830},  {74.780, 112.020},  {68.480, 124.900},  {73.310, 117.260},  {80.050, 117.040},
     {79.760, 120.550},  {68.190, 116.060},  {72.510, 118.690},  {72.700, 115.660},  {69.310, 121.540},
     {81.790, 119.860},  {70.880, 128.170},  {69.290, 129.660},  {72.410, 120.110},  {69.900, 122.680},
     {72.800, 122.190},  {74.240, 115.060},  {79.410, 124.920},  {84.180, 114.510},  {76.960, 127.600},
     {79.280, 123.080},  {82.750, 116.990},  {72.930, 115.960},  {72.780, 117.270},  {81.210, 122.040},
     {74.770, 114.480},  {70.450, 122.180},  {70.960, 120.010},  {71.200, 122.710},  {72.220, 116.850},
     {71.010, 117.590},  {80.690, 121.100},  {80.680, 123.050},  {67.160, 120.990},  {68.200, 113.230},
     {68.180, 111.390},  {78.460, 132.010},  {100.050, 121.280}, {98.380, 121.770},  {85.450, 64.600},
     {68.690, 114.490},  {68.880, 122.820},  {70.490, 112.320},  {70.060, 111.480},  {70.140, 90.550},
     {75.430, 91.540},   {64.270, 135.040},  {69.090, 112.480},  {74.550, 94.890},   {63.270, 126.110},
     {64.430, 128.220},  {69.090, 117.020},  {65.270, 125.410},  {48.690, 122.720},  {67.740, 126.900},
     {70.530, 119.310},  {64.050, 117.810},  {64.810, 119.450},  {64.660, 115.970},  {65.260, 117.840},
     {45.110, 121.520},  {64.650, 131.550},  {65.600, 121.760},  {65.670, 122.140},  {66.940, 119.910},
     {65.900, 120.920},  {67.630, 116.540},  {77.510, 121.530},  {68.230, 113.510},  {67.660, 111.040},
     {65.000, 125.100},  {45.570, 128.660},  {46.400, 124.040},  {72.510, 104.870},  {67.030, 123.450},
     {70.230, 115.050},  {67.650, 120.810},  {69.080, 119.320},  {70.040, 114.450},  {79.130, 119.640},
     {65.380, 121.760},  {63.560, 117.570},  {63.410, 121.180},  {63.550, 122.950},  {65.280, 121.320},
     {68.010, 119.800},  {68.160, 114.190},  {64.080, 126.280},  {64.920, 126.050},  {61.810, 123.620},
     {63.930, 122.130},  {63.720, 122.690},  {63.000, 123.100},  {47.190, 129.110},  {48.350, 122.890},
     {62.750, 116.190},  {70.720, 115.520},  {72.910, 109.420},  {69.420, 123.820},  {72.030, 111.680},
     {68.700, 123.880},  {69.540, 123.710},  {69.960, 120.300},  {82.380, 112.740},  {76.890, 124.690},
     {67.880, 110.700},  {65.800, 122.560},  {62.580, 127.560},  {63.320, 127.380},  {63.170, 120.930},
     {45.560, 129.470},  {47.020, 121.510},  {69.520, 121.150},  {67.950, 119.890},  {72.210, 106.800},
     {71.150, 112.560},  {67.440, 122.020},  {68.260, 120.050},  {68.090, 123.300},  {69.300, 117.360},
     {63.840, 115.360},  {78.930, 120.470},  {68.130, 124.900},  {66.090, 124.600},  {67.940, 120.490},
     {66.910, 121.180},  {68.380, 117.800},  {77.470, 123.670},  {46.770, 118.190},  {46.990, 117.020},
     {63.230, 125.300},  {68.580, 120.890},  {68.190, 116.060},  {67.450, 121.860},  {64.310, 130.800},
     {69.870, 114.020},  {68.070, 118.550},  {50.390, 117.620},  {50.220, 119.660},  {51.390, 119.110},
     {50.000, 120.030},  {52.270, 111.890},  {54.360, 117.750},  {50.820, 115.830},  {49.760, 122.100},
     {50.130, 125.380},  {49.290, 123.700},  {51.300, 116.330},  {53.390, 122.000},  {49.820, 121.500},
     {51.410, 118.880},  {50.730, 116.540},  {52.490, 110.860},  {42.350, 121.760},  {53.490, 121.640},
     {74.780, 112.020},  {70.890, 121.040},  {72.430, 116.980},  {84.890, 111.460},  {73.390, 115.840},
     {72.410, 120.110},  {73.040, 120.890},  {73.420, 117.640},  {84.180, 114.510},  {69.470, 125.580},
     {72.140, 117.470},  {81.790, 119.860},  {72.930, 115.960},  {73.160, 116.070},  {81.480, 121.220},
     {70.500, 122.010},  {70.990, 123.410},  {69.060, 126.700},  {72.210, 116.880},  {80.730, 122.890},
     {75.470, 111.610},  {78.460, 132.010},  {99.630, 122.300},  {98.720, 121.620},  {64.300, 122.890},
     {65.160, 123.080},  {65.550, 123.840},  {65.730, 123.080},  {66.680, 121.580},  {62.220, 119.510},
     {48.640, 125.580},  {49.560, 121.100},  {72.730, 117.850},  {70.340, 128.700},  {69.290, 119.190},
     {69.730, 118.320},  {70.180, 123.780},  {61.560, 118.240},  {61.300, 118.760},  {60.970, 119.720},
     {61.150, 122.130},  {78.010, 119.870},  {78.410, 120.350},  {62.810, 119.110},  {63.490, 118.180},
     {63.910, 116.590},  {64.510, 122.180},  {63.790, 118.480},  {66.940, 122.640},  {67.240, 120.750},
     {65.740, 119.900},  {63.870, 117.820},  {64.120, 118.640},  {63.840, 119.620},  {64.090, 127.310},
     {62.350, 114.220},  {46.710, 116.860},  {47.080, 115.120},  {68.510, 120.720},  {67.770, 122.500},
     {67.850, 115.510},  {68.500, 117.180},  {68.570, 115.580},  {77.470, 117.730},  {65.820, 120.420},
     {63.430, 116.630},  {62.550, 122.540},  {63.790, 117.980},  {63.280, 130.360},  {65.060, 125.790},
     {63.740, 126.070},  {63.460, 120.890},  {64.260, 126.410},  {64.570, 118.320},  {47.610, 115.400},
     {47.630, 115.360},  {62.010, 115.400},  {68.910, 121.690},  {67.360, 119.170},  {72.720, 88.220},
     {65.140, 122.940},  {49.760, 115.940},  {64.550, 118.740},  {65.490, 124.050},  {61.600, 117.930},
     {47.060, 118.000},  {47.500, 115.900},  {66.840, 127.150},  {68.520, 123.000},  {69.180, 116.890},
     {66.060, 123.940},  {60.530, 137.740},  {49.030, 123.760},  {50.180, 118.290},  {72.090, 120.030},
     {72.630, 108.180},  {69.450, 121.520},  {70.830, 121.620},  {65.510, 118.510},  {47.910, 116.610},
     {69.540, 119.500},  {69.590, 121.430},  {46.590, 117.260},  {66.170, 118.730},  {67.880, 115.220},
     {68.230, 117.920},  {69.050, 113.780},  {52.650, 116.360},  {52.370, 121.520},  {49.720, 115.810},
     {52.770, 115.960},  {52.850, 119.510},  {49.160, 118.590},  {50.580, 114.990},  {40.610, 120.110},
     {40.640, 119.330},  {40.810, 117.900},  {41.340, 118.720},  {52.960, 115.450},  {53.580, 114.860},
     {71.550, 124.860},  {74.520, 118.130},  {81.510, 117.230},  {68.070, 123.870},  {71.870, 112.910},
     {73.250, 118.130},  {57.690, 129.790},  {64.070, 108.060},  {97.090, 120.320},  {98.050, 119.970},
     {64.300, 122.890},  {65.160, 123.080},  {65.810, 122.050},  {65.730, 123.080},  {66.510, 122.220},
     {49.560, 121.100},  {70.340, 128.700},  {69.730, 118.320},  {61.560, 118.240},  {61.300, 118.760},
     {60.970, 119.720},  {61.150, 122.130},  {78.010, 119.870},  {78.410, 120.350},  {62.650, 119.700},
     {63.300, 118.280},  {64.550, 122.030},  {63.520, 118.010},  {66.670, 123.650},  {64.500, 115.530},
     {62.810, 130.800},  {64.490, 116.650},  {64.050, 127.440},  {47.060, 115.210},  {68.510, 120.720},
     {67.710, 122.810},  {69.220, 115.690},  {65.820, 120.420},  {62.670, 119.470},  {63.510, 118.850},
     {63.930, 126.070},  {64.530, 126.040},  {64.140, 117.760},  {64.260, 126.410},  {50.290, 114.810},
     {64.650, 126.530},  {47.360, 115.570},  {69.140, 120.020},  {65.420, 124.330},  {66.150, 123.630},
     {50.240, 117.980},  {72.320, 108.630},  {71.100, 121.930},  {64.550, 118.740},  {47.050, 117.940},
     {47.500, 115.900},  {66.650, 127.150},  {69.760, 118.660},  {46.590, 117.260},  {66.000, 116.750},
     {47.950, 116.400},  {69.330, 119.500},  {70.160, 114.880},  {66.600, 116.790},  {65.940, 122.760},
     {72.220, 107.350},  {52.210, 122.140},  {52.280, 120.210},  {52.480, 115.960},  {52.850, 119.510},
     {49.160, 118.590},  {50.850, 114.990},  {40.610, 120.110},  {40.640, 119.330},  {40.810, 117.900},
     {41.340, 118.720},  {52.960, 115.450},  {53.580, 114.860},  {71.540, 125.890},  {68.070, 123.870},
     {73.210, 123.440},  {57.690, 129.790},  {64.070, 108.060},  {80.250, 124.000},  {97.090, 120.320},
     {98.050, 119.970},  {56.530, 179.460},  {56.970, 178.600},  {56.960, 178.000},  {58.180, 179.660},
     {62.730, 170.020},  {56.730, 173.290},  {56.940, 179.490},  {58.930, 179.420},  {56.190, 179.140},
     {59.440, 178.460},  {57.380, 177.980},  {59.410, 177.890},  {65.040, 174.070},  {54.280, 120.930},
     {52.390, 112.190},  {53.890, 123.260},  {37.860, 115.610},  {36.710, 110.580},  {52.400, 112.370},
     {54.270, 121.940},  {53.970, 111.820},  {53.240, 110.340},  {56.030, 119.560},  {56.450, 180.000},
     {56.900, 178.320},  {58.120, 180.000},  {62.730, 170.020},  {56.730, 173.290},  {56.900, 179.740},
     {58.830, 180.000},  {56.190, 179.140},  {59.410, 178.620},  {57.400, 177.900},  {59.370, 178.120},
     {58.680, 179.670},  {64.660, 176.170},  {59.790, 116.450},  {55.510, 122.020},  {50.000, 87.500},
     {71.830, 110.310},  {73.020, 122.500},  {64.710, 114.640},  {69.580, 118.830},  {74.050, 123.980},
     {73.720, 121.760},  {73.220, 110.310},  {72.940, 126.030},  {73.070, 110.310},  {73.320, 124.390},
     {74.800, 113.380},  {72.690, 117.050},  {71.900, 117.060},  {74.440, 110.370},  {75.830, 122.030},
     {76.220, 113.630},  {66.540, 109.280},  {67.950, 125.360},  {76.680, 109.280},  {83.180, 123.880},
     {83.030, 112.610},  {84.610, 110.420},  {78.910, 110.560},  {84.340, 123.440},  {78.170, 130.380},
     {77.380, 122.880},  {75.930, 123.330},  {59.770, 123.100},  {60.900, 120.790},  {60.850, 121.200},
     {59.440, 123.020},  {59.440, 123.020},  {60.640, 119.100},  {61.200, 121.710},  {77.510, 121.150},
     {78.060, 119.450},  {86.330, 120.440},  {81.240, 121.410},  {76.450, 111.380},  {81.780, 122.290},
     {83.310, 125.030},  {83.910, 113.630},  {76.880, 121.150},  {78.310, 119.320},  {58.960, 113.750},
     {58.400, 118.040},  {67.140, 90.080},   {57.080, 123.760},  {67.250, 118.330},  {64.140, 121.140},
     {68.850, 119.430},  {69.270, 121.650},  {72.200, 90.000},   {62.640, 124.480},  {68.050, 116.600},
     {58.620, 113.770},  {58.620, 113.770},  {71.310, 125.720},  {57.520, 123.800},  {67.000, 118.240},
     {64.220, 120.410},  {69.270, 121.650},  {62.640, 124.470},  {72.200, 90.000},   {68.050, 116.600},
     {98.110, 108.810},  {95.130, 115.750},  {100.060, 115.330}, {104.130, 120.400}, {99.770, 122.760},
     {99.130, 125.900},  {102.180, 113.000}, {97.340, 108.800},  {95.370, 115.780},  {58.560, 148.210},
     {94.970, 62.600},   {100.970, 50.800},  {46.110, 147.730},  {73.280, 94.170},   {47.300, 133.700},
     {84.660, 63.900},   {42.890, 132.140},  {63.100, 120.660},  {62.330, 120.540},  {46.630, 115.780},
     {46.770, 115.100},  {67.140, 116.170},  {63.000, 114.480},  {61.820, 120.060},  {45.870, 115.420},
     {46.120, 114.160},  {64.310, 118.500},  {66.570, 115.500},  {61.860, 122.180},  {46.810, 114.570},
     {47.050, 113.410},  {69.250, 112.930},  {66.420, 118.500},  {62.910, 116.930},  {63.040, 118.970},
     {47.440, 113.840},  {62.960, 117.960},  {62.450, 120.460},  {46.270, 117.250},  {46.420, 116.530},
     {62.910, 114.200},  {60.790, 120.100},  {43.410, 111.430},  {42.580, 115.800},  {67.250, 115.590},
     {91.530, 54.600},   {88.720, 58.500},   {45.490, 118.090},  {87.900, 60.000},   {67.540, 100.530},
     {64.530, 117.930},  {45.450, 119.660},  {45.790, 117.920},  {45.470, 119.620},  {91.170, 59.590},
     {62.940, 125.850},  {92.030, 59.150},   {93.610, 59.070},   {43.980, 125.430},  {70.610, 106.900},
     {50.350, 111.680},  {50.220, 112.300},  {38.380, 115.450},  {47.970, 116.430},  {49.060, 115.420},
     {49.960, 108.670},  {48.500, 116.320},  {50.010, 115.170},  {37.870, 119.430},  {47.550, 117.180},
     {38.580, 114.470},  {50.250, 114.100},  {47.620, 114.470},  {102.060, 50.160},  {70.160, 119.750},
     {92.710, 65.980},   {76.670, 107.850},  {71.640, 118.120},  {70.900, 115.840},  {66.570, 100.400},
     {63.190, 111.580},  {60.760, 118.700},  {46.160, 111.770},  {46.210, 111.550},  {65.280, 112.920},
     {68.320, 104.050},  {66.990, 111.960},  {61.780, 116.720},  {60.440, 121.790},  {71.810, 84.990},
     {60.650, 120.880},  {45.500, 117.250},  {74.690, 88.020},   {74.010, 121.330},  {45.890, 113.100},
     {45.750, 113.850},  {61.910, 112.000},  {44.060, 106.590},  {42.600, 114.000},  {64.320, 117.390},
     {66.270, 114.420},  {71.460, 86.670},   {46.060, 114.470},  {66.080, 101.230},  {45.250, 118.300},
     {70.160, 87.610},   {64.550, 112.870},  {44.870, 114.840},  {44.510, 116.770},  {44.820, 115.140},
     {73.470, 87.580},   {65.220, 112.130},  {63.370, 119.700},  {66.000, 114.190},  {66.410, 111.770},
     {74.590, 117.460},  {74.450, 118.180},  {39.010, 109.720},  {48.210, 113.360},  {49.100, 111.180},
     {50.890, 111.490},  {50.530, 110.940},  {51.950, 112.570},  {48.420, 114.440},  {50.970, 109.190},
     {53.300, 106.850},  {52.700, 109.730},  {39.240, 109.040},  {71.620, 107.500},  {82.570, 103.450},
     {82.030, 105.120},  {72.970, 120.170},  {51.100, 180.000},  {64.910, 179.920},  {60.250, 177.730},
     {54.830, 180.000},  {56.970, 179.990},  {53.870, 179.950},  {55.860, 179.960},  {45.620, 179.980},
     {46.230, 179.950},  {66.890, 180.000},  {65.700, 171.560},  {60.690, 175.590},  {59.680, 179.690},
     {59.950, 180.000},  {60.880, 176.350},  {62.620, 179.950},  {62.880, 174.310},  {62.150, 176.610},
     {53.810, 172.830},  {54.260, 173.510},  {53.620, 173.640},  {56.480, 177.280},  {76.360, 178.110},
     {69.870, 169.600},  {67.470, 179.990},  {78.230, 175.920},  {70.520, 174.250},  {70.160, 176.060},
     {61.580, 180.000},  {73.090, 116.940},  {81.900, 118.000},  {56.300, 180.000},  {58.540, 180.000},
     {71.350, 122.400},  {82.090, 117.340},  {71.060, 122.400},  {81.960, 117.340},  {55.230, 179.940},
     {57.390, 179.930},  {47.140, 179.910},  {47.260, 179.940},  {68.970, 179.970},  {67.650, 171.570},
     {62.490, 175.090},  {61.310, 179.910},  {61.630, 179.970},  {62.660, 176.000},  {64.430, 179.940},
     {64.780, 173.770},  {64.010, 176.120},  {54.850, 174.710},  {55.500, 174.270},  {69.160, 180.000},
     {72.150, 175.070},  {72.040, 175.610},  {66.900, 116.050},  {80.340, 119.930},  {63.890, 106.600},
     {59.130, 112.400},  {61.080, 110.420},  {60.100, 114.470},  {63.250, 111.030},  {78.980, 115.780},
     {74.410, 121.100},  {58.670, 151.880},  {59.530, 118.800},  {51.470, 126.500},  {76.750, 113.400},
     {79.200, 113.590},  {66.970, 119.570},  {88.340, 117.670},  {70.760, 118.180},  {66.130, 115.300},
     {69.830, 119.940},  {60.950, 112.640},  {68.300, 108.140},  {52.630, 110.330},  {51.860, 114.740},
     {75.450, 115.090},  {77.940, 103.590},  {71.340, 118.140},  {62.390, 112.220},  {70.160, 117.980},
     {70.350, 117.580},  {70.710, 117.610},  {64.220, 111.540},  {75.470, 116.940},  {72.080, 110.890},
     {71.830, 110.510},  {67.180, 116.000},  {61.270, 119.300},  {62.640, 118.770},  {86.210, 112.290},
     {87.140, 116.240},  {86.900, 118.000},  {79.840, 115.480},  {82.230, 118.040},  {63.760, 110.700},
     {65.970, 114.950},  {65.370, 118.520},  {65.320, 118.690},  {45.180, 118.400},  {68.640, 116.200},
     {69.290, 111.180},  {68.080, 109.990},  {70.290, 112.400},  {64.870, 114.210},  {83.890, 113.840},
     {83.150, 116.720},  {71.790, 112.200},  {50.010, 120.000},  {74.000, 113.530},  {75.260, 116.000},
     {66.400, 118.110},  {85.850, 120.110},  {66.220, 120.970},  {62.710, 123.800},  {66.050, 120.500},
     {60.100, 115.790},  {52.300, 111.140},  {72.990, 108.920},  {70.350, 118.470},  {60.110, 115.790},
     {52.630, 110.090},  {52.730, 111.120},  {70.330, 118.090},  {70.640, 118.550},  {77.370, 112.160},
     {71.450, 113.480},  {71.290, 112.780},  {87.710, 116.280},  {53.860, 106.500},  {70.490, 117.550},
     {70.490, 119.080},  {77.370, 112.160},  {72.610, 109.870},  {70.950, 113.870},  {87.710, 116.280},
     {63.750, 108.700},  {63.120, 110.470},  {62.610, 114.030},  {62.850, 112.980},  {79.610, 115.770},
     {90.460, 64.920},   {68.290, 114.600},  {71.170, 110.100},  {66.600, 107.100},  {84.970, 110.730},
     {38.610, 120.000},  {55.330, 114.100},  {55.840, 105.010},  {54.690, 108.560},  {54.690, 108.560},
     {57.610, 107.370},  {46.310, 112.090},  {43.060, 111.330},  {44.500, 122.340},  {48.420, 111.410},
     {48.420, 111.410},  {61.190, 115.800},  {58.650, 111.210},  {62.150, 108.170},  {60.520, 112.590},
     {53.710, 111.790},  {52.330, 116.820},  {57.140, 113.260},  {71.310, 116.850},  {80.820, 112.000},
     {62.280, 180.000},  {78.200, 109.490},  {76.590, 108.880},  {65.780, 106.450},  {74.180, 112.230},
     {74.760, 111.700},  {67.680, 105.970},  {80.170, 110.430},  {74.020, 111.510},  {74.690, 108.380},
     {71.160, 109.150},  {64.580, 113.050},  {64.290, 118.770},  {70.950, 110.460},  {90.620, 107.300},
     {91.570, 111.250},  {90.160, 115.910},  {83.540, 111.100},  {86.650, 112.140},  {72.950, 115.070},
     {76.860, 114.000},  {68.490, 115.340},  {88.540, 117.130},  {59.970, 106.700},  {64.860, 112.200},
     {62.840, 113.070},  {79.030, 118.500},  {73.470, 107.000},  {75.740, 113.090},  {66.830, 119.160},
     {87.260, 118.260},  {74.080, 113.250},  {79.970, 110.310},  {89.910, 116.220},  {74.690, 111.380},
     {79.970, 110.310},  {89.910, 116.220},  {69.670, 121.200},  {76.020, 113.600},  {67.100, 118.830},
     {88.040, 116.900},  {75.480, 108.180},  {74.990, 115.100},  {62.810, 103.700},  {70.400, 100.760},
     {64.250, 111.950},  {67.320, 117.300},  {88.140, 115.740},  {74.840, 101.700},  {67.990, 115.110},
     {87.990, 116.080},  {81.020, 115.370},  {75.560, 112.150},  {75.730, 110.350},  {70.040, 116.080},
     {65.080, 113.430},  {67.340, 110.610},  {72.480, 109.110},  {67.310, 134.560},  {67.310, 134.560},
     {91.280, 108.910},  {93.100, 111.340},  {91.240, 117.180},  {82.970, 114.980},  {71.250, 110.290},
     {69.290, 110.200},  {86.560, 115.340},  {89.190, 112.230},  {66.870, 116.800},  {61.450, 124.480},
     {61.350, 128.370},  {65.160, 123.470},  {86.260, 112.100},  {86.440, 115.700},  {85.910, 117.840},
     {80.450, 118.450},  {82.010, 120.430},  {59.930, 120.400},  {80.080, 120.860},  {77.830, 131.840},
     {66.060, 120.600},  {85.340, 119.890},  {88.590, 115.730},  {88.590, 115.730},  {105.720, 119.180},
     {107.600, 119.180}, {109.720, 119.180}, {96.030, 123.930},  {98.240, 123.930},  {109.670, 120.880},
     {110.840, 113.000}, {109.880, 119.610}, {101.850, 122.050}, {106.640, 118.190}, {100.790, 123.930},
     {66.540, 107.150},  {62.700, 106.930},  {64.090, 123.340},  {68.220, 104.700},  {47.740, 118.310},
     {70.010, 116.630},  {66.220, 124.680},  {49.110, 119.380},  {64.010, 110.900},  {62.170, 107.230},
     {62.450, 116.320},  {61.690, 118.260},  {66.810, 103.130},  {47.130, 109.920},  {56.980, 108.480},
     {66.230, 118.750},  {66.760, 108.150},  {67.180, 109.650},  {66.670, 111.750},  {66.370, 111.890},
     {66.020, 111.270},  {68.680, 113.310},  {69.070, 106.140},  {68.480, 104.950},  {59.890, 121.930},
     {62.050, 119.810},  {77.770, 112.910},  {80.590, 116.570},  {77.780, 110.020},  {78.550, 112.700},
     {77.950, 116.010},  {79.010, 115.270},  {61.850, 108.280},  {42.590, 104.390},  {63.750, 107.650},
     {86.390, 60.710},   {47.150, 109.570},  {62.150, 119.320},  {60.630, 121.750},  {70.040, 90.870},
     {46.250, 112.120},  {67.710, 102.220},  {50.780, 99.800},   {41.300, 107.130},  {35.430, 109.980},
     {52.050, 110.170},  {51.400, 115.940},  {50.160, 103.980},  {50.870, 106.400},  {51.020, 106.570},
     {50.320, 107.890},  {50.440, 107.390},  {50.250, 104.780},  {53.140, 113.320},  {53.080, 101.110},
     {51.670, 100.920},  {42.850, 120.260},  {41.820, 116.890},  {43.440, 113.050},  {44.280, 113.680},
     {53.750, 108.930},  {52.560, 109.470},  {58.300, 109.330},  {54.580, 108.670},  {54.880, 109.850},
     {55.880, 109.490},  {60.040, 111.270},  {72.400, 113.210},  {71.820, 118.730},  {74.130, 114.910},
     {69.570, 105.710},  {69.040, 113.480},  {70.910, 107.140},  {69.210, 112.000},  {70.750, 107.150},
     {70.250, 110.550},  {67.040, 115.260},  {72.790, 107.180},  {71.890, 126.140},  {66.640, 117.020},
     {65.880, 116.650},  {81.710, 114.090},  {87.090, 113.800},  {78.520, 119.810},  {70.790, 106.520},
     {60.890, 130.130},  {61.530, 118.740},  {63.370, 116.350},  {63.830, 119.420},  {96.310, 120.020},
     {99.300, 120.950},  {101.380, 126.130}, {98.100, 118.630},  {98.150, 119.670},  {90.470, 131.360},
     {98.680, 119.570},  {65.140, 114.820},  {41.380, 108.440},  {65.530, 113.870},  {48.620, 110.190},
     {63.010, 112.580},  {63.100, 110.960},  {46.430, 111.360},  {62.840, 110.640},  {63.610, 110.400},
     {62.840, 111.090},  {62.270, 108.040},  {46.190, 110.110},  {66.730, 108.720},  {63.720, 114.070},
     {66.200, 109.260},  {64.760, 111.730},  {65.250, 109.080},  {67.250, 111.660},  {65.900, 113.730},
     {67.380, 107.420},  {56.830, 112.520},  {58.790, 110.730},  {59.350, 113.220},  {72.410, 108.230},
     {73.090, 111.560},  {74.940, 113.550},  {74.840, 115.810},  {75.510, 113.680},  {63.210, 114.480},
     {47.540, 108.520},  {61.500, 108.610},  {44.680, 110.860},  {60.960, 114.910},  {42.500, 108.870},
     {70.470, 109.050},  {51.670, 108.390},  {40.520, 108.110},  {36.440, 108.720},  {51.790, 109.390},
     {42.290, 109.680},  {49.850, 110.400},  {48.090, 108.660},  {49.590, 109.080},  {49.430, 109.380},
     {48.360, 109.920},  {49.190, 104.380},  {52.090, 109.260},  {51.120, 108.090},  {50.150, 109.390},
     {37.700, 110.500},  {39.300, 109.890},  {37.650, 111.330},  {40.530, 110.000},  {37.420, 117.890},
     {46.920, 110.100},  {51.970, 106.890},  {48.900, 108.940},  {52.260, 108.560},  {52.080, 109.170},
     {58.990, 118.490},  {72.690, 110.670},  {59.430, 108.640},  {69.790, 111.070},  {65.210, 115.490},
     {66.270, 119.600},  {67.830, 109.380},  {66.680, 118.620},  {72.250, 108.190},  {70.280, 120.970},
     {72.460, 104.400},  {55.970, 113.910},  {56.000, 121.380},  {61.270, 107.020},  {73.000, 69.790},
     {87.700, 115.430},  {92.770, 109.510},  {96.690, 112.590},  {90.880, 124.550},  {98.130, 109.200},
     {60.550, 123.000},  {63.610, 100.480},  {57.150, 124.810},  {57.160, 124.620},  {57.160, 124.620},
     {59.860, 119.420},  {59.860, 119.420},  {63.920, 104.990},  {59.980, 121.010},  {60.360, 120.260},
     {60.360, 120.260},  {79.050, 112.280},  {67.200, 117.200},  {64.320, 125.200},  {66.540, 120.570},
     {65.820, 121.350},  {65.820, 121.350},  {68.270, 120.240},  {68.270, 120.240},  {70.240, 106.960},
     {60.440, 122.250},  {61.100, 121.480},  {61.100, 121.480},  {78.330, 118.300},  {67.800, 110.370},
     {64.230, 117.200},  {64.550, 125.330},  {63.980, 125.750},  {63.980, 125.750},  {63.280, 101.010},
     {68.640, 103.110},  {47.620, 119.280},  {58.980, 106.740},  {66.270, 124.810},  {65.800, 125.000},
     {64.640, 124.800},  {65.190, 121.320},  {65.630, 124.700},  {65.140, 124.600},  {67.270, 121.140},
     {67.600, 119.950},  {65.040, 124.980},  {64.340, 124.200},  {68.210, 125.900},  {65.800, 123.900},
     {68.530, 110.330},  {60.200, 122.140},  {58.910, 126.100},  {64.460, 125.000},  {60.390, 125.100},
     {60.800, 121.560},  {60.800, 121.560},  {73.870, 124.900},  {76.240, 124.400},  {74.540, 125.800},
     {76.230, 125.100},  {78.900, 115.530},  {60.720, 125.590},  {63.150, 124.360},  {62.560, 125.090},
     {62.560, 125.090},  {63.760, 119.460},  {65.480, 120.050},  {67.370, 112.680},  {65.740, 120.460},
     {65.740, 120.460},  {68.910, 104.390},  {59.290, 123.120},  {59.960, 122.110},  {59.960, 122.110},
     {80.220, 110.280},  {79.610, 110.870},  {66.980, 120.090},  {68.460, 113.150},  {68.460, 113.150},
     {57.170, 124.790},  {65.880, 120.960},  {63.070, 124.090},  {65.510, 116.400},  {47.630, 125.590},
     {55.210, 121.620},  {68.210, 119.850},  {66.370, 120.190},  {67.340, 122.000},  {66.290, 123.760},
     {68.180, 122.160},  {69.270, 117.850},  {69.270, 117.850},  {66.140, 124.330},  {71.140, 119.990},
     {66.690, 124.080},  {69.700, 109.460},  {59.660, 125.850},  {59.650, 124.380},  {65.120, 124.970},
     {61.240, 123.300},  {61.050, 122.130},  {61.050, 122.130},  {57.370, 140.880},  {76.640, 117.230},
     {77.900, 120.690},  {75.010, 125.640},  {76.630, 125.440},  {74.880, 129.910},  {68.940, 109.900},
     {63.880, 128.010},  {63.050, 126.610},  {57.100, 124.610},  {64.600, 118.030},  {46.990, 125.660},
     {54.340, 125.700},  {66.830, 122.960},  {65.900, 120.310},  {66.520, 123.190},  {65.910, 123.430},
     {70.180, 113.020},  {66.370, 126.350},  {66.230, 122.250},  {65.400, 121.780},  {69.010, 125.210},
     {66.670, 122.380},  {67.340, 115.740},  {59.490, 125.860},  {59.280, 125.250},  {64.080, 127.730},
     {60.690, 124.700},  {75.240, 121.030},  {77.180, 122.190},  {74.800, 125.660},  {76.830, 123.960},
     {76.340, 124.220},  {68.940, 109.900},  {57.100, 124.610},  {64.600, 118.030},  {47.070, 125.220},
     {54.340, 125.700},  {66.830, 122.960},  {65.900, 120.310},  {66.520, 123.190},  {65.910, 123.430},
     {66.510, 125.820},  {70.180, 113.020},  {66.230, 122.250},  {65.400, 121.780},  {69.010, 125.210},
     {66.670, 122.380},  {65.210, 123.420},  {59.490, 125.860},  {59.280, 125.250},  {64.080, 127.730},
     {60.690, 124.700},  {75.240, 121.030},  {77.180, 122.190},  {74.800, 125.660},  {76.830, 123.960},
     {77.930, 119.180},  {56.330, 122.800},  {59.890, 119.360},  {59.890, 119.360},  {63.040, 106.580},
     {58.340, 121.290},  {58.780, 120.510},  {58.780, 120.510},  {77.180, 111.910},  {62.220, 120.200},
     {66.640, 118.050},  {66.640, 118.050},  {69.150, 103.860},  {59.680, 119.950},  {60.340, 119.100},
     {60.340, 119.100},  {80.160, 108.010},  {39.830, 116.800},  {50.900, 111.260},  {50.000, 119.610},
     {50.000, 119.610},  {51.440, 101.410},  {40.320, 122.520},  {40.940, 121.480},  {40.940, 121.480},
     {53.460, 113.950},  {58.320, 124.200},  {56.940, 120.030},  {56.940, 120.030},  {59.850, 109.910},
     {57.960, 122.280},  {58.320, 121.400},  {58.320, 121.400},  {74.730, 118.400},  {70.350, 116.710},
     {69.850, 119.960},  {69.850, 119.960},  {70.330, 111.530},  {61.200, 124.880},  {62.110, 123.180},
     {62.110, 123.180},  {78.110, 124.640},  {65.770, 124.000},  {68.570, 111.700},  {69.090, 116.440},
     {69.090, 116.440},  {71.610, 102.970},  {60.870, 123.560},  {61.710, 121.980},  {61.710, 121.980},
     {66.770, 123.600},  {69.080, 119.640},  {69.080, 119.640},  {70.250, 109.470},  {61.690, 121.720},
     {62.360, 120.910},  {62.360, 120.910},  {80.370, 116.500},  {71.200, 117.080},  {69.530, 122.770},
     {68.820, 120.550},  {68.190, 119.150},  {72.040, 122.790},  {69.710, 119.220},  {68.300, 119.650},
     {62.600, 119.990},  {62.200, 120.070},  {68.140, 119.770},  {63.880, 118.950},  {63.450, 118.660},
     {77.870, 119.200},  {80.300, 119.240},  {77.910, 122.260},  {80.100, 120.500},  {79.650, 120.500},
     {71.200, 117.080},  {68.820, 120.550},  {68.190, 119.150},  {72.040, 122.790},  {69.710, 119.220},
     {68.300, 119.650},  {62.600, 119.990},  {62.200, 120.070},  {68.140, 119.770},  {63.880, 118.950},
     {63.450, 118.660},  {77.870, 119.200},  {80.300, 119.240},  {77.910, 122.260},  {80.100, 120.500},
     {79.650, 120.500},  {66.770, 123.600},  {69.650, 111.370},  {61.900, 120.860},  {62.500, 120.380},
     {62.500, 120.380},  {81.840, 112.350},  {67.780, 123.800},  {69.610, 119.850},  {69.610, 119.850},
     {65.220, 122.800},  {70.300, 106.550},  {62.140, 120.110},  {62.140, 120.110},  {72.340, 104.710},
     {80.360, 114.950},  {61.990, 121.350},  {62.650, 120.640},  {62.650, 120.640},  {80.800, 116.100},
     {68.130, 122.200},  {62.330, 120.760},  {63.000, 119.990},  {63.000, 119.990},  {82.110, 113.040},
     {74.030, 126.200},  {70.760, 118.390},  {62.830, 122.800},  {63.490, 122.340},  {63.490, 122.340},
     {71.290, 104.450},  {62.590, 117.860},  {66.040, 104.700},  {65.290, 111.410},  {62.490, 119.910},
     {62.490, 119.910},  {82.020, 105.880},  {82.010, 112.000},  {82.680, 109.640},  {60.320, 120.910},
     {59.150, 124.800},  {60.140, 123.990},  {60.660, 120.720},  {60.660, 120.720},  {74.880, 122.470},
     {76.310, 122.500},  {75.690, 121.850},  {76.680, 121.750},  {76.380, 121.880},  {58.510, 126.600},
     {59.780, 123.320},  {59.780, 123.320},  {60.590, 124.600},  {60.760, 122.690},  {60.760, 122.690},
     {78.220, 118.520},  {60.940, 120.780},  {75.520, 121.510},  {76.990, 121.550},  {76.170, 121.470},
     {77.280, 121.080},  {76.970, 121.200},  {60.940, 120.780},  {75.520, 121.510},  {76.990, 121.550},
     {76.170, 121.470},  {77.280, 121.080},  {76.970, 121.200},  {76.600, 78.250},   {92.990, 124.200},
     {99.310, 112.860},  {99.570, 111.920},  {96.930, 123.200},  {98.410, 119.100},  {96.720, 124.600},
     {98.710, 118.790},  {93.790, 126.000},  {100.150, 112.490}, {100.760, 113.240}, {96.930, 123.200},
     {68.590, 115.860},  {68.010, 118.040},  {68.010, 118.040},  {69.370, 118.890},  {68.790, 121.110},
     {70.440, 121.040},  {66.590, 116.200},  {61.850, 120.770},  {62.070, 118.190},  {62.340, 118.190},
     {62.340, 118.190},  {73.520, 102.690},  {65.900, 118.880},  {67.020, 118.880},  {67.020, 118.880},
     {65.180, 116.750},  {63.060, 119.980},  {64.880, 116.540},  {65.850, 116.540},  {65.850, 116.540},
     {47.330, 118.360},  {63.130, 115.560},  {62.760, 119.960},  {63.380, 120.810},  {63.240, 121.340},
     {62.510, 117.110},  {46.040, 116.780},  {64.890, 121.680},  {66.400, 114.820},  {66.990, 115.190},
     {66.870, 115.310},  {66.880, 113.050},  {66.990, 112.650},  {76.610, 121.270},  {64.310, 117.390},
     {64.270, 121.000},  {68.060, 107.900},  {61.550, 117.720},  {64.620, 114.920},  {47.360, 115.940},
     {56.580, 119.300},  {65.720, 122.170},  {64.150, 122.980},  {66.300, 118.540},  {66.330, 119.310},
     {68.180, 114.630},  {68.570, 113.030},  {66.600, 116.450},  {62.890, 112.320},  {58.640, 125.110},
     {75.900, 118.400},  {78.480, 117.320},  {78.660, 116.600},  {68.470, 117.040},  {65.090, 122.150},
     {63.920, 121.350},  {67.600, 109.510},  {65.330, 127.140},  {64.290, 123.710},  {70.730, 109.950},
     {72.670, 104.240},  {73.700, 104.690},  {74.610, 102.630},  {73.070, 104.500},  {85.860, 116.290},
     {65.240, 124.190},  {66.430, 120.660},  {68.800, 108.920},  {68.600, 110.190},  {70.480, 107.470},
     {66.550, 120.320},  {62.010, 117.720},  {73.380, 102.970},  {72.540, 107.940},  {65.240, 124.190},
     {68.020, 119.060},  {69.430, 118.060},  {74.240, 103.730},  {72.470, 106.430},  {73.170, 104.300},
     {88.980, 108.340},  {62.210, 131.830},  {65.610, 114.920},  {48.080, 118.710},  {56.610, 119.300},
     {62.720, 116.350},  {70.090, 110.870},  {66.530, 121.370},  {67.870, 117.570},  {70.120, 111.950},
     {67.300, 117.520},  {66.400, 115.920},  {70.070, 120.540},  {67.320, 118.150},  {68.060, 115.560},
     {63.340, 112.320},  {59.020, 125.110},  {61.710, 121.000},  {76.360, 118.400},  {79.070, 117.320},
     {76.920, 118.290},  {78.020, 119.130},  {79.250, 116.600},  {64.220, 122.070},  {72.260, 94.230},
     {68.800, 108.920},  {62.010, 117.720},  {65.610, 114.920},  {47.860, 119.820},  {56.610, 119.300},
     {70.090, 110.870},  {66.530, 121.370},  {67.870, 117.570},  {69.680, 113.030},  {67.300, 117.520},
     {66.400, 115.920},  {70.070, 120.540},  {67.320, 118.150},  {68.060, 115.560},  {63.340, 112.320},
     {59.020, 125.110},  {61.710, 121.000},  {76.360, 118.400},  {79.070, 117.320},  {76.920, 118.290},
     {78.020, 119.130},  {79.250, 116.600},  {64.680, 111.970},  {68.300, 108.630},  {64.910, 110.790},
     {49.210, 118.460},  {56.340, 120.380},  {63.240, 111.690},  {68.060, 120.590},  {67.130, 120.430},
     {68.850, 112.320},  {68.180, 118.420},  {68.250, 119.200},  {75.970, 105.470},  {67.170, 125.230},
     {73.150, 111.150},  {67.140, 124.930},  {74.420, 107.220},  {68.020, 117.810},  {66.470, 118.160},
     {71.640, 118.900},  {69.530, 113.390},  {69.600, 113.140},  {60.460, 124.560},  {59.910, 122.540},
     {60.710, 123.440},  {60.230, 128.500},  {60.840, 122.230},  {60.840, 122.230},  {76.060, 120.410},
     {77.030, 125.010},  {74.720, 126.550},  {78.300, 119.540},  {78.430, 120.370},  {77.090, 124.810},
     {46.260, 118.580},  {97.400, 54.040},   {45.340, 119.000},  {67.600, 109.510},  {70.730, 109.950},
     {72.240, 105.470},  {73.580, 104.690},  {74.060, 104.160},  {73.550, 108.410},  {73.130, 104.340},
     {85.860, 116.290},  {65.700, 120.660},  {65.710, 120.680},  {68.900, 116.040},  {71.090, 105.630},
     {73.800, 104.150},  {74.240, 103.730},  {71.970, 107.920},  {72.920, 105.010},  {89.270, 107.640},
     {70.890, 103.170},  {73.380, 102.970},  {72.540, 107.940},  {75.970, 105.470},  {73.100, 111.300},
     {74.420, 107.220},  {60.080, 152.480},  {66.000, 140.000},  {66.060, 120.920},  {67.330, 118.170},
     {68.360, 123.580},  {74.560, 113.310},  {69.170, 110.860},  {63.870, 134.030},  {62.610, 120.520},
     {63.660, 117.750},  {66.630, 117.040},  {77.140, 111.980},  {77.530, 120.970},  {65.630, 121.760},
     {69.660, 114.270},  {69.710, 115.050},  {71.100, 113.960},  {65.650, 118.090},  {83.220, 120.110},
     {67.860, 118.530},  {71.160, 111.190},  {72.260, 112.160},  {66.250, 117.020},  {84.980, 116.280},
     {71.710, 120.200},  {73.160, 113.390},  {74.430, 114.700},  {66.960, 119.570},  {86.420, 117.700},
     {78.040, 116.050},  {78.590, 107.220},  {70.940, 110.720},  {78.090, 114.100},  {72.370, 109.660},
     {66.510, 112.150},  {65.740, 115.970},  {69.010, 114.600},  {90.200, 115.900},  {80.750, 107.290},
     {82.850, 111.210},  {72.280, 110.450},  {67.420, 114.390},  {85.550, 115.950},  {76.910, 124.090},
     {61.880, 132.320},  {68.040, 110.620},  {71.120, 110.790},  {91.120, 117.190},  {80.740, 108.920},
     {83.600, 111.340},  {65.270, 116.810},  {62.490, 128.350},  {65.650, 123.470},  {80.480, 112.120},
     {81.800, 115.730},  {83.520, 115.730},  {78.540, 131.840},  {86.300, 116.180},  {109.960, 120.870},
     {101.960, 112.960}, {102.420, 119.630}, {63.220, 137.740},  {66.000, 140.000},  {66.690, 118.670},
     {67.330, 118.170},  {74.560, 113.310},  {69.170, 110.860},  {63.870, 134.030},  {62.610, 120.520},
     {63.660, 117.750},  {66.630, 117.040},  {77.140, 111.980},  {79.580, 114.810},  {65.450, 122.300},
     {70.020, 113.110},  {69.660, 115.190},  {71.100, 113.960},  {65.650, 118.090},  {83.220, 120.110},
     {67.770, 118.530},  {71.160, 111.190},  {72.260, 112.160},  {66.250, 117.020},  {84.980, 116.280},
     {71.710, 120.200},  {73.160, 113.390},  {74.430, 114.700},  {66.960, 119.570},  {86.420, 117.700},
     {67.900, 102.980},  {78.590, 107.220},  {70.940, 110.720},  {78.090, 114.100},  {72.370, 109.660},
     {66.510, 112.150},  {65.740, 115.970},  {69.010, 114.600},  {90.200, 115.900},  {80.750, 107.290},
     {82.850, 111.210},  {72.280, 110.450},  {67.420, 114.390},  {85.550, 115.950},  {76.910, 124.090},
     {61.880, 132.320},  {68.040, 110.620},  {71.120, 110.790},  {91.120, 117.190},  {80.740, 108.920},
     {83.600, 111.340},  {65.270, 116.810},  {62.490, 128.350},  {65.650, 123.470},  {80.480, 112.120},
     {81.800, 115.730},  {83.520, 115.730},  {78.540, 131.840},  {86.300, 116.180},  {109.960, 120.870},
     {101.960, 112.960}, {102.420, 119.630}, {67.090, 106.270},  {62.040, 111.880},  {42.110, 101.560},
     {68.330, 116.980},  {66.360, 122.710},  {66.220, 122.360},  {49.550, 117.300},  {65.540, 124.500},
     {63.170, 123.710},  {64.590, 127.340},  {64.990, 125.770},  {64.840, 126.330},  {63.080, 124.440},
     {49.620, 114.890},  {68.360, 120.000},  {67.570, 116.980},  {66.090, 125.630},  {69.450, 112.510},
     {69.270, 112.930},  {78.160, 121.130},  {63.530, 114.440},  {64.560, 117.770},  {63.650, 121.180},
     {64.170, 119.220},  {63.620, 119.920},  {63.010, 125.510},  {46.460, 114.950},  {67.890, 112.350},
     {67.100, 111.710},  {66.920, 112.430},  {60.930, 123.350},  {78.350, 116.120},  {64.340, 127.460},
     {63.730, 129.910},  {63.880, 129.310},  {62.010, 113.150},  {63.110, 123.630},  {67.900, 106.090},
     {49.080, 116.130},  {55.550, 117.830},  {69.370, 117.130},  {67.820, 121.110},  {68.180, 114.210},
     {68.560, 108.940},  {68.070, 116.150},  {68.580, 114.540},  {68.490, 114.870},  {69.190, 113.920},
     {69.640, 121.920},  {69.150, 112.800},  {69.930, 110.170},  {61.620, 125.270},  {60.110, 125.700},
     {61.180, 124.010},  {61.760, 125.610},  {78.630, 115.620},  {77.920, 123.530},  {75.150, 122.540},
     {78.190, 121.410},  {78.160, 121.500},  {76.750, 125.260},  {63.320, 122.820},  {48.860, 117.160},
     {68.230, 119.660},  {77.480, 122.910},  {62.500, 126.090},  {48.860, 117.160},  {48.340, 115.620},
     {66.820, 129.430},  {80.450, 112.970},  {48.620, 115.620},  {67.070, 129.430},  {62.930, 106.600},
     {43.080, 104.140},  {86.530, 62.020},   {45.790, 118.890},  {48.790, 121.240},  {66.930, 101.700},
     {49.800, 101.230},  {40.050, 114.850},  {36.550, 107.570},  {52.310, 110.570},  {50.080, 118.220},
     {50.050, 109.120},  {49.690, 104.400},  {50.890, 107.960},  {50.950, 107.910},  {50.320, 110.640},
     {50.990, 109.930},  {52.990, 116.450},  {51.130, 106.550},  {51.510, 104.760},  {42.970, 118.180},
     {41.930, 116.190},  {43.250, 112.600},  {43.730, 115.260},  {54.500, 107.480},  {51.650, 114.370},
     {55.730, 109.980},  {54.760, 112.250},  {54.360, 113.890},  {54.780, 111.230},  {59.800, 115.820},
     {75.130, 106.710},  {70.760, 117.500},  {69.630, 115.540},  {70.400, 126.060},  {69.520, 110.980},
     {68.150, 108.360},  {70.140, 112.010},  {39.730, 117.850},  {70.070, 112.230},  {36.080, 117.240},
     {49.620, 118.330},  {48.690, 117.220},  {48.900, 112.680},  {50.140, 113.120},  {50.400, 113.550},
     {50.760, 115.240},  {49.740, 113.130},  {48.710, 110.110},  {53.830, 116.320},  {72.070, 115.630},
     {50.330, 110.710},  {72.070, 108.550},  {50.520, 109.820},  {41.490, 118.050},  {40.240, 119.630},
     {41.880, 115.710},  {43.060, 113.200},  {52.120, 112.460},  {52.060, 114.920},  {54.500, 112.180},
     {53.400, 114.910},  {53.620, 115.600},  {54.450, 112.340},  {72.150, 106.270},  {72.240, 128.060},
     {72.410, 105.270},  {61.230, 127.330},  {59.950, 125.080},  {65.370, 112.760},  {100.210, 112.390},
     {99.870, 120.270},  {99.730, 119.000},  {95.590, 118.730},  {99.620, 119.250},  {60.660, 118.200},
     {70.160, 116.890},  {68.020, 117.940},  {68.420, 112.690},  {69.610, 117.380},  {71.080, 116.410},
     {63.760, 117.210},  {63.550, 117.210},  {70.860, 116.410},  {63.720, 117.210},  {63.510, 117.210},
     {69.100, 115.180},  {69.890, 114.620},  {68.520, 108.660},  {58.480, 113.190},  {71.340, 116.630},
     {69.870, 116.870},  {66.960, 116.560},  {68.740, 118.100},  {70.340, 117.520},  {61.610, 115.080},
     {67.100, 115.260},  {55.310, 115.490},  {72.050, 107.260},  {54.600, 116.310},  {73.780, 115.000},
     {65.790, 115.100},  {72.010, 115.560},  {72.870, 109.000},  {72.240, 115.490},  {74.080, 115.710},
     {71.670, 115.410},  {59.920, 112.380},  {73.390, 128.610},  {77.150, 125.130},  {74.090, 114.700},
     {73.710, 114.010},  {64.840, 117.380},  {61.420, 116.780},  {60.600, 116.640},  {61.770, 116.690},
     {72.320, 114.490},  {73.140, 114.390},  {81.060, 119.810},  {79.650, 116.100},  {78.810, 115.580},
     {72.280, 106.530},  {61.200, 119.620},  {62.850, 108.730},  {64.210, 108.550},  {67.920, 99.990},
     {60.950, 119.620},  {60.950, 119.620},  {97.760, 113.750},  {99.030, 119.680},  {98.560, 119.030},
     {93.680, 126.000},  {99.420, 118.490},  {42.150, 101.600},  {50.200, 108.760},  {49.910, 108.980},
     {47.090, 108.160},  {48.850, 109.470},  {50.060, 106.970},  {49.840, 107.160},  {49.700, 106.840},
     {50.070, 107.190},  {51.190, 107.370},  {43.560, 102.400},  {49.640, 106.170},  {47.620, 107.320},
     {48.470, 96.800},   {41.930, 104.800},  {35.670, 107.980},  {52.550, 107.810},  {50.570, 102.740},
     {50.610, 102.330},  {49.440, 106.630},  {50.460, 101.030},  {50.240, 103.710},  {49.970, 102.420},
     {50.310, 102.170},  {47.260, 100.870},  {49.340, 98.720},   {49.580, 99.690},   {44.140, 109.450},
     {42.540, 110.640},  {43.670, 110.190},  {44.150, 110.140},  {44.390, 110.730},  {54.130, 106.760},
     {51.720, 100.150},  {57.540, 109.200},  {54.390, 106.240},  {54.540, 107.060},  {55.940, 106.410},
     {65.080, 110.630},  {66.990, 115.020},  {64.470, 113.390},  {65.950, 113.140},  {64.210, 112.090},
     {65.430, 113.590},  {64.910, 118.130},  {68.210, 103.850},  {68.350, 102.770},  {61.090, 126.370},
     {79.830, 108.130},  {62.390, 112.450},  {62.270, 117.970},  {62.430, 117.580},  {62.560, 117.110},
     {62.850, 115.700},  {62.540, 117.850},  {60.430, 110.500},  {61.670, 115.650},  {54.880, 113.700},
     {66.310, 113.500},  {65.920, 108.120},  {64.520, 110.280},  {64.880, 110.500},  {65.400, 109.520},
     {64.540, 109.910},  {64.800, 112.730},  {64.800, 112.730},  {65.220, 109.690},  {63.890, 113.800},
     {65.620, 103.000},  {65.240, 107.970},  {65.890, 105.010},  {63.400, 115.470},  {60.450, 115.970},
     {61.300, 117.480},  {62.000, 118.000},  {61.690, 117.800},  {77.610, 111.500},  {80.000, 115.790},
     {75.020, 109.550},  {78.050, 112.820},  {76.870, 113.190},  {63.310, 119.950},  {67.320, 106.320},
     {66.250, 109.770},  {65.390, 112.190},  {66.470, 108.240},  {66.090, 113.680},  {66.090, 113.680},
     {61.600, 123.420},  {80.940, 116.970},  {64.910, 118.020},  {63.630, 115.140},  {64.540, 120.640},
     {63.750, 120.870},  {64.150, 119.620},  {67.250, 106.760},  {63.800, 118.620},  {64.150, 119.620},
     {65.510, 111.660},  {68.120, 107.230},  {66.270, 108.470},  {75.750, 119.590},  {71.750, 91.100},
     {67.350, 106.450},  {65.510, 111.660},  {68.120, 107.230},  {66.270, 108.470},  {75.750, 119.590},
     {60.450, 110.760},  {66.950, 112.080},  {66.830, 112.100},  {66.500, 110.500},  {66.250, 110.280},
     {62.330, 122.100},  {78.280, 113.490},  {85.270, 61.820},   {88.980, 59.990},   {90.380, 56.520},
     {68.810, 93.400},   {63.940, 103.300},  {63.940, 109.500},  {58.060, 115.670},  {70.280, 117.790},
     {68.760, 106.830},  {84.320, 111.300},  {67.760, 104.880},  {65.660, 114.680},  {66.100, 109.590},
     {81.940, 104.340},  {68.170, 110.400},  {80.210, 110.970},  {68.170, 110.400},  {80.210, 110.970},
     {67.810, 108.290},  {68.080, 108.310},  {66.400, 111.860},  {83.370, 113.620},  {62.760, 114.680},
     {64.670, 120.020},  {67.590, 107.860},  {60.040, 121.220},  {65.620, 105.580},  {61.920, 126.250},
     {99.450, 111.630},  {103.740, 119.070}, {97.950, 118.950},  {91.270, 118.080},  {97.420, 115.640},
     {65.020, 108.600},  {63.020, 102.320},  {64.590, 103.330},  {63.020, 110.870},  {63.350, 115.460},
     {82.100, 110.520},  {62.650, 99.040},   {63.650, 101.290},  {66.100, 101.790},  {66.040, 107.620},
     {67.310, 99.540},   {82.930, 105.900},  {64.650, 104.500},  {61.690, 101.900},  {61.990, 101.950},
     {61.200, 102.720},  {66.480, 103.470},  {48.160, 97.190},   {54.100, 101.940},  {69.040, 99.880},
     {67.110, 101.800},  {62.450, 98.260},   {65.340, 103.280},  {64.790, 103.990},  {65.840, 105.170},
     {66.990, 97.970},   {66.350, 115.160},  {67.930, 102.890},  {69.280, 102.120},  {69.100, 99.560},
     {60.750, 99.270},   {60.850, 96.940},   {60.620, 97.610},   {77.420, 95.150},   {77.560, 95.510},
     {85.340, 105.530},  {81.290, 101.490},  {81.300, 101.810},  {59.710, 99.300},   {64.420, 100.820},
     {64.090, 106.720},  {65.020, 101.340},  {65.390, 100.480},  {80.980, 105.680},  {60.070, 99.700},
     {64.770, 100.820},  {66.610, 89.970},   {66.630, 89.210},   {64.430, 106.880},  {80.490, 107.930},
     {62.160, 97.300},   {61.190, 90.100},   {64.940, 107.440},  {82.030, 105.540},  {64.940, 107.440},
     {82.030, 105.540},  {59.120, 108.700},  {63.020, 103.380},  {61.870, 110.570},  {64.880, 103.110},
     {79.650, 110.110},  {67.450, 107.100},  {69.660, 103.570},  {70.010, 110.610},  {68.870, 103.480},
     {83.240, 114.710},  {36.510, 98.760},   {49.670, 95.180},   {51.270, 95.540},   {51.040, 100.100},
     {51.040, 100.100},  {51.210, 105.580},  {48.180, 101.880},  {41.290, 94.510},   {42.510, 89.070},
     {47.430, 97.250},   {47.430, 97.250},   {53.260, 89.990},   {61.200, 102.520},  {54.080, 88.130},
     {57.140, 104.160},  {55.340, 101.770},  {53.280, 109.510},  {58.360, 102.630},  {71.170, 110.600},
     {74.350, 86.220},   {72.910, 98.000},   {70.540, 100.420},  {66.370, 93.420},   {68.130, 102.030},
     {69.830, 101.870},  {69.740, 98.120},   {69.560, 115.340},  {68.760, 109.720},  {72.480, 102.290},
     {62.580, 99.510},   {61.230, 101.730},  {63.780, 93.680},   {78.670, 97.830},   {78.860, 98.140},
     {85.870, 112.940},  {84.460, 100.820},  {84.230, 101.760},  {67.280, 106.300},  {70.570, 106.830},
     {70.440, 100.580},  {87.340, 105.750},  {63.300, 88.800},   {65.000, 101.360},  {66.570, 96.530},
     {81.040, 104.980},  {64.300, 106.100},  {68.270, 107.460},  {84.570, 108.150},  {73.070, 107.710},
     {89.700, 105.500},  {73.070, 107.710},  {89.700, 105.500},  {67.650, 104.000},  {69.920, 108.110},
     {67.910, 107.730},  {85.580, 109.620},  {69.610, 98.850},   {69.470, 105.080},  {67.260, 98.200},
     {69.400, 104.870},  {66.610, 108.570},  {84.470, 109.060},  {68.780, 102.120},  {83.340, 112.340},
     {71.860, 100.100},  {69.090, 107.820},  {87.090, 109.750},  {70.950, 119.960},  {70.850, 110.460},
     {72.860, 108.810},  {68.910, 114.230},  {61.190, 106.690},  {61.150, 104.370},  {61.090, 104.490},
     {59.000, 145.960},  {59.000, 145.960},  {76.220, 106.590},  {77.110, 105.040},  {86.500, 117.420},
     {82.540, 109.600},  {75.140, 98.300},   {72.150, 101.460},  {82.710, 109.600},  {88.770, 108.470},
     {72.700, 97.400},   {63.950, 101.730},  {63.280, 101.980},  {64.100, 99.330},   {82.350, 95.730},
     {82.540, 95.950},   {87.130, 111.280},  {81.160, 113.940},  {59.740, 101.000},  {76.850, 113.280},
     {79.510, 103.890},  {62.680, 89.400},   {80.520, 101.210},  {87.030, 106.350},  {87.030, 106.350},
     {102.320, 85.300},  {95.800, 98.200},   {105.800, 98.500},  {113.120, 106.600}, {99.570, 105.290},
     {99.150, 106.930},  {104.500, 110.730}, {103.090, 114.140}, {106.390, 97.900},  {65.960, 103.540},
     {43.060, 96.360},   {61.500, 100.500},  {65.100, 96.900},   {44.980, 97.670},   {59.650, 101.770},
     {44.060, 97.850},   {59.950, 99.660},   {59.600, 101.940},  {61.420, 99.890},   {63.510, 97.800},
     {43.910, 97.660},   {63.720, 96.550},   {62.780, 101.180},  {61.660, 96.940},   {61.970, 101.770},
     {62.590, 100.170},  {61.770, 104.500},  {62.270, 96.980},   {62.860, 111.670},  {64.890, 98.210},
     {64.330, 99.530},   {57.790, 100.310},  {57.640, 100.900},  {76.740, 98.880},   {76.100, 101.180},
     {75.720, 98.710},   {75.730, 99.370},   {60.550, 99.860},   {44.340, 97.500},   {60.100, 97.060},
     {58.350, 100.900},  {43.390, 96.550},   {62.670, 102.820},  {63.640, 99.200},   {44.110, 96.300},
     {70.240, 81.320},   {44.010, 95.200},   {68.840, 97.400},   {48.850, 96.410},   {66.890, 100.600},
     {67.790, 102.200},  {59.520, 97.200},   {35.200, 95.520},   {37.430, 96.190},   {49.970, 92.980},
     {46.470, 98.280},   {48.110, 94.460},   {45.300, 93.210},   {47.100, 95.150},   {46.750, 97.270},
     {48.200, 94.100},   {46.080, 93.060},   {51.150, 101.020},  {49.120, 95.950},   {48.580, 97.350},
     {40.920, 99.110},   {40.500, 95.520},   {40.370, 95.950},   {40.510, 95.540},   {54.390, 95.490},
     {55.380, 92.950},   {53.620, 94.210},   {53.780, 94.610},   {58.550, 105.250},  {73.380, 90.440},
     {64.560, 103.460},  {62.770, 113.800},  {68.780, 107.100},  {68.930, 98.360},   {61.460, 100.530},
     {63.790, 106.220},  {64.100, 109.110},  {64.000, 104.580},  {68.400, 104.990},  {63.350, 98.330},
     {68.360, 104.480},  {69.980, 122.180},  {56.940, 116.740},  {59.320, 107.620},  {78.140, 110.700},
     {79.950, 106.660},  {67.300, 106.650},  {58.990, 103.580},  {56.870, 105.310},  {58.570, 99.090},
     {58.650, 99.100},   {100.040, 98.260},  {100.770, 97.780},  {93.590, 107.580},  {87.250, 131.320},
     {93.360, 109.240},  {65.640, 110.410},  {60.420, 124.800},  {59.340, 104.210},  {44.230, 99.500},
     {63.010, 113.590},  {59.460, 102.550},  {62.470, 103.170},  {63.130, 102.370},  {60.000, 99.570},
     {62.290, 103.260},  {60.600, 117.670},  {62.860, 102.790},  {61.120, 99.800},   {61.960, 116.440},
     {65.550, 98.560},   {65.800, 98.010},   {56.110, 109.270},  {56.940, 103.530},  {60.790, 102.120},
     {56.380, 104.150},  {75.720, 100.170},  {75.600, 101.190},  {58.870, 107.770},  {63.970, 111.640},
     {62.460, 103.510},  {61.910, 116.530},  {36.070, 99.210},   {48.330, 99.910},   {50.250, 109.350},
     {39.650, 98.960},   {49.200, 110.240},  {61.590, 113.220},  {60.270, 110.220},  {68.740, 100.610},
     {67.970, 114.590},  {66.360, 102.540},  {65.230, 120.280},  {67.920, 113.270},  {63.230, 107.610},
     {72.190, 110.600},  {69.560, 95.300},   {66.920, 115.860},  {65.600, 117.990},  {63.000, 114.690},
     {72.990, 95.710},   {72.010, 117.220},  {68.540, 117.390},  {68.880, 116.670},  {56.720, 121.350},
     {57.580, 114.000},  {61.640, 116.430},  {58.150, 109.760},  {72.350, 112.190},  {71.250, 113.890},
     {75.540, 112.780},  {74.810, 118.090},  {71.510, 100.340},  {75.800, 116.140},  {56.350, 110.710},
     {54.380, 114.980},  {61.300, 107.380},  {55.630, 107.780},  {93.720, 96.240},   {90.160, 102.360},
     {98.440, 98.810},   {93.540, 106.300},  {96.270, 104.410},  {67.070, 103.380},  {62.390, 114.650},
     {65.360, 102.920},  {62.070, 102.890},  {64.450, 115.770},  {66.220, 102.790},  {57.300, 106.560},
     {63.330, 109.240},  {64.000, 101.690},  {63.780, 103.340},  {59.060, 106.230},  {43.230, 103.620},
     {63.940, 102.760},  {63.790, 112.500},  {65.260, 101.560},  {65.840, 100.770},  {55.960, 106.270},
     {75.870, 113.400},  {74.660, 103.760},  {59.290, 107.530},  {63.850, 113.980},  {65.600, 101.770},
     {65.310, 103.750},  {57.470, 104.160},  {62.400, 103.700},  {62.360, 115.320},  {65.050, 102.440},
     {63.510, 107.190},  {63.500, 102.120},  {67.910, 99.960},   {69.070, 112.030},  {69.260, 101.980},
     {69.530, 102.700},  {77.040, 117.400},  {34.260, 101.090},  {49.690, 101.320},  {48.280, 116.580},
     {48.850, 101.450},  {52.540, 119.200},  {57.350, 107.170},  {52.720, 115.930},  {56.650, 102.260},
     {73.170, 101.550},  {71.450, 113.780},  {70.250, 106.340},  {70.800, 113.530},  {71.420, 102.400},
     {68.510, 103.370},  {68.130, 104.020},  {68.760, 114.640},  {69.420, 104.180},  {70.640, 101.940},
     {78.990, 117.120},  {62.620, 102.200},  {65.690, 109.780},  {67.490, 98.480},   {69.210, 94.550},
     {64.830, 108.570},  {67.730, 113.430},  {68.960, 102.070},  {69.040, 103.060},  {69.500, 99.510},
     {67.300, 118.910},  {69.360, 103.810},  {70.950, 100.510},  {67.330, 104.110},  {66.800, 103.090},
     {69.370, 108.730},  {68.990, 102.440},  {64.570, 95.680},   {64.720, 112.750},  {66.430, 101.350},
     {66.640, 101.700},  {70.090, 100.480},  {71.250, 102.450},  {71.770, 102.370},  {60.920, 103.530},
     {60.040, 103.830},  {60.070, 101.790},  {64.950, 100.450},  {81.520, 103.240},  {82.230, 101.480},
     {85.370, 102.880},  {80.940, 101.410},  {78.780, 104.330},  {73.530, 115.800},  {69.980, 115.260},
     {70.340, 116.090},  {58.380, 114.600},  {57.310, 115.480},  {56.910, 114.660},  {62.020, 113.440},
     {80.110, 110.230},  {79.570, 111.750},  {81.840, 116.940},  {77.150, 114.560},  {72.510, 101.770},
     {60.190, 103.670},  {63.870, 104.480},  {82.050, 102.520},  {82.310, 101.890},  {76.760, 112.460},
     {80.280, 117.280},  {79.910, 104.590},  {79.620, 102.650},  {57.260, 107.140},  {56.920, 105.230},
     {57.300, 101.620},  {59.250, 112.720},  {98.920, 105.180},  {97.210, 104.560},  {95.280, 107.130},
     {100.790, 114.130}, {93.470, 109.610},  {68.330, 90.800},   {68.730, 90.180},   {68.330, 90.800},
     {68.730, 90.180},   {62.070, 101.440},  {61.820, 103.010},  {65.280, 104.030},  {71.820, 94.140},
     {66.880, 98.700},   {65.620, 115.160},  {64.330, 107.820},  {60.830, 102.990},  {64.550, 97.370},
     {64.310, 96.710},   {83.060, 111.160},  {77.900, 95.110},   {76.420, 95.560},   {65.480, 102.030},
     {64.570, 106.880},  {64.350, 100.790},  {61.170, 99.700},   {81.050, 107.930},  {61.660, 97.300},
     {66.250, 100.550},  {64.690, 107.440},  {64.930, 99.560},   {82.230, 105.540},  {70.820, 101.790},
     {69.640, 107.620},  {66.260, 104.680},  {85.560, 108.600},  {72.340, 108.140},  {68.550, 106.800},
     {70.860, 115.390},  {66.740, 111.600},  {61.500, 109.400},  {63.500, 110.300},  {68.340, 93.680},
     {86.860, 114.840},  {79.730, 97.830},   {78.100, 98.140},   {68.170, 110.240},  {66.630, 104.480},
     {85.380, 109.190},  {70.340, 119.960},  {66.560, 114.230},  {53.630, 145.960},  {65.790, 104.370},
     {65.210, 104.490},  {86.750, 117.420},  {76.900, 106.590},  {75.980, 105.040},  {65.430, 98.240},
     {63.970, 108.280},  {62.850, 110.870},  {85.370, 111.280},  {81.920, 95.730},   {80.670, 95.950},
     {80.550, 107.910},  {83.060, 107.620},  {82.090, 108.730},  {88.130, 178.440},  {99.120, 108.320},
     {98.190, 106.930},  {62.070, 101.440},  {61.820, 103.010},  {65.280, 104.030},  {71.820, 94.140},
     {66.880, 98.700},   {65.620, 115.160},  {64.330, 107.820},  {60.830, 102.990},  {64.550, 97.370},
     {64.310, 96.710},   {83.060, 111.160},  {77.900, 95.110},   {76.420, 95.560},   {65.480, 102.030},
     {64.570, 106.880},  {64.350, 100.790},  {61.170, 99.700},   {81.050, 107.930},  {61.660, 97.300},
     {66.250, 100.550},  {64.690, 107.440},  {64.930, 99.560},   {82.230, 105.540},  {70.820, 101.790},
     {69.640, 107.620},  {66.260, 104.680},  {85.560, 108.600},  {72.340, 108.140},  {68.550, 106.800},
     {70.860, 115.390},  {66.740, 111.600},  {61.500, 109.400},  {63.500, 110.300},  {68.340, 93.680},
     {86.860, 114.840},  {79.730, 97.830},   {78.100, 98.140},   {68.170, 110.240},  {66.630, 104.480},
     {85.380, 109.190},  {70.340, 119.960},  {66.560, 114.230},  {53.630, 145.960},  {65.790, 104.370},
     {65.210, 104.490},  {86.750, 117.420},  {76.900, 106.590},  {75.980, 105.040},  {65.430, 98.240},
     {63.970, 108.280},  {62.850, 110.870},  {85.370, 111.280},  {81.920, 95.730},   {80.670, 95.950},
     {80.550, 107.910},  {83.060, 107.620},  {82.090, 108.730},  {88.130, 178.440},  {99.120, 108.320},
     {98.190, 106.930},  {59.090, 104.790},  {59.140, 104.860},  {59.140, 104.860},  {63.210, 102.460},
     {63.210, 102.460},  {62.960, 113.680},  {60.390, 105.730},  {60.390, 105.730},  {57.460, 103.110},
     {72.950, 99.550},   {71.410, 103.410},  {59.260, 104.150},  {64.720, 107.500},  {58.650, 101.720},
     {59.370, 104.210},  {63.000, 113.790},  {59.370, 104.210},  {63.000, 113.790},  {60.710, 114.470},
     {66.990, 103.220},  {67.560, 114.130},  {66.990, 103.220},  {67.560, 114.130},  {62.400, 116.500},
     {62.400, 116.500},  {57.960, 114.200},  {72.440, 112.810},  {71.990, 113.540},  {61.250, 110.710},
     {61.250, 110.710},  {56.600, 107.780},  {94.100, 96.240},   {90.960, 102.360},  {59.670, 103.830},
     {61.950, 106.890},  {62.250, 117.870},  {65.880, 100.160},  {64.170, 105.390},  {56.690, 106.270},
     {54.980, 113.970},  {70.270, 106.360},  {59.130, 107.550},  {63.640, 113.980},  {65.370, 102.680},
     {64.980, 103.750},  {57.070, 110.360},  {57.910, 104.200},  {59.600, 106.540},  {64.310, 112.160},
     {64.850, 104.770},  {65.240, 103.340},  {59.600, 106.540},  {64.310, 112.160},  {64.850, 104.770},
     {65.240, 103.340},  {61.560, 115.250},  {63.980, 102.140},  {66.040, 95.740},   {67.010, 108.440},
     {62.060, 115.580},  {79.860, 55.100},   {65.180, 122.400},  {85.440, 50.880},   {69.540, 106.290},
     {70.320, 113.210},  {70.530, 104.700},  {71.610, 101.330},  {69.540, 106.290},  {70.320, 113.210},
     {70.530, 104.700},  {71.610, 101.330},  {72.010, 101.780},  {64.390, 104.840},  {64.390, 104.840},
     {60.300, 104.300},  {61.760, 100.450},  {75.730, 100.940},  {77.890, 101.470},  {69.900, 116.140},
     {69.600, 116.790},  {62.460, 114.560},  {62.460, 114.560},  {58.710, 111.370},  {56.790, 120.430},
     {72.020, 101.250},  {60.540, 104.480},  {74.640, 103.860},  {77.620, 102.120},  {70.140, 118.560},
     {74.750, 111.710},  {61.640, 107.140},  {61.640, 107.140},  {55.680, 112.700},  {93.740, 61.540},
     {92.490, 105.170},  {41.150, 117.250},  {42.960, 110.840},  {41.410, 114.700},  {35.940, 117.700},
     {41.390, 116.900},  {45.710, 108.460},  {42.500, 121.200},  {42.540, 116.170},  {50.510, 118.300},
     {63.640, 115.040},  {40.430, 98.020},   {38.910, 92.980},   {37.040, 112.070},  {40.890, 93.550},
     {41.280, 110.360},  {38.790, 102.290},  {39.720, 94.950},   {41.680, 107.090},  {38.840, 96.820},
     {39.410, 95.000},   {41.500, 91.700},   {29.130, 90.600},   {33.080, 90.530},   {43.220, 90.590},
     {40.780, 94.490},   {40.220, 96.070},   {38.790, 92.470},   {40.740, 93.070},   {40.360, 97.080},
     {39.130, 89.530},   {41.060, 106.210},  {42.680, 90.250},   {42.690, 90.060},   {37.780, 94.370},
     {38.650, 96.540},   {36.430, 97.400},   {38.720, 99.180},   {50.930, 89.500},   {48.550, 98.720},
     {48.800, 97.480},   {48.100, 94.660},   {47.970, 95.310},   {39.580, 95.210},   {41.300, 106.630},
     {38.500, 95.070},   {39.630, 86.830},   {38.990, 97.680},   {39.110, 108.340},  {40.030, 106.170},
     {54.250, 48.800},   {40.110, 110.000},  {43.790, 92.710},   {43.870, 106.810},  {47.340, 107.500},
     {23.650, 87.000},   {32.050, 90.510},   {31.160, 110.270},  {34.070, 97.290},   {29.610, 113.910},
     {45.300, 94.020},   {43.950, 110.090},  {47.410, 90.170},   {45.130, 107.570},  {43.100, 91.190},
     {42.290, 109.070},  {37.790, 94.610},   {39.520, 104.910},  {39.810, 103.100},  {41.620, 109.750},
     {43.150, 92.240},   {42.790, 107.540},  {42.570, 91.300},   {42.600, 105.700},  {39.760, 83.400},
     {39.370, 103.580},  {43.170, 100.340},  {46.570, 110.610},  {43.430, 110.130},  {43.590, 109.020},
     {37.660, 106.770},  {39.430, 106.510},  {37.270, 103.360},  {42.180, 96.950},   {50.530, 104.550},
     {48.850, 112.220},  {50.940, 102.840},  {47.960, 107.510},  {44.590, 93.680},   {47.560, 109.490},
     {38.360, 92.620},   {39.590, 95.710},   {40.900, 93.860},   {65.560, 90.170},   {65.560, 90.170},
     {64.380, 93.520},   {58.920, 102.760},  {58.980, 102.640},  {60.000, 108.080},  {61.190, 95.470},
     {41.990, 101.570},  {39.570, 98.990},   {39.450, 100.600},  {39.980, 107.580},  {40.100, 99.990},
     {42.610, 108.230},  {38.710, 102.750},  {38.310, 104.050},  {42.250, 106.580},  {38.390, 102.830},
     {38.480, 103.170},  {39.140, 94.570},   {41.130, 97.110},   {28.120, 100.620},  {31.800, 97.740},
     {39.680, 112.950},  {41.120, 101.380},  {39.940, 102.970},  {38.370, 99.400},   {39.840, 102.810},
     {39.880, 104.310},  {37.590, 99.570},   {41.660, 108.320},  {42.370, 98.600},   {42.970, 96.320},
     {35.860, 106.470},  {37.690, 103.400},  {35.150, 104.120},  {38.150, 103.460},  {48.920, 98.100},
     {48.070, 104.500},  {47.990, 101.950},  {47.570, 101.840},  {47.260, 102.470},  {38.670, 103.080},
     {42.780, 104.070},  {37.620, 101.240},  {36.960, 99.820},   {42.850, 103.630},  {38.290, 101.250},
     {38.940, 99.000},   {39.360, 107.660},  {40.020, 107.970},  {40.270, 102.120},  {53.940, 54.700},
     {39.940, 110.220},  {44.300, 94.700},   {45.290, 106.480},  {22.430, 99.020},   {34.230, 97.270},
     {32.480, 107.600},  {33.730, 99.250},   {29.870, 109.740},  {52.370, 95.520},   {49.300, 107.520},
     {47.050, 98.610},   {45.100, 116.410},  {44.890, 106.960},  {45.860, 103.250},  {44.730, 98.570},
     {45.610, 106.800},  {45.580, 99.260},   {37.520, 101.850},  {41.190, 102.920},  {42.390, 98.040},
     {44.090, 105.670},  {43.940, 94.560},   {43.940, 109.120},  {41.410, 104.160},  {44.260, 105.910},
     {38.320, 91.630},   {39.210, 107.430},  {44.300, 99.230},   {46.090, 100.340},  {47.130, 96.620},
     {37.140, 109.670},  {46.660, 119.730},  {46.380, 108.210},  {46.660, 107.840},  {37.890, 106.610},
     {39.630, 107.070},  {36.540, 105.670},  {40.380, 106.640},  {49.910, 107.850},  {50.300, 110.290},
     {50.330, 106.070},  {49.520, 106.810},  {46.800, 98.700},   {49.150, 107.430},  {37.080, 110.170},
     {38.770, 104.490},  {61.650, 101.990},  {65.560, 90.170},   {61.260, 103.290},  {59.550, 106.430},
     {60.490, 102.640},  {60.770, 109.340},  {60.590, 101.820},  {27.240, 95.640},   {30.170, 95.990},
     {28.660, 97.080},   {28.120, 96.600},   {28.980, 94.840},   {29.040, 95.380},   {28.760, 96.070},
     {30.090, 96.500},   {23.430, 93.720},   {23.210, 96.440},   {32.340, 93.510},   {30.110, 95.820},
     {30.290, 95.590},   {30.070, 95.980},   {29.500, 93.130},   {30.110, 97.380},   {29.730, 101.110},
     {29.630, 92.930},   {30.170, 109.230},  {30.500, 98.640},   {30.880, 98.150},   {27.940, 99.120},
     {26.260, 95.810},   {26.700, 94.220},   {27.090, 94.520},   {32.420, 102.870},  {33.290, 92.160},
     {33.980, 93.830},   {33.890, 99.070},   {33.730, 99.170},   {41.920, 102.920},  {39.460, 99.030},
     {41.480, 98.300},   {39.350, 99.900},   {39.870, 99.560},   {38.710, 100.370},  {40.860, 88.610},
     {40.330, 106.760},  {40.680, 100.510},  {43.660, 89.760},   {51.300, 92.260},   {37.940, 99.920},
     {38.040, 102.120},  {38.610, 100.850},  {38.730, 100.210},  {37.940, 99.400},   {38.750, 94.320},
     {39.670, 97.490},   {35.060, 100.000},  {41.250, 98.440},   {41.260, 96.420},   {40.110, 98.830},
     {39.860, 100.300},  {39.380, 97.790},   {39.740, 100.140},  {39.890, 100.630},  {39.050, 98.620},
     {40.460, 106.600},  {40.850, 98.280},   {40.650, 98.210},   {39.660, 98.410},   {37.720, 98.700},
     {38.030, 98.160},   {37.500, 100.220},  {47.600, 96.370},   {47.470, 101.900},  {48.260, 96.760},
     {47.800, 101.930},  {47.780, 103.100},  {39.270, 98.710},   {41.730, 89.010},   {41.420, 90.360},
     {37.980, 101.050},  {41.150, 97.160},   {40.520, 99.320},   {43.300, 94.760},   {43.300, 94.760},
     {47.820, 104.900},  {41.060, 92.430},   {38.470, 100.290},  {38.920, 101.400},  {41.050, 92.430},
     {41.930, 89.910},   {41.970, 89.740},   {41.560, 97.160},   {40.910, 99.330},   {44.100, 93.610},
     {41.600, 98.810},   {48.670, 102.460},  {41.930, 89.910},   {41.560, 97.160},   {40.910, 99.330},
     {43.630, 95.660},   {41.600, 98.810},   {50.980, 93.360},   {37.900, 103.370},  {54.740, 48.300},
     {41.410, 98.300},   {47.400, 108.300},  {36.380, 106.290},  {45.720, 96.960},   {44.500, 96.750},
     {41.610, 102.340},  {39.760, 101.190},  {41.250, 102.810},  {46.990, 97.750},   {46.580, 99.500},
     {40.860, 107.890},  {41.570, 103.100},  {38.430, 106.430},  {42.690, 104.250},  {43.680, 119.300},
     {38.880, 106.410},  {49.380, 105.390},  {42.400, 102.990},  {49.130, 112.700},  {41.220, 99.520},
     {37.800, 101.670},  {40.330, 89.830},   {60.990, 96.080},   {60.060, 101.260},  {60.590, 101.810},
     {60.410, 107.540},  {60.950, 106.530},  {57.790, 115.040},  {60.570, 108.760},  {38.700, 96.410},
     {39.120, 95.110},   {39.300, 94.950},   {39.300, 94.950},   {40.880, 90.060},   {40.880, 90.060},
     {40.630, 107.880},  {38.060, 94.320},   {38.060, 94.320},   {36.710, 96.460},   {36.650, 95.670},
     {45.310, 91.470},   {46.490, 95.470},   {38.770, 95.210},   {40.550, 106.890},  {38.800, 92.710},
     {39.310, 86.850},   {41.250, 104.490},  {39.430, 94.960},   {40.910, 107.470},  {39.430, 94.960},
     {40.910, 107.470},  {39.710, 106.170},  {41.530, 90.170},   {40.900, 109.200},  {41.530, 90.170},
     {40.900, 109.200},  {38.070, 106.430},  {38.070, 106.430},  {37.160, 104.770},  {36.140, 109.130},
     {44.100, 104.650},  {47.070, 103.410},  {38.750, 92.620},   {38.750, 92.620},   {43.010, 69.230},
     {58.780, 84.900},   {59.380, 93.520},   {38.000, 103.860},  {38.280, 102.190},  {38.030, 103.810},
     {38.030, 103.810},  {39.420, 103.120},  {39.420, 103.120},  {41.280, 108.480},  {35.490, 106.030},
     {35.490, 106.030},  {35.450, 103.620},  {36.330, 103.390},  {44.560, 104.640},  {45.480, 100.780},
     {37.950, 104.040},  {37.720, 105.090},  {40.110, 102.480},  {39.350, 105.450},  {39.330, 103.470},
     {39.330, 105.590},  {41.200, 108.730},  {41.070, 101.250},  {42.320, 92.980},   {37.600, 101.250},
     {37.060, 99.810},   {40.090, 102.390},  {41.420, 107.270},  {40.140, 102.730},  {41.070, 97.200},
     {41.360, 108.420},  {38.220, 102.780},  {41.510, 107.250},  {38.220, 102.780},  {41.510, 107.250},
     {40.090, 107.230},  {45.090, 105.600},  {43.410, 123.530},  {41.520, 102.400},  {44.080, 107.110},
     {42.390, 98.040},   {47.080, 98.040},   {47.080, 98.040},   {41.660, 98.620},   {43.100, 107.060},
     {41.660, 98.620},   {43.100, 107.060},  {43.910, 106.380},  {43.660, 107.500},  {45.300, 121.880},
     {45.210, 106.930},  {44.040, 108.310},  {37.280, 106.900},  {37.280, 106.900},  {36.810, 106.170},
     {37.840, 106.670},  {46.420, 106.330},  {46.560, 106.190},  {36.250, 104.490},  {56.860, 101.990},
     {56.630, 103.290}}};

static constexpr std::array<std::array<const char*, 4>, 714> dihedralsAtomTypes = {
    {{"X", "c", "c", "X"},     {"X", "c", "c1", "X"},    {"X", "c", "cg", "X"},    {"X", "c", "ch", "X"},
     {"X", "c", "c2", "X"},    {"X", "c", "cu", "X"},    {"X", "c", "cv", "X"},    {"X", "c", "ce", "X"},
     {"X", "c", "cf", "X"},    {"X", "c", "c3", "X"},    {"X", "c", "cx", "X"},    {"X", "c", "cy", "X"},
     {"X", "c", "ca", "X"},    {"X", "c", "cc", "X"},    {"X", "c", "cd", "X"},    {"X", "c", "n", "X"},
     {"X", "c", "n2", "X"},    {"X", "c", "nc", "X"},    {"X", "c", "nd", "X"},    {"X", "c", "ne", "X"},
     {"X", "c", "nf", "X"},    {"X", "c", "na", "X"},    {"X", "c", "na", "X"},    {"X", "c", "no", "X"},
     {"X", "c", "oh", "X"},    {"X", "c", "os", "X"},    {"X", "c", "p2", "X"},    {"X", "c", "pc", "X"},
     {"X", "c", "pd", "X"},    {"X", "c", "pe", "X"},    {"X", "c", "pf", "X"},    {"X", "c", "p3", "X"},
     {"X", "c", "p4", "X"},    {"X", "c", "px", "X"},    {"X", "c", "p5", "X"},    {"X", "c", "py", "X"},
     {"X", "c", "sh", "X"},    {"X", "c", "ss", "X"},    {"X", "c", "s4", "X"},    {"X", "c", "sx", "X"},
     {"X", "c", "s6", "X"},    {"X", "c", "sy", "X"},    {"X", "c1", "c1", "X"},   {"X", "c1", "cg", "X"},
     {"X", "c1", "ch", "X"},   {"X", "cg", "cg", "X"},   {"X", "ch", "ch", "X"},   {"X", "cg", "ch", "X"},
     {"X", "c1", "c2", "X"},   {"X", "c1", "c3", "X"},   {"X", "c1", "ca", "X"},   {"X", "c1", "cb", "X"},
     {"X", "c1", "cc", "X"},   {"X", "c1", "cd", "X"},   {"X", "c1", "ce", "X"},   {"X", "c1", "cf", "X"},
     {"X", "c1", "cu", "X"},   {"X", "c1", "cv", "X"},   {"X", "c1", "cx", "X"},   {"X", "c1", "cy", "X"},
     {"X", "c1", "n", "X"},    {"X", "c1", "n2", "X"},   {"X", "c1", "n3", "X"},   {"X", "c1", "n4", "X"},
     {"X", "c1", "na", "X"},   {"X", "c1", "nb", "X"},   {"X", "c1", "nc", "X"},   {"X", "c1", "nd", "X"},
     {"X", "c1", "ne", "X"},   {"X", "c1", "nf", "X"},   {"X", "c1", "nh", "X"},   {"X", "c1", "no", "X"},
     {"X", "c1", "oh", "X"},   {"X", "c1", "os", "X"},   {"X", "c1", "p2", "X"},   {"X", "c1", "pb", "X"},
     {"X", "c1", "pc", "X"},   {"X", "c1", "pd", "X"},   {"X", "c1", "pe", "X"},   {"X", "c1", "pf", "X"},
     {"X", "c1", "p3", "X"},   {"X", "c1", "p4", "X"},   {"X", "c1", "px", "X"},   {"X", "c1", "p5", "X"},
     {"X", "c1", "py", "X"},   {"X", "c1", "s2", "X"},   {"X", "c1", "sh", "X"},   {"X", "c1", "ss", "X"},
     {"X", "c1", "s4", "X"},   {"X", "c1", "sx", "X"},   {"X", "c1", "s6", "X"},   {"X", "c1", "sy", "X"},
     {"X", "c2", "c2", "X"},   {"X", "c2", "ce", "X"},   {"X", "c2", "cf", "X"},   {"X", "ce", "cf", "X"},
     {"X", "ce", "ce", "X"},   {"X", "cf", "cf", "X"},   {"X", "cc", "cd", "X"},   {"X", "cc", "cc", "X"},
     {"X", "cd", "cd", "X"},   {"X", "c2", "c3", "X"},   {"X", "c2", "ca", "X"},   {"X", "c2", "n", "X"},
     {"X", "c2", "n2", "X"},   {"X", "c2", "ne", "X"},   {"X", "c2", "nf", "X"},   {"X", "ce", "ne", "X"},
     {"X", "cf", "nf", "X"},   {"X", "c2", "nc", "X"},   {"X", "c2", "nd", "X"},   {"X", "cc", "nd", "X"},
     {"X", "cd", "nc", "X"},   {"X", "cc", "nc", "X"},   {"X", "cd", "nd", "X"},   {"X", "c2", "n3", "X"},
     {"X", "c2", "n4", "X"},   {"X", "c2", "na", "X"},   {"X", "cc", "na", "X"},   {"X", "cd", "na", "X"},
     {"X", "c2", "nh", "X"},   {"X", "c2", "no", "X"},   {"X", "c2", "oh", "X"},   {"X", "c2", "os", "X"},
     {"X", "c2", "p2", "X"},   {"X", "c2", "pe", "X"},   {"X", "c2", "pf", "X"},   {"X", "ce", "pf", "X"},
     {"X", "ce", "pe", "X"},   {"X", "cf", "pf", "X"},   {"X", "c2", "pc", "X"},   {"X", "c2", "pd", "X"},
     {"X", "cc", "pc", "X"},   {"X", "cc", "pd", "X"},   {"X", "cd", "pc", "X"},   {"X", "cd", "pd", "X"},
     {"X", "c2", "p3", "X"},   {"X", "c2", "p4", "X"},   {"X", "ce", "p4", "X"},   {"X", "cf", "p4", "X"},
     {"X", "c2", "px", "X"},   {"X", "ce", "px", "X"},   {"X", "cf", "px", "X"},   {"X", "c2", "p5", "X"},
     {"X", "ce", "p5", "X"},   {"X", "cf", "p5", "X"},   {"X", "c2", "py", "X"},   {"X", "ce", "py", "X"},
     {"X", "cf", "py", "X"},   {"X", "c2", "sh", "X"},   {"X", "c2", "ss", "X"},   {"X", "c2", "s4", "X"},
     {"X", "ce", "s4", "X"},   {"X", "cf", "s4", "X"},   {"X", "c2", "sx", "X"},   {"X", "ce", "sx", "X"},
     {"X", "cf", "sx", "X"},   {"X", "c2", "s6", "X"},   {"X", "ce", "s6", "X"},   {"X", "cf", "s6", "X"},
     {"X", "c2", "sy", "X"},   {"X", "ce", "sy", "X"},   {"X", "cf", "sy", "X"},   {"X", "c3", "c3", "X"},
     {"X", "cx", "cx", "X"},   {"X", "cy", "cy", "X"},   {"X", "c3", "ca", "X"},   {"X", "c3", "n", "X"},
     {"X", "cx", "n", "X"},    {"X", "cy", "n", "X"},    {"X", "c3", "n2", "X"},   {"X", "c3", "ne", "X"},
     {"X", "c3", "nf", "X"},   {"X", "c3", "n3", "X"},   {"X", "c3", "n4", "X"},   {"X", "c3", "na", "X"},
     {"X", "c3", "nh", "X"},   {"X", "c3", "no", "X"},   {"X", "c3", "oh", "X"},   {"X", "c3", "os", "X"},
     {"X", "c3", "p2", "X"},   {"X", "c3", "pe", "X"},   {"X", "c3", "pf", "X"},   {"X", "c3", "p3", "X"},
     {"X", "c3", "p4", "X"},   {"X", "c3", "px", "X"},   {"X", "c3", "p5", "X"},   {"X", "c3", "py", "X"},
     {"X", "c3", "sh", "X"},   {"X", "c3", "ss", "X"},   {"X", "c3", "s4", "X"},   {"X", "c3", "sx", "X"},
     {"X", "c3", "s6", "X"},   {"X", "c3", "sy", "X"},   {"X", "c3", "cc", "X"},   {"X", "c3", "cd", "X"},
     {"X", "ca", "ca", "X"},   {"X", "ca", "cp", "X"},   {"X", "ca", "cq", "X"},   {"X", "cp", "cp", "X"},
     {"X", "cq", "cq", "X"},   {"X", "ca", "n", "X"},    {"X", "ca", "n2", "X"},   {"X", "ca", "ne", "X"},
     {"X", "ca", "nf", "X"},   {"X", "ca", "n4", "X"},   {"X", "ca", "na", "X"},   {"X", "ca", "nb", "X"},
     {"X", "ca", "nc", "X"},   {"X", "ca", "nd", "X"},   {"X", "ca", "nh", "X"},   {"X", "cc", "nh", "X"},
     {"X", "cd", "nh", "X"},   {"X", "ca", "no", "X"},   {"X", "ca", "oh", "X"},   {"X", "ca", "os", "X"},
     {"X", "ca", "p2", "X"},   {"X", "ca", "pe", "X"},   {"X", "ca", "pf", "X"},   {"X", "ca", "pc", "X"},
     {"X", "ca", "pd", "X"},   {"X", "ca", "p3", "X"},   {"X", "ca", "p4", "X"},   {"X", "ca", "px", "X"},
     {"X", "ca", "p5", "X"},   {"X", "ca", "py", "X"},   {"X", "ca", "sh", "X"},   {"X", "ca", "ss", "X"},
     {"X", "ca", "s4", "X"},   {"X", "ca", "sx", "X"},   {"X", "ca", "s6", "X"},   {"X", "ca", "sy", "X"},
     {"X", "n", "cc", "X"},    {"X", "n", "cd", "X"},    {"X", "n", "n", "X"},     {"X", "n", "n2", "X"},
     {"X", "n", "ne", "X"},    {"X", "n", "nf", "X"},    {"X", "n", "n3", "X"},    {"X", "n", "n4", "X"},
     {"X", "n", "na", "X"},    {"X", "n", "nc", "X"},    {"X", "n", "nd", "X"},    {"X", "n", "nh", "X"},
     {"X", "n", "no", "X"},    {"X", "n", "oh", "X"},    {"X", "n", "os", "X"},    {"X", "n", "p2", "X"},
     {"X", "n", "pe", "X"},    {"X", "n", "pf", "X"},    {"X", "n", "pc", "X"},    {"X", "n", "pd", "X"},
     {"X", "n", "p3", "X"},    {"X", "n", "p4", "X"},    {"X", "n", "px", "X"},    {"X", "n", "p5", "X"},
     {"X", "n", "py", "X"},    {"X", "n", "sh", "X"},    {"X", "n", "ss", "X"},    {"X", "n", "s4", "X"},
     {"X", "n", "sx", "X"},    {"X", "n", "s6", "X"},    {"X", "n", "sy", "X"},    {"X", "n1", "c2", "X"},
     {"X", "n1", "c3", "X"},   {"X", "n1", "ca", "X"},   {"X", "n1", "cb", "X"},   {"X", "n1", "cc", "X"},
     {"X", "n1", "cd", "X"},   {"X", "n1", "ce", "X"},   {"X", "n1", "cf", "X"},   {"X", "n1", "cu", "X"},
     {"X", "n1", "cv", "X"},   {"X", "n1", "cx", "X"},   {"X", "n1", "cy", "X"},   {"X", "n1", "n", "X"},
     {"X", "n1", "n1", "X"},   {"X", "n1", "n2", "X"},   {"X", "n1", "n3", "X"},   {"X", "n1", "n4", "X"},
     {"X", "n1", "na", "X"},   {"X", "n1", "nb", "X"},   {"X", "n1", "nc", "X"},   {"X", "n1", "nd", "X"},
     {"X", "n1", "ne", "X"},   {"X", "n1", "nf", "X"},   {"X", "n1", "nh", "X"},   {"X", "n1", "no", "X"},
     {"X", "n1", "oh", "X"},   {"X", "n1", "os", "X"},   {"X", "n1", "p2", "X"},   {"X", "n1", "pb", "X"},
     {"X", "n1", "pc", "X"},   {"X", "n1", "pd", "X"},   {"X", "n1", "pe", "X"},   {"X", "n1", "pf", "X"},
     {"X", "n1", "p3", "X"},   {"X", "n1", "p4", "X"},   {"X", "n1", "px", "X"},   {"X", "n1", "p5", "X"},
     {"X", "n1", "py", "X"},   {"X", "n1", "s2", "X"},   {"X", "n1", "sh", "X"},   {"X", "n1", "ss", "X"},
     {"X", "n1", "s4", "X"},   {"X", "n1", "sx", "X"},   {"X", "n1", "s6", "X"},   {"X", "n1", "sy", "X"},
     {"X", "n2", "n2", "X"},   {"X", "n2", "n2", "X"},   {"X", "n2", "ne", "X"},   {"X", "n2", "ne", "X"},
     {"X", "n2", "nf", "X"},   {"X", "n2", "nf", "X"},   {"X", "ne", "nf", "X"},   {"X", "ne", "nf", "X"},
     {"X", "ne", "ne", "X"},   {"X", "nf", "nf", "X"},   {"X", "nc", "nc", "X"},   {"X", "nd", "nd", "X"},
     {"X", "nc", "nd", "X"},   {"X", "n2", "nc", "X"},   {"X", "n2", "nc", "X"},   {"X", "n2", "nd", "X"},
     {"X", "n2", "nd", "X"},   {"X", "n2", "n3", "X"},   {"X", "ne", "n3", "X"},   {"X", "nf", "n3", "X"},
     {"X", "n2", "n4", "X"},   {"X", "ne", "n4", "X"},   {"X", "nf", "n4", "X"},   {"X", "n2", "na", "X"},
     {"X", "ne", "na", "X"},   {"X", "nf", "na", "X"},   {"X", "na", "nc", "X"},   {"X", "na", "nd", "X"},
     {"X", "n2", "nh", "X"},   {"X", "ne", "nh", "X"},   {"X", "nf", "nh", "X"},   {"X", "n2", "no", "X"},
     {"X", "ne", "no", "X"},   {"X", "nf", "no", "X"},   {"X", "n2", "oh", "X"},   {"X", "ne", "oh", "X"},
     {"X", "nf", "oh", "X"},   {"X", "n2", "os", "X"},   {"X", "ne", "os", "X"},   {"X", "nf", "os", "X"},
     {"X", "nc", "os", "X"},   {"X", "nc", "ss", "X"},   {"X", "n2", "p2", "X"},   {"X", "n2", "pe", "X"},
     {"X", "n2", "pf", "X"},   {"X", "ne", "pf", "X"},   {"X", "n2", "pc", "X"},   {"X", "n2", "pd", "X"},
     {"X", "nc", "p2", "X"},   {"X", "nd", "p2", "X"},   {"X", "nc", "pc", "X"},   {"X", "nd", "pd", "X"},
     {"X", "nd", "pc", "X"},   {"X", "nc", "pd", "X"},   {"X", "ne", "pe", "X"},   {"X", "nf", "pf", "X"},
     {"X", "n2", "p3", "X"},   {"X", "n2", "p4", "X"},   {"X", "ne", "p4", "X"},   {"X", "nf", "p4", "X"},
     {"X", "n2", "p5", "X"},   {"X", "ne", "p5", "X"},   {"X", "nf", "p5", "X"},   {"X", "ne", "px", "X"},
     {"X", "nf", "px", "X"},   {"X", "n2", "sh", "X"},   {"X", "ne", "sh", "X"},   {"X", "nf", "sh", "X"},
     {"X", "n2", "ss", "X"},   {"X", "n2", "ss", "X"},   {"X", "ne", "ss", "X"},   {"X", "ne", "ss", "X"},
     {"X", "nf", "ss", "X"},   {"X", "nf", "ss", "X"},   {"X", "n2", "s4", "X"},   {"X", "ne", "sx", "X"},
     {"X", "nf", "sx", "X"},   {"X", "n2", "s6", "X"},   {"X", "ne", "sy", "X"},   {"X", "ne", "sy", "X"},
     {"X", "nf", "sy", "X"},   {"X", "nf", "sy", "X"},   {"X", "n3", "n3", "X"},   {"X", "n3", "n4", "X"},
     {"X", "n3", "na", "X"},   {"X", "n3", "nh", "X"},   {"X", "n3", "no", "X"},   {"X", "n3", "oh", "X"},
     {"X", "n3", "os", "X"},   {"X", "n3", "p2", "X"},   {"X", "n3", "pe", "X"},   {"X", "n3", "pf", "X"},
     {"X", "n3", "p3", "X"},   {"X", "n3", "p4", "X"},   {"X", "n3", "px", "X"},   {"X", "n3", "p5", "X"},
     {"X", "n3", "py", "X"},   {"X", "n3", "sh", "X"},   {"X", "n3", "ss", "X"},   {"X", "n3", "s4", "X"},
     {"X", "n3", "sx", "X"},   {"X", "n3", "s6", "X"},   {"X", "n3", "sy", "X"},   {"X", "n4", "n4", "X"},
     {"X", "n4", "na", "X"},   {"X", "n4", "nh", "X"},   {"X", "n4", "no", "X"},   {"X", "n4", "oh", "X"},
     {"X", "n4", "os", "X"},   {"X", "n4", "p2", "X"},   {"X", "n4", "pe", "X"},   {"X", "n4", "pf", "X"},
     {"X", "n4", "p3", "X"},   {"X", "n4", "p4", "X"},   {"X", "n4", "px", "X"},   {"X", "n4", "p5", "X"},
     {"X", "n4", "py", "X"},   {"X", "n4", "sh", "X"},   {"X", "n4", "ss", "X"},   {"X", "n4", "s4", "X"},
     {"X", "n4", "sx", "X"},   {"X", "n4", "s6", "X"},   {"X", "n4", "sy", "X"},   {"X", "na", "na", "X"},
     {"X", "na", "nh", "X"},   {"X", "na", "no", "X"},   {"X", "na", "oh", "X"},   {"X", "na", "os", "X"},
     {"X", "na", "p2", "X"},   {"X", "na", "pe", "X"},   {"X", "na", "pf", "X"},   {"X", "na", "p3", "X"},
     {"X", "na", "p4", "X"},   {"X", "na", "px", "X"},   {"X", "na", "p5", "X"},   {"X", "na", "py", "X"},
     {"X", "na", "sh", "X"},   {"X", "na", "ss", "X"},   {"X", "na", "s4", "X"},   {"X", "na", "sx", "X"},
     {"X", "na", "s6", "X"},   {"X", "na", "sy", "X"},   {"X", "nh", "nh", "X"},   {"X", "nh", "no", "X"},
     {"X", "nh", "oh", "X"},   {"X", "nh", "os", "X"},   {"X", "nh", "p2", "X"},   {"X", "nh", "pe", "X"},
     {"X", "nh", "pf", "X"},   {"X", "nh", "p3", "X"},   {"X", "nh", "p4", "X"},   {"X", "nh", "px", "X"},
     {"X", "nh", "p5", "X"},   {"X", "nh", "py", "X"},   {"X", "nh", "sh", "X"},   {"X", "nh", "ss", "X"},
     {"X", "nh", "s4", "X"},   {"X", "nh", "s4", "X"},   {"X", "nh", "sx", "X"},   {"X", "nh", "sx", "X"},
     {"X", "nh", "s6", "X"},   {"X", "nh", "sy", "X"},   {"X", "no", "no", "X"},   {"X", "no", "no", "X"},
     {"X", "no", "oh", "X"},   {"X", "no", "os", "X"},   {"X", "no", "p2", "X"},   {"X", "no", "pe", "X"},
     {"X", "no", "pf", "X"},   {"X", "no", "p3", "X"},   {"X", "no", "p4", "X"},   {"X", "no", "px", "X"},
     {"X", "no", "p5", "X"},   {"X", "no", "p5", "X"},   {"X", "no", "py", "X"},   {"X", "no", "py", "X"},
     {"X", "no", "sh", "X"},   {"X", "no", "ss", "X"},   {"X", "no", "s4", "X"},   {"X", "no", "sx", "X"},
     {"X", "no", "s6", "X"},   {"X", "no", "sy", "X"},   {"X", "oh", "oh", "X"},   {"X", "oh", "os", "X"},
     {"X", "oh", "p2", "X"},   {"X", "oh", "pe", "X"},   {"X", "oh", "pf", "X"},   {"X", "oh", "p3", "X"},
     {"X", "oh", "p4", "X"},   {"X", "oh", "px", "X"},   {"X", "oh", "p5", "X"},   {"X", "oh", "py", "X"},
     {"X", "oh", "sh", "X"},   {"X", "oh", "ss", "X"},   {"X", "oh", "s4", "X"},   {"X", "oh", "sx", "X"},
     {"X", "oh", "s6", "X"},   {"X", "oh", "sy", "X"},   {"X", "os", "os", "X"},   {"X", "os", "ss", "X"},
     {"X", "os", "sh", "X"},   {"X", "os", "s4", "X"},   {"X", "os", "sx", "X"},   {"X", "os", "s6", "X"},
     {"X", "os", "sy", "X"},   {"X", "os", "p2", "X"},   {"X", "os", "p2", "X"},   {"X", "os", "pe", "X"},
     {"X", "os", "pe", "X"},   {"X", "os", "pf", "X"},   {"X", "os", "pf", "X"},   {"X", "os", "p3", "X"},
     {"X", "os", "p4", "X"},   {"X", "os", "px", "X"},   {"X", "os", "p5", "X"},   {"X", "os", "py", "X"},
     {"X", "p2", "p2", "X"},   {"X", "p2", "pe", "X"},   {"X", "p2", "pf", "X"},   {"X", "p2", "pc", "X"},
     {"X", "p2", "pd", "X"},   {"X", "pe", "pe", "X"},   {"X", "pf", "pf", "X"},   {"X", "pc", "pc", "X"},
     {"X", "pd", "pd", "X"},   {"X", "pc", "pd", "X"},   {"X", "p2", "p3", "X"},   {"X", "pe", "p3", "X"},
     {"X", "pf", "p3", "X"},   {"X", "p2", "p4", "X"},   {"X", "pe", "px", "X"},   {"X", "pf", "px", "X"},
     {"X", "p2", "p5", "X"},   {"X", "pe", "py", "X"},   {"X", "pf", "py", "X"},   {"X", "p2", "sh", "X"},
     {"X", "pe", "sh", "X"},   {"X", "pf", "sh", "X"},   {"X", "p2", "ss", "X"},   {"X", "pe", "ss", "X"},
     {"X", "pf", "ss", "X"},   {"X", "p2", "s4", "X"},   {"X", "pe", "sx", "X"},   {"X", "pf", "sx", "X"},
     {"X", "p2", "s6", "X"},   {"X", "pe", "sy", "X"},   {"X", "pf", "sy", "X"},   {"X", "p3", "p3", "X"},
     {"X", "p3", "p4", "X"},   {"X", "p3", "px", "X"},   {"X", "p3", "p5", "X"},   {"X", "p3", "py", "X"},
     {"X", "p3", "sh", "X"},   {"X", "p3", "ss", "X"},   {"X", "p3", "s4", "X"},   {"X", "p3", "sx", "X"},
     {"X", "p3", "s6", "X"},   {"X", "p3", "sy", "X"},   {"X", "p4", "p4", "X"},   {"X", "px", "px", "X"},
     {"X", "p4", "p5", "X"},   {"X", "px", "py", "X"},   {"X", "p4", "s4", "X"},   {"X", "px", "sx", "X"},
     {"X", "p4", "s6", "X"},   {"X", "px", "sy", "X"},   {"X", "p4", "sh", "X"},   {"X", "px", "sh", "X"},
     {"X", "p4", "ss", "X"},   {"X", "px", "ss", "X"},   {"X", "p5", "p5", "X"},   {"X", "py", "py", "X"},
     {"X", "p5", "sh", "X"},   {"X", "py", "sh", "X"},   {"X", "p5", "ss", "X"},   {"X", "py", "ss", "X"},
     {"X", "p5", "s4", "X"},   {"X", "py", "sx", "X"},   {"X", "p5", "s6", "X"},   {"X", "py", "sy", "X"},
     {"X", "sh", "sh", "X"},   {"X", "sh", "ss", "X"},   {"X", "sh", "s4", "X"},   {"X", "sh", "sx", "X"},
     {"X", "sh", "s6", "X"},   {"X", "sh", "sy", "X"},   {"X", "ss", "ss", "X"},   {"X", "ss", "s4", "X"},
     {"X", "ss", "sx", "X"},   {"X", "ss", "s6", "X"},   {"X", "ss", "sy", "X"},   {"X", "s4", "s4", "X"},
     {"X", "sx", "sx", "X"},   {"X", "s4", "s6", "X"},   {"X", "sx", "sy", "X"},   {"X", "s6", "s6", "X"},
     {"X", "sy", "sy", "X"},   {"c3", "c", "sh", "hs"},  {"c3", "c", "sh", "hs"},  {"c2", "c2", "ss", "c3"},
     {"c2", "c2", "ss", "c3"}, {"c2", "c2", "n", "c"},   {"c2", "c2", "n", "c"},   {"c", "n", "p2", "c2"},
     {"c", "n", "p2", "c2"},   {"n", "c3", "c", "n"},    {"n", "c3", "c", "n"},    {"c", "n", "c3", "c"},
     {"c", "n", "c3", "c"},    {"c3", "c3", "n", "c"},   {"c3", "c3", "n", "c"},   {"c3", "c3", "n", "c"},
     {"c3", "c3", "c", "n"},   {"c3", "c3", "c", "n"},   {"c2", "ne", "p5", "o"},  {"c2", "ne", "p5", "o"},
     {"c2", "nf", "p5", "o"},  {"c2", "nf", "p5", "o"},  {"ce", "ne", "p5", "o"},  {"ce", "ne", "p5", "o"},
     {"ce", "nf", "p5", "o"},  {"ce", "nf", "p5", "o"},  {"cf", "ne", "p5", "o"},  {"cf", "ne", "p5", "o"},
     {"cf", "nf", "p5", "o"},  {"cf", "nf", "p5", "o"},  {"hn", "n", "c", "o"},    {"hn", "n", "c", "o"},
     {"c3", "ss", "ss", "c3"}, {"c3", "ss", "ss", "c3"}, {"c3", "n3", "nh", "ca"}, {"c3", "n3", "nh", "ca"},
     {"c3", "n3", "p5", "o"},  {"c3", "n3", "p5", "o"},  {"ca", "nh", "oh", "ho"}, {"ca", "nh", "oh", "ho"},
     {"oh", "p5", "os", "c3"}, {"oh", "p5", "os", "c3"}, {"os", "p5", "os", "c3"}, {"os", "p5", "os", "c3"},
     {"h1", "c3", "c", "o"},   {"h1", "c3", "c", "o"},   {"hc", "c3", "c", "o"},   {"hc", "c3", "c", "o"},
     {"hc", "c3", "c3", "hc"}, {"hc", "c3", "c3", "c3"}, {"hc", "c3", "c2", "c2"}, {"hc", "c3", "c2", "c2"},
     {"ho", "oh", "c3", "c3"}, {"ho", "oh", "c3", "c3"}, {"ho", "oh", "c", "o"},   {"ho", "oh", "c", "o"},
     {"c2", "c2", "c", "o"},   {"c2", "c2", "c", "o"},   {"c3", "c2", "c2", "c3"}, {"c3", "c2", "c2", "c3"},
     {"c3", "c3", "c3", "c3"}, {"c3", "c3", "c3", "c3"}, {"c3", "c3", "c3", "c3"}, {"c3", "c3", "n3", "c3"},
     {"c3", "c3", "n3", "c3"}, {"c3", "c3", "os", "c3"}, {"c3", "c3", "os", "c3"}, {"c3", "c3", "os", "c"},
     {"c3", "c3", "os", "c"},  {"c3", "os", "c3", "os"}, {"c3", "os", "c3", "os"}, {"c3", "os", "c3", "os"},
     {"c3", "os", "c3", "na"}, {"c3", "os", "c3", "na"}, {"o", "c", "os", "c3"},   {"o", "c", "os", "c3"},
     {"os", "c3", "na", "c2"}, {"os", "c3", "na", "c2"}, {"os", "c3", "c3", "os"}, {"os", "c3", "c3", "os"},
     {"os", "c3", "c3", "oh"}, {"os", "c3", "c3", "oh"}, {"oh", "c3", "c3", "oh"}, {"oh", "c3", "c3", "oh"},
     {"f", "c3", "c3", "f"},   {"f", "c3", "c3", "f"},   {"cl", "c3", "c3", "cl"}, {"cl", "c3", "c3", "cl"},
     {"br", "c3", "c3", "br"}, {"br", "c3", "c3", "br"}, {"h1", "c3", "c3", "os"}, {"h1", "c3", "c3", "os"},
     {"h1", "c3", "c3", "oh"}, {"h1", "c3", "c3", "oh"}, {"h1", "c3", "c3", "f"},  {"h1", "c3", "c3", "f"},
     {"h1", "c3", "c3", "cl"}, {"h1", "c3", "c3", "cl"}, {"h1", "c3", "c3", "br"}, {"h1", "c3", "c3", "br"},
     {"hc", "c3", "c3", "os"}, {"hc", "c3", "c3", "os"}, {"hc", "c3", "c3", "oh"}, {"hc", "c3", "c3", "oh"},
     {"hc", "c3", "c3", "f"},  {"hc", "c3", "c3", "f"},  {"hc", "c3", "c3", "cl"}, {"hc", "c3", "c3", "cl"},
     {"hc", "c3", "c3", "br"}, {"hc", "c3", "c3", "br"}}};

static constexpr std::array<std::array<double, 4>, 714> dihedralsParameters = {
    {{4., 1.200, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {4., 8.700, 180.000, 2.000},  {4., 8.700, 180.000, 2.000},
     {4., 8.700, 180.000, 2.000},  {4., 8.700, 180.000, 2.000},  {4., 8.700, 180.000, 2.000},
     {6., 0.000, 180.000, 2.000},  {6., 0.000, 180.000, 2.000},  {6., 0.000, 180.000, 2.000},
     {4., 14.500, 180.000, 2.000}, {4., 11.500, 180.000, 2.000}, {4., 11.500, 180.000, 2.000},
     {4., 10.000, 180.000, 2.000}, {2., 8.300, 180.000, 2.000},  {2., 8.00, 180.000, 2.000},
     {2., 8.00, 180.000, 2.000},   {2., 0.400, 180.000, 2.000},  {2., 0.400, 180.000, 2.000},
     {4., 5.800, 180.000, 2.000},  {4., 1.400, 180.000, 4.000},  {4., 1.800, 180.000, 2.000},
     {2., 4.600, 180.000, 2.000},  {2., 5.400, 180.000, 2.000},  {2., 13.300, 180.000, 2.000},
     {2., 4.000, 180.000, 2.000},  {2., 4.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {4., 6.200, 180.000, 2.000},  {4., 5.400, 180.000, 2.000},
     {4., 5.400, 180.000, 2.000},  {4., 4.000, 0.000, 2.000},    {4., 4.000, 0.000, 2.000},
     {2., 4.500, 180.000, 2.000},  {2., 6.200, 180.000, 2.000},  {4., 0.800, 180.000, 2.000},
     {4., 0.800, 180.000, 2.000},  {6., 3.000, 0.000, 2.000},    {6., 3.000, 0.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},  {4., 26.600, 180.000, 2.000},
     {4., 26.600, 180.000, 2.000}, {4., 26.600, 180.000, 2.000}, {4., 26.600, 180.000, 2.000},
     {4., 4.000, 180.000, 2.000},  {4., 4.000, 180.000, 2.000},  {4., 16.000, 180.000, 2.000},
     {4., 16.000, 180.000, 2.000}, {4., 16.000, 180.000, 2.000}, {6., 0.000, 0.000, 2.000},
     {4., 10.200, 180.000, 2.000}, {4., 2.600, 180.000, 2.000},  {2., 8.300, 180.000, 2.000},
     {2., 8.300, 180.000, 2.000},  {2., 8.300, 180.000, 2.000},  {2., 1.600, 180.000, 2.000},
     {2., 1.600, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},
     {2., 9.500, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},
     {2., 9.500, 180.000, 2.000},  {4., 1.200, 180.000, 2.000},  {6., 0.000, 180.000, 3.000},
     {4., 2.500, 180.000, 2.000},  {4., 6.800, 180.000, 2.000},  {4., 6.800, 180.000, 2.000},
     {4., 2.700, 180.000, 2.000},  {4., 3.000, 180.000, 2.000},  {2., 2.100, 180.000, 2.000},
     {2., 2.100, 180.000, 2.000},  {2., 13.300, 180.000, 2.000}, {2., 13.300, 180.000, 2.000},
     {2., 13.300, 180.000, 2.000}, {2., 13.300, 180.000, 2.000}, {2., 1.900, 180.000, 2.000},
     {2., 1.900, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},
     {2., 9.500, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},  {2., 9.500, 180.000, 2.000},
     {2., 9.500, 180.000, 2.000},  {4., 1.800, 180.000, 2.000},  {4., 26.600, 180.000, 2.000},
     {4., 26.600, 180.000, 2.000}, {4., 26.600, 180.000, 2.000}, {4., 1.300, 0.000, 2.000},
     {4., 1.300, 0.000, 2.000},    {4., 1.300, 0.000, 2.000},    {6., 39.900, 180.000, 2.000},
     {6., 39.900, 180.000, 2.000}, {6., 39.900, 180.000, 2.000}, {6., 8.600, 180.000, 2.000},
     {6., 8.600, 180.000, 2.000},  {6., 8.600, 180.000, 2.000},  {2., 1.000, 180.000, 2.000},
     {2., 2.200, 180.000, 2.000},  {4., 26.600, 180.000, 2.000}, {4., 26.600, 180.000, 2.000},
     {4., 26.600, 180.000, 2.000}, {4., 2.400, 0.000, 2.000},    {4., 2.400, 0.000, 2.000},
     {4., 2.400, 0.000, 2.000},    {6., 39.900, 180.000, 2.000}, {6., 39.900, 180.000, 2.000},
     {6., 39.900, 180.000, 2.000}, {6., 7.600, 180.000, 2.000},  {6., 7.600, 180.000, 2.000},
     {6., 7.600, 180.000, 2.000},  {9., 1.400, 0.000, 3.000},    {9., 1.400, 0.000, 3.000},
     {9., 1.400, 0.000, 3.000},    {6., 0.000, 0.000, 2.000},    {6., 0.000, 0.000, 2.000},
     {6., 0.000, 0.000, 2.000},    {6., 0.000, 0.000, 2.000},    {6., 0.000, 0.000, 3.000},
     {6., 0.000, 0.000, 3.000},    {6., 0.000, 0.000, 3.000},    {6., 1.800, 0.000, 3.000},
     {9., 1.400, 0.000, 3.000},    {6., 0.000, 0.000, 2.000},    {6., 0.000, 0.000, 2.000},
     {6., 0.000, 0.000, 2.000},    {3., 0.500, 0.000, 3.000},    {3., 1.150, 0.000, 3.000},
     {3., 0.800, 180.000, 2.000},  {3., 0.800, 180.000, 2.000},  {3., 0.800, 180.000, 2.000},
     {6., 0.800, 0.000, 3.000},    {6., 0.800, 0.000, 3.000},    {6., 0.800, 0.000, 3.000},
     {9., 0.200, 0.000, 3.000},    {9., 0.200, 0.000, 3.000},    {3., 0.750, 0.000, 3.000},
     {3., 1.000, 0.000, 3.000},    {6., 1.200, 0.000, 3.000},    {6., 1.200, 0.000, 3.000},
     {9., 1.300, 0.000, 3.000},    {9., 1.300, 0.000, 3.000},    {6., 0.000, 0.000, 3.000},
     {6., 0.000, 0.000, 3.000},    {4., 14.500, 180.000, 2.000}, {4., 14.500, 180.000, 2.000},
     {4., 14.500, 180.000, 2.000}, {4., 4.000, 180.000, 2.000},  {4., 4.000, 180.000, 2.000},
     {4., 1.800, 180.000, 2.000},  {2., 0.000, 180.000, 3.000},  {2., 0.000, 180.000, 3.000},
     {2., 0.000, 180.000, 3.000},  {4., 7.000, 0.000, 2.000},    {4., 1.200, 180.000, 2.000},
     {2., 9.60, 180.0, 2.000},     {2., 9.60, 180.0, 2.000},     {2., 9.60, 180.0, 2.000},
     {4., 4.200, 180.000, 2.000},  {4., 4.200, 180.000, 2.000},  {4., 4.200, 180.000, 2.000},
     {4., 2.400, 180.000, 2.000},  {2., 1.800, 180.000, 2.000},  {2., 1.800, 180.000, 2.000},
     {2., 1.200, 180.000, 2.000},  {2., 1.200, 180.000, 2.000},  {2., 1.200, 180.000, 2.000},
     {2., 9.600, 180.000, 2.000},  {2., 9.600, 180.000, 2.000},  {4., 0.000, 180.000, 2.000},
     {4., 2.100, 180.000, 2.000},  {4., 2.100, 180.000, 2.000},  {6., 8.800, 180.000, 2.000},
     {6., 8.800, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.800, 180.000, 2.000},
     {4., 1.200, 0.000, 2.000},    {4., 1.200, 0.000, 2.000},    {6., 7.800, 180.000, 2.000},
     {6., 7.800, 180.000, 2.000},  {4., 6.600, 180.000, 2.000},  {4., 6.600, 180.000, 2.000},
     {4., 4.600, 0.000, 2.000},    {2., 0.800, 0.000, 2.000},    {2., 0.800, 0.000, 2.000},
     {2., 0.800, 0.000, 2.000},    {4., 4.300, 0.000, 2.000},    {4., 3.800, 0.000, 2.000},
     {4., 2.800, 0.000, 2.000},    {2., 9.600, 180.000, 2.000},  {2., 9.600, 180.000, 2.000},
     {4., 4.400, 0.000, 2.000},    {4., 5.500, 180.000, 2.000},  {2., 3.000, 0.000, 2.000},
     {2., 2.200, 0.000, 2.000},    {2., 2.000, 180.000, 2.000},  {2., 2.000, 180.000, 2.000},
     {2., 9.600, 180.000, 2.000},  {2., 9.600, 180.000, 2.000},  {2., 2.000, 180.000, 2.000},
     {4., 9.000, 0.000, 2.000},    {4., 1.300, 0.000, 2.000},    {4., 1.300, 0.000, 2.000},
     {6., 13.200, 180.000, 2.000}, {6., 13.200, 180.000, 2.000}, {2., 2.200, 0.000, 2.000},
     {2., 3.000, 0.000, 2.000},    {4., 6.000, 0.000, 3.000},    {4., 6.000, 0.000, 3.000},
     {6., 6.600, 180.000, 2.000},  {6., 6.600, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},  {1., 0.000, 180.000, 2.000},
     {1., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},  {2., 0.000, 180.000, 2.000},
     {3., 0.000, 180.000, 2.000},  {3., 0.000, 180.000, 2.000},  {1., 3.000, 180.000, 2.000},
     {1., 2.800, 0.000, 1.000},    {1., 3.000, 180.000, 2.000},  {1., 2.800, 0.000, 1.000},
     {1., 3.000, 180.000, 2.000},  {1., 2.800, 0.000, 1.000},    {1., 3.000, 180.000, 2.000},
     {1., 2.800, 0.000, 1.000},    {1., 1.200, 180.000, 2.000},  {1., 1.200, 180.000, 2.000},
     {1., 4.000, 180.000, 2.000},  {1., 4.000, 180.000, 2.000},  {1., 4.000, 180.000, 2.000},
     {1., 3.000, 180.000, 2.000},  {1., 2.800, 0.000, 1.000},    {1., 3.000, 180.000, 2.000},
     {1., 2.800, 0.000, 1.000},    {2., 12.200, 180.000, 2.000}, {2., 12.200, 180.000, 2.000},
     {2., 12.200, 180.000, 2.000}, {3., 24.000, 180.000, 2.000}, {3., 24.000, 180.000, 2.000},
     {3., 24.000, 180.000, 2.000}, {2., 3.400, 180.000, 2.000},  {2., 3.400, 180.000, 2.000},
     {2., 3.400, 180.000, 2.000},  {2., 9.600, 180.000, 2.000},  {2., 9.600, 180.000, 2.000},
     {2., 5.600, 180.000, 2.000},  {2., 5.600, 180.000, 2.000},  {2., 5.600, 180.000, 2.000},
     {2., 1.500, 180.000, 2.000},  {2., 1.500, 180.000, 2.000},  {2., 1.500, 180.000, 2.000},
     {1., 3.200, 180.000, 2.000},  {1., 3.200, 180.000, 2.000},  {1., 3.200, 180.000, 2.000},
     {1., 3.000, 180.000, 2.000},  {1., 3.000, 180.000, 2.000},  {1., 3.000, 180.000, 2.000},
     {1., 4.800, 180.000, 2.000},  {1., 4.800, 180.000, 2.000},  {1., 5.400, 180.000, 2.000},
     {1., 5.400, 180.000, 2.000},  {1., 5.400, 180.000, 2.000},  {1., 5.400, 180.000, 2.000},
     {1., 5.400, 180.000, 2.000},  {1., 5.400, 180.000, 2.000},  {1., 5.400, 180.000, 2.000},
     {1., 5.400, 180.000, 2.000},  {1., 6.600, 180.000, 2.000},  {1., 6.600, 180.000, 2.000},
     {1., 6.600, 180.000, 2.000},  {1., 6.600, 180.000, 2.000},  {1., 0.600, 0.000, 1.000},
     {1., 0.600, 0.000, 1.000},    {2., 4.200, 180.000, 2.000},  {2., 13.300, 180.000, 2.000},
     {2., 13.300, 180.000, 2.000}, {2., 13.300, 180.000, 2.000}, {3., 20.000, 180.000, 2.000},
     {3., 3.000, 180.000, 3.000},  {3., 3.000, 180.000, 3.000},  {3., 3.000, 180.000, 3.000},
     {3., 3.000, 180.000, 3.000},  {1., 2.100, 180.000, 2.000},  {1., 2.100, 180.000, 2.000},
     {1., 2.100, 180.000, 2.000},  {1., 2.800, 180.000, 2.000},  {1., 1.300, 180.000, 1.000},
     {1., 2.800, 180.000, 2.000},  {1., 1.300, 180.000, 1.000},  {1., 2.800, 180.000, 2.000},
     {1., 1.300, 180.000, 1.000},  {2., 13.300, 180.000, 2.000}, {2., 3.000, 180.000, 3.000},
     {2., 3.000, 180.000, 3.000},  {3., 20.000, 180.000, 2.000}, {3., 1.500, 180.000, 3.000},
     {3., 20.400, 180.000, 1.000}, {3., 1.500, 180.000, 3.000},  {3., 20.400, 180.000, 1.000},
     {4., 9.000, 0.000, 2.000},    {6., 1.500, 0.000, 3.000},    {4., 6.400, 0.000, 2.000},
     {4., 7.600, 0.000, 2.000},    {4., 16.000, 180.000, 2.000}, {1., 2.200, 0.000, 2.000},
     {1., 1.800, 0.000, 2.000},    {2., 6.400, 180.000, 2.000},  {2., 6.400, 180.000, 2.000},
     {2., 6.400, 180.000, 2.000},  {4., 9.400, 0.000, 2.000},    {4., 8.400, 180.000, 2.000},
     {4., 8.400, 180.000, 2.000},  {6., 18.000, 180.000, 2.000}, {6., 18.000, 180.000, 2.000},
     {1., 3.100, 0.000, 2.000},    {1., 2.600, 0.000, 2.000},    {4., 15.000, 0.000, 2.000},
     {4., 15.000, 0.000, 2.000},   {6., 18.800, 0.000, 2.000},   {6., 18.800, 0.000, 2.000},
     {9., 1.700, 0.000, 3.000},    {6., 1.400, 0.000, 3.000},    {6., 1.100, 0.000, 3.000},
     {6., 0.500, 180.000, 3.000},  {3., 1.000, 0.000, 3.000},    {3., 1.700, 0.000, 3.000},
     {3., 0.500, 180.000, 3.000},  {3., 0.500, 180.000, 3.000},  {3., 0.500, 180.000, 3.000},
     {6., 0.900, 0.000, 3.000},    {4., 0.200, 0.000, 3.000},    {4., 0.200, 0.000, 3.000},
     {9., 0.800, 0.000, 3.000},    {9., 0.800, 0.000, 3.000},    {3., 2.000, 0.000, 3.000},
     {3., 1.000, 0.000, 3.000},    {6., 1.700, 0.000, 3.000},    {6., 1.700, 0.000, 3.000},
     {9., 1.200, 0.000, 3.000},    {9., 1.200, 0.000, 3.000},    {4., 3.600, 0.000, 2.000},
     {4., 4.800, 0.000, 2.000},    {4., 24.000, 180.000, 2.000}, {2., 2.000, 0.000, 2.000},
     {2., 1.300, 0.000, 2.000},    {1., 1.000, 180.000, 2.000},  {1., 1.000, 180.000, 2.000},
     {1., 1.000, 180.000, 2.000},  {4., 5.800, 0.000, 2.000},    {4., 4.400, 0.000, 3.000},
     {4., 4.400, 0.000, 3.000},    {6., 5.000, 180.000, 2.000},  {6., 5.000, 180.000, 2.000},
     {2., 3.600, 0.000, 2.000},    {2., 15.600, 0.000, 2.000},   {4., 4.200, 0.000, 2.000},
     {4., 4.200, 0.000, 2.000},    {6., 22.000, 180.000, 2.000}, {6., 22.000, 180.000, 2.000},
     {4., 7.200, 180.000, 3.000},  {4., 10.200, 180.000, 2.000}, {2., 3.000, 0.000, 2.000},
     {2., 3.000, 0.000, 1.000},    {2., 2.800, 180.000, 2.000},  {2., 2.800, 180.000, 2.000},
     {2., 2.800, 180.000, 2.000},  {4., 9.400, 0.000, 2.000},    {4., 4.700, 0.000, 3.000},
     {4., 4.700, 0.000, 3.000},    {6., 4.800, 0.000, 2.000},    {6., 4.800, 0.000, 2.000},
     {2., 3.200, 0.000, 2.000},    {2., 4.200, 0.000, 2.000},    {4., 3.000, 0.000, 2.000},
     {4., 0.400, 180.000, 3.000},  {4., 3.000, 0.000, 2.000},    {4., 0.400, 180.000, 3.000},
     {6., 0.600, 180.000, 2.000},  {6., 0.600, 180.000, 2.000},  {4., 1.600, 180.000, 4.000},
     {4., 7.200, 180.000, 2.000},  {2., 7.800, 180.000, 2.000},  {2., 6.000, 180.000, 2.000},
     {1., 0.300, 180.000, 2.000},  {1., 0.300, 180.000, 2.000},  {1., 0.300, 180.000, 2.000},
     {4., 7.600, 180.000, 2.000},  {4., 2.300, 180.000, 2.000},  {4., 2.300, 180.000, 2.000},
     {6., 14.400, 0.000, 2.000},   {6., 2.400, 0.000, 3.000},    {6., 14.400, 0.000, 2.000},
     {6., 2.400, 0.000, 3.000},    {2., 4.600, 180.000, 2.000},  {2., 5.400, 180.000, 2.000},
     {4., 10.400, 180.000, 2.000}, {4., 10.400, 180.000, 2.000}, {6., 2.000, 0.000, 2.000},
     {6., 2.000, 0.000, 2.000},    {1., 1.600, 0.000, 2.000},    {1., 1.600, 0.000, 2.000},
     {1., 1.500, 180.000, 2.000},  {1., 1.500, 180.000, 2.000},  {1., 1.500, 180.000, 2.000},
     {2., 0.800, 180.000, 3.000},  {2., 1.400, 0.000, 1.000},    {2., 1.400, 0.000, 1.000},
     {3., 1.600, 0.000, 3.000},    {3., 1.600, 0.000, 3.000},    {1., 2.400, 0.000, 2.000},
     {1., 2.400, 0.000, 2.000},    {2., 10.000, 0.000, 1.000},   {2., 10.000, 0.000, 1.000},
     {3., 28.500, 180.000, 1.000}, {3., 28.500, 180.000, 1.000}, {1., 1.000, 0.000, 1.000},
     {1., 2.200, 0.000, 2.000},    {1., 1.800, 0.000, 2.000},    {2., 3.300, 0.000, 3.000},
     {2., 3.300, 0.000, 3.000},    {3., 3.600, 180.000, 2.000},  {3., 3.600, 180.000, 2.000},
     {1., 3.000, 180.000, 2.000},  {1., 2.000, 180.000, 1.000},  {1., 3.000, 180.000, 2.000},
     {1., 2.000, 180.000, 1.000},  {1., 3.000, 180.000, 2.000},  {1., 2.000, 180.000, 1.000},
     {2., 4.400, 0.000, 2.000},    {2., 2.100, 180.000, 2.000},  {2., 2.100, 180.000, 2.000},
     {3., 2.400, 0.000, 2.000},    {3., 2.400, 0.000, 2.000},    {1., 6.600, 180.000, 2.000},
     {1., 6.600, 180.000, 2.000},  {1., 6.600, 180.000, 2.000},  {1., 6.600, 180.000, 2.000},
     {1., 6.600, 180.000, 2.000},  {1., 1.200, 180.000, 2.000},  {1., 1.200, 180.000, 2.000},
     {1., 7.200, 180.000, 2.000},  {1., 7.200, 180.000, 2.000},  {1., 7.200, 180.000, 2.000},
     {2., 2.400, 0.000, 1.000},    {2., 2.400, 0.000, 1.000},    {2., 2.400, 0.000, 1.000},
     {2., 13.300, 180.000, 2.000}, {2., 4.900, 0.000, 2.000},    {2., 4.900, 0.000, 2.000},
     {3., 20.000, 180.000, 2.000}, {3., 5.700, 0.000, 1.000},    {3., 5.700, 0.000, 1.000},
     {1., 1.400, 180.000, 2.000},  {1., 1.400, 180.000, 2.000},  {1., 1.400, 180.000, 2.000},
     {1., 1.400, 180.000, 2.000},  {1., 1.400, 180.000, 2.000},  {1., 1.400, 180.000, 2.000},
     {2., 13.300, 180.000, 2.000}, {2., 3.000, 0.000, 2.000},    {2., 3.000, 0.000, 2.000},
     {3., 20.000, 180.000, 2.000}, {3., 1.200, 180.000, 3.000},  {3., 1.200, 180.000, 3.000},
     {4., 2.000, 0.000, 3.000},    {4., 3.600, 0.000, 1.000},    {4., 3.600, 0.000, 1.000},
     {6., 11.000, 180.000, 2.000}, {6., 11.000, 180.000, 2.000}, {2., 9.200, 0.000, 2.000},
     {2., 2.300, 0.000, 3.000},    {4., 15.400, 0.000, 2.000},   {4., 15.400, 0.000, 2.000},
     {6., 1.600, 0.000, 3.000},    {6., 1.600, 0.000, 3.000},    {4., 26.600, 180.000, 2.000},
     {4., 5.800, 180.000, 2.000},  {6., 39.900, 180.000, 2.000}, {6., 1.900, 180.000, 2.000},
     {4., 26.600, 180.000, 2.000}, {4., 3.400, 0.000, 1.000},    {6., 39.900, 180.000, 2.000},
     {6., 0.700, 0.000, 3.000},    {2., 0.500, 180.000, 1.000},  {2., 0.500, 180.000, 1.000},
     {2., 1.200, 180.000, 2.000},  {2., 1.200, 180.000, 2.000},  {9., 60.000, 180.000, 2.000},
     {9., 5.400, 0.000, 2.000},    {3., 0.900, 0.000, 3.000},    {3., 0.900, 0.000, 3.000},
     {3., 11.400, 180.000, 2.000}, {3., 11.400, 180.000, 2.000}, {6., 40.000, 180.000, 2.000},
     {6., 1.600, 0.000, 3.000},    {9., 60.000, 180.000, 2.000}, {9., 2.500, 0.000, 3.000},
     {1., 5.600, 0.000, 3.000},    {1., 5.300, 0.000, 3.000},    {2., 1.400, 0.000, 3.000},
     {2., 1.400, 0.000, 3.000},    {3., 14.000, 180.000, 2.000}, {3., 14.000, 180.000, 2.000},
     {1., 0.000, 0.000, 3.000},    {2., 0.600, 0.000, 3.000},    {2., 0.600, 0.000, 3.000},
     {3., 9.200, 180.000, 2.000},  {3., 9.200, 180.000, 2.000},  {4., 26.600, 180.000, 2.000},
     {4., 2.500, 0.000, 3.000},    {6., 40.000, 180.000, 2.000}, {6., 26.000, 180.000, 2.000},
     {9., 60.000, 180.000, 2.000}, {9., 1.400, 180.000, 2.000},  {1., 2.250, 180.000, 2.000},
     {1., 1.300, 180.000, 1.000},  {1., 1.100, 180.000, 2.000},  {1., 0.700, 180.000, 3.000},
     {1., 0.650, 180.000, 2.000},  {1., 1.200, 180.000, 1.000},  {1., 1.000, 180.000, 2.000},
     {1., 1.900, 180.000, 1.000},  {1., 1.700, 180.000, 1.},     {1., 2.000, 180.000, 2.},
     {1., 0.850, 180.000, 2.},     {1., 0.800, 0.000, 1.},       {1., 0.50, 180.0, 4.},
     {1., 0.15, 180.0, 3.},        {1., 0.53, 0.0, 1.},          {1., 0.100, 0.0, 4.},
     {1., 0.07, 0.0, 2.},          {1., 0.00, 0.0, 3.},          {1., 2.30, 0.0, 1.},
     {1., 0.00, 0.0, 3.},          {1., 2.30, 0.0, 1.},          {1., 0.00, 0.0, 3.},
     {1., 2.30, 0.0, 1.},          {1., 0.00, 0.0, 3.},          {1., 2.30, 0.0, 1.},
     {1., 0.00, 0.0, 3.},          {1., 2.30, 0.0, 1.},          {1., 0.00, 0.0, 3.},
     {1., 2.30, 0.0, 1.},          {1., 2.50, 180.0, 2.},        {1., 2.00, 0.0, 1.},
     {1., 3.50, 0.0, 2.},          {1., 0.60, 0.0, 3.},          {1., 1.90, 0.0, 2.},
     {1., 1.90, 0.0, 3.},          {1., 3.00, 180.0, 2.},        {1., 2.30, 0.0, 3.},
     {1., 1.20, 0.0, 1.},          {2., 3.00, 0.0, 2.},          {1., 0.25, 0.0, 3.},
     {1., 1.20, 0.0, 2.},          {1., 0.25, 0.0, 3.},          {1., 1.20, 0.0, 2.},
     {1., 0.80, 0.0, 1.},          {1., 0.08, 180.0, 3.},        {1., 0.80, 0.0, 1.},
     {1., 0.08, 180.0, 3.},        {1., 0.15, 0.0, 3.},          {1., 0.16, 0.0, 3.},
     {1., 0.38, 180.0, 3.},        {1., 1.15, 0.0, 1.},          {1., 0.16, 0.0, 3.},
     {1., 0.25, 0.0, 1.},          {1., 2.30, 180.0, 2.},        {1., 1.90, 0.0, 1.},
     {1., 2.175, 180.0, 2.},       {1., 0.30, 0.0, 3.},          {1., 6.65, 180.0, 2.},
     {1., 1.90, 180.0, 1.},        {1., 0.18, 0.0, 3.},          {1., 0.25, 180.0, 2.},
     {1., 0.20, 180.0, 1.},        {1., 0.30, 0.0, 3.},          {1., 0.48, 180.0, 2.},
     {1., 0.383, 0.0, 3.},         {1., 0.1, 180.0, 2.},         {1., 0.383, 0.0, 3.},
     {1., 0.80, 180.0, 1.},        {1., 0.10, 0.0, 3.},          {1., 0.85, 180.0, 2.},
     {1., 1.35, 180.0, 1.},        {1., 0.383, 0.0, 3.},         {1., 0.65, 0.0, 2.},
     {1., 2.70, 180.0, 2.},        {1., 1.40, 180.0, 1.},        {1., 0.00, 000.0, 2.},
     {1., 2.50, 0.0, 1.},          {1., 0.144, 0.0, 3.},         {1., 1.175, 0.0, 2.},
     {1., 0.144, 0.0, 3.},         {1., 1.175, 0.0, 2.},         {1., 0.144, 0.0, 3.},
     {1., 1.175, 0.0, 2.},         {1., 0.00, 0.0, 3.},          {1., 1.20, 180.0, 1.},
     {1., 0.00, 0.0, 3.},          {1., 0.45, 180.0, 1.},        {1., 0.00, 0.0, 3.},
     {1., 0.00, 180.0, 1.},        {1., 0.00, 0.0, 3.},          {1., 0.25, 0.0, 1.},
     {1., 0.00, 0.0, 3.},          {1., 0.25, 0.0, 1.},          {1., 0.00, 0.0, 3.},
     {1., 0.19, 0.0, 1.},          {1., 0.00, 0.0, 3.},          {1., 0.25, 0.0, 1.},
     {1., 0.00, 0.0, 3.},          {1., 0.55, 0.0, 1.},          {1., 0.00, 0.0, 3.},
     {1., 0.25, 0.0, 1.},          {1., 0.00, 0.0, 3.},          {1., 0.25, 0.0, 1.},
     {1., 0.00, 0.0, 3.},          {1., 0.19, 0.0, 1.},          {1., 0.00, 0.0, 3.},
     {1., 0.25, 0.0, 1.},          {1., 0.00, 0.0, 3.},          {1., 0.55, 0.0, 1.}}};

static constexpr std::array<std::array<const char*, 4>, 38> improperDihedralsAtomTypes = {
    {{"X", "o", "c", "o"},     {"X", "X", "c", "o"},     {"X", "X", "ca", "ha"},   {"X", "X", "n", "hn"},
     {"X", "X", "n2", "hn"},   {"X", "X", "na", "hn"},   {"X", "c3", "n", "c3"},   {"X", "n2", "ca", "n2"},
     {"c", "c2", "c2", "c3"},  {"c", "ca", "ca", "c3"},  {"c", "c3", "n", "hn"},   {"c", "c3", "n", "o"},
     {"c2", "c2", "na", "c3"}, {"c2", "c", "c2", "c3"},  {"c2", "c3", "c2", "hc"}, {"c2", "c3", "ca", "hc"},
     {"c2", "hc", "c", "o"},   {"c3", "o", "c", "oh"},   {"c3", "c2", "c2", "n2"}, {"c3", "c2", "c2", "na"},
     {"c3", "ca", "ca", "n2"}, {"c3", "ca", "ca", "na"}, {"ca", "ca", "ca", "c2"}, {"ca", "ca", "ca", "c3"},
     {"ca", "ca", "ca", "f"},  {"ca", "ca", "ca", "cl"}, {"ca", "ca", "ca", "br"}, {"ca", "ca", "ca", "i"},
     {"ca", "ca", "c", "oh"},  {"ca", "ca", "na", "c3"}, {"ca", "c", "ca", "c3"},  {"ca", "hc", "c", "o"},
     {"ca", "n2", "ca", "n2"}, {"hc", "o", "c", "oh"},   {"hc", "o", "c", "os"},   {"n2", "c2", "ca", "n2"},
     {"n2", "ca", "ca", "n2"}, {"na", "n2", "ca", "n2"}}};

static constexpr std::array<std::array<double, 3>, 38> improperDihedralsParameters = {
    {{1.1, 180., 2.}, {10.5, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.},
     {1.1, 180., 2.}, {10.5, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.},
     {1.1, 180., 2.}, {1.1, 180., 2.},  {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.},
     {1.1, 180., 2.}, {1.1, 180., 2.},  {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.},
     {1.1, 180., 2.}, {1.1, 180., 2.},  {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.},
     {1.1, 180., 2.}, {1.1, 180., 2.},  {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.}, {1.1, 180., 2.},
     {1.1, 180., 2.}, {1.1, 180., 2.}}};

static constexpr std::array<const char*, 67> ljAtomTypes = {
    "h1", "h2", "h3", "h4", "h5", "ha", "hc", "hn", "ho", "hp", "hs", "hw", "hx", "o",  "oh", "os", "ow",
    "c",  "c1", "c2", "c3", "ca", "cc", "cd", "ce", "cf", "cg", "ch", "cp", "cq", "cu", "cv", "cx", "cy",
    "cz", "n",  "n1", "n2", "n3", "n4", "na", "nb", "nc", "nd", "ne", "nf", "nh", "no", "s",  "s2", "s4",
    "s6", "sx", "sy", "sh", "ss", "p2", "p3", "p4", "p5", "pb", "px", "py", "f",  "cl", "br", "i"};

static constexpr std::array<std::array<double, 2>, 67> ljParameters = {
    {{1.3870, 0.0157}, {1.2870, 0.0157}, {1.1870, 0.0157}, {1.4090, 0.0150}, {1.3590, 0.0150}, {1.4590, 0.0150},
     {1.4870, 0.0157}, {0.6000, 0.0157}, {0.0000, 0.0000}, {0.6000, 0.0157}, {0.6000, 0.0157}, {0.0000, 0.0000},
     {1.1000, 0.0157}, {1.6612, 0.2100}, {1.7210, 0.2104}, {1.6837, 0.1700}, {1.7683, 0.1520}, {1.9080, 0.0860},
     {1.9080, 0.2100}, {1.9080, 0.0860}, {1.9080, 0.1094}, {1.9080, 0.0860}, {1.9080, 0.0860}, {1.9080, 0.0860},
     {1.9080, 0.0860}, {1.9080, 0.0860}, {1.9080, 0.2100}, {1.9080, 0.2100}, {1.9080, 0.0860}, {1.9080, 0.0860},
     {1.9080, 0.0860}, {1.9080, 0.0860}, {1.9080, 0.0860}, {1.9080, 0.0860}, {1.9080, 0.0860}, {1.8240, 0.1700},
     {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700},
     {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700}, {1.8240, 0.1700},
     {2.0000, 0.2500}, {2.0000, 0.2500}, {2.0000, 0.2500}, {2.0000, 0.2500}, {2.0000, 0.2500}, {2.0000, 0.2500},
     {2.0000, 0.2500}, {2.0000, 0.2500}, {2.1000, 0.2000}, {2.1000, 0.2000}, {2.1000, 0.2000}, {2.1000, 0.2000},
     {2.1000, 0.2000}, {2.1000, 0.2000}, {2.1000, 0.2000}, {1.75, 0.061},    {1.948, 0.265},   {2.02, 0.420},
     {2.15, 0.50}}};

} // namespace GaffDefaultParameters
} // namespace MolecularMechanics
} // namespace Scine

#endif // MOLECULARMECHANICS_GAFFDEFAULTPARAMETERS_H
